@@ -107,7 +107,7 @@ class World:
             world = scene.world
             world.setZen(args['gradient_top'])
             world.setHor(args['gradient_bottom'])
-            world.setSkytype(1) # make sure sky gets blended
+            world.setSkytype(1)  # make sure sky gets blended
 
             self.stars.set_up(args, world)
             self.mist.set_up(args, world)
@@ -143,7 +143,7 @@ class Floor:
         #note that the idea is to fake it so that mirror still works
         #TODO: it probably would be nicer to handle this with compositing as
         #this solution does not work properly with stars option!
-        opacity = int(args['floor_opacity'])/100.0
+        opacity = int(args['floor_opacity']) / 100.0
         self.material.setMode(self.mode ^ Material.Modes['RAYTRANSP'])
         self.material.fresnelTrans = 5 * (1.0 - opacity)
         self.material.fresnelTransFac = 5 * (1.0 - opacity)
@@ -344,10 +344,10 @@ class Box(BlenderObject):
         ob = Object.Get(self.name).getParent()
 
         width, height = image.getSize()
-        fac = height/0.8
-        box_width = width/fac
-        box_height = height/fac
-        box_depth = max(float(args['box_depth'])/fac, 0.001)
+        fac = height / 0.8
+        box_width = width / fac
+        box_height = height / fac
+        box_depth = max(float(args['box_depth']) / fac, 0.001)
         ob.setSize(box_depth, box_width, box_height)
 
 
@@ -361,7 +361,7 @@ class Book(BlenderObject):
             left_page.save(temporary_image.path)
             args[image_arg] = temporary_image.path
 
-        if args['page_mapping'] == 'Wrap Both':
+        if args['page_mapping'].startswith('Wrap'):
             im_path = args['input_image_1']
             im = PILImage.open(im_path)
             width, height = im.size
@@ -591,6 +591,7 @@ class BlenderInitializer:
 
 #FIXME: duplicate code from lib/system.py (should be imported)
 
+
 class TempFile:
 
     def __init__(self, suffix='', path=None):
