@@ -10,9 +10,16 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 
+# Follows PEP8
+
+import os
+import sys
+
+sys.path.insert(0, os.path.dirname(__file__))
+
 from core.config import init_config_paths
-init_config_paths()
\ No newline at end of file
+init_config_paths()
