@@ -10,7 +10,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
@@ -18,11 +18,16 @@
 
 # Embedded icon is designed by Igor Kekeljevic (http://www.admiror-ns.co.yu).
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
-from lib.imtools import fill_background_color, generate_layer, remove_alpha, has_transparency
+from lib.imtools import fill_background_color, generate_layer, \
+    remove_alpha, has_transparency, get_alpha, paste
 
 #---Pil
+
+
 def init():
     global Image, HTMLColorToRGBA
     import Image
@@ -31,6 +36,7 @@ def init():
 
 FILL_CHOICES = (_t('Color'), _t('Image'))
 
+
 def background(image, fill, mark, color,
         horizontal_offset=None, vertical_offset=None,
         horizontal_justification=None, vertical_justification=None,
@@ -41,41 +47,46 @@ def background(image, fill, mark, color,
         image = image.convert('RGBA')
     if fill == FILL_CHOICES[0]:
         opacity = (255 * opacity) / 100
-        return fill_background_color(image, HTMLColorToRGBA(color,opacity))
+        return fill_background_color(image, HTMLColorToRGBA(color,
+            opacity))
     elif fill == FILL_CHOICES[1]:
         layer = generate_layer(image.size, mark, method,
                                horizontal_offset, vertical_offset,
-                               horizontal_justification, vertical_justification,
+                               horizontal_justification,
+                               vertical_justification,
                                orientation, opacity)
-        layer.paste(remove_alpha(image), mask = image.convert('RGBA'))
+        paste(layer, image, mask=image)
         return layer
 
 #---Phatch
-class Action(models.StampMixin,models.Action):
-    label       = _t('Background')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(background)
-    version     = '0.1'
-    tags        = [_t('color'), _t('filter')]
-    __doc__     = _t('Put color under transparent image')
-    
-    def interface(self,fields):
-        fields[_t('Fill')] = self.ChoiceField(FILL_CHOICES[0], choices=FILL_CHOICES)
-        fields[_t('Color')]  = self.ColorField('#FFFFFF')
+
+
+class Action(models.StampMixin, models.Action):
+    label = _t('Background')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(background)
+    version = '0.1'
+    tags = [_t('color'), _t('filter')]
+    __doc__ = _t('Put color under transparent image')
+
+    def interface(self, fields):
+        fields[_t('Fill')] = self.ChoiceField(FILL_CHOICES[0],
+            choices=FILL_CHOICES)
+        fields[_t('Color')] = self.ColorField('#FFFFFF')
 
         super(Action, self).interface(fields)
-        
+
     def get_relevant_field_labels(self):
         """If this method is present, Phatch will only show relevant
-        fields. 
-        
+        fields.
+
         :returns: list of the field labels which are relevant
         :rtype: list of strings
-        
-        .. note:: 
-        
+
+        .. note::
+
             It is very important that the list of labels has EXACTLY
             the same order as defined in the interface method.
         """
@@ -90,7 +101,7 @@ class Action(models.StampMixin,models.Action):
 
         return relevant
 
-    icon  = \
+    icon = \
 'x\xda\x01a\r\x9e\xf2\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
 \x00\x000\x08\x06\x00\x00\x00W\x02\xf9\x87\x00\x00\x00\x04sBIT\x08\x08\x08\
 \x08|\x08d\x88\x00\x00\r\x18IDATh\x81\xed\x99}l\x14\xe7\x9d\xc7?\xcf\xbc\xac\
