@@ -105,7 +105,7 @@ class BlenderObject(object):
         if len(image_size.split()) > 1:
             values['image_size'] = system.fix_quotes(image_size)
 
-        return COMMAND%arg_str%values
+        return COMMAND % arg_str % values
 
 
 class Book(BlenderObject):
@@ -336,11 +336,11 @@ class Action(models.Action):
         global imtools
         from lib import imtools
         self.find_exe('blender')
-        out, err = system.shell('%(blender)s -v'%self.exe)
+        out, err = system.shell((self.exe, '-v'))
         if not RE_BLENDER_VERSION.search(out):
             raise Exception(
                 _('Sorry, you have the wrong version of Blender installed.') +
-                ' '+_('Blender %s is required.')%BLENDER_VERSIONS)
+                ' ' + _('Blender %s is required.') % BLENDER_VERSIONS)
 
     def interface(self, fields):
         fields[_t('Render Width')] = self.PixelField('800px')
@@ -384,7 +384,7 @@ class Action(models.Action):
         camera.selected_object = self.get_field_string('Object')
         # important the dialog title should change for every object
         # otherwise same dialog is used
-        camera.dialog = _('Select Rotation for %s')%_(
+        camera.dialog = _('Select Rotation for %s') % _(
             camera.selected_object)
         camera.init_dictionary()
 
@@ -393,7 +393,7 @@ class Action(models.Action):
     def apply(self, photo, setting, cache):
         info = photo.info
         w, h = info['size']
-        values = self.values(info, pixel_fields = {
+        values = self.values(info, pixel_fields={
             'Render Width': w,
             'Render Height': h,
             'Box Depth': h,
@@ -436,7 +436,7 @@ class Action(models.Action):
 
         selected_object.set_args(self, values)
         values['blend'] = os.path.join(blender_path,
-            selected_object.name.lower()+'.blend')
+            selected_object.name.lower() + '.blend')
 
         values['blender'] = self.exe['blender']
         values['runner'] = os.path.join(blender_path, 'runner.py')
