@@ -18,16 +18,22 @@
 
 # Embedded icon is designed by Igor Kekeljevic (http://www.admiror-ns.co.yu).
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
     global Image, ImageColor, imtools
-    import Image, ImageColor
+    import Image
+    import ImageColor
     from lib import imtools
 
-def brightness(image,amount=50):
+
+def brightness(image, amount=50):
     """Adjust brightness from black to white
     - amount: -1(black) 0 (unchanged) 1(white)
     - repeat: how many times it should be repeated"""
@@ -41,34 +47,34 @@ def brightness(image,amount=50):
         im = imtools.blend(
                 image,
                 Image.new(image.mode, image.size, 0),
-                -amount/100.0
-        )
+                -amount / 100.0)
     else:
         #fade to white
         im = imtools.blend(
                 image,
                 Image.new(image.mode, image.size,
-                    ImageColor.getcolor('white',image.mode)),
-                amount/100.0
-        )
+                    ImageColor.getcolor('white', image.mode)),
+                amount / 100.0)
     #fix image transparency mask
     if imtools.has_alpha(image):
-        im.putalpha(image.split()[-1])
+        im.putalpha(imtools.get_alpha(image))
     return im
 
 #---Phatch
-class Action(models.Action):
-    label       = _t('Brightness')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(brightness)
-    version     = '0.1'
-    tags        = [_t('color')]
-    __doc__     = _t('Adjust brightness from black to white')
 
-    def interface(self,fields):
-        fields[_t('Amount')] = self.SliderField(50,-100,100)
+
+class Action(models.Action):
+    label = _t('Brightness')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(brightness)
+    version = '0.1'
+    tags = [_t('color')]
+    __doc__ = _t('Adjust brightness from black to white')
+
+    def interface(self, fields):
+        fields[_t('Amount')] = self.SliderField(50, -100, 100)
 
     icon = \
 'x\xda\x01p\x0b\x8f\xf4\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
