@@ -18,45 +18,53 @@
 
 # Embedded icon is designed by Igor Kekeljevic (http://www.admiror-ns.co.yu).
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
     global Image, ImageOps, imtools
-    import Image, ImageOps
+    import Image
+    import ImageOps
     from lib import imtools
 
-def colorize(image,black,white,amount=100):
+
+def colorize(image, black, white, amount=100):
     """Apply a filter
     - amount: 0-1"""
     if image.mode != 'L':
-        im      = image.convert('L')
+        im = image.convert('L')
     else:
-        im      = image
-    colorized   = ImageOps.colorize(im, black, white)
+        im = image
+    colorized = ImageOps.colorize(im, black, white)
     if image.mode == 'RGBA':
-        colorized  = colorized.convert('RGBA')
-        colorized.putalpha(image.split()[-1])
+        colorized = colorized.convert('RGBA')
+        colorized.putalpha(imtools.get_alpha(image))
     if amount < 100:
-        return imtools.blend(image, colorized, amount/100.0)
+        return imtools.blend(image, colorized, amount / 100.0)
     return colorized
 
 #---Phatch
-class Action(models.Action):
-    label       = _t('Colorize')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(colorize)
-    version     = '0.1'
-    tags        = [_t('color')]
-    __doc__     = _t('Colorize grayscale image')
 
-    def interface(self,fields):
-        fields[_t('Black')]  = self.ColorField('#735710')
-        fields[_t('White')]  = self.ColorField('#FFFFFF')
-        fields[_t('Amount')] = self.SliderField(100,1,100)
+
+class Action(models.Action):
+    label = _t('Colorize')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(colorize)
+    version = '0.1'
+    tags = [_t('color')]
+    __doc__ = _t('Colorize grayscale image')
+
+    def interface(self, fields):
+        fields[_t('Black')] = self.ColorField('#735710')
+        fields[_t('White')] = self.ColorField('#FFFFFF')
+        fields[_t('Amount')] = self.SliderField(100, 1, 100)
 
     icon = \
 'x\xda\x01\x1f\x08\xe0\xf7\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00*\
