@@ -15,6 +15,8 @@
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
 # Phatch recommends SPE (http://pythonide.stani.be) for editing python files.
+#
+# Follows PEP8
 
 # Embedded icon is taken from www.openclipart.org (public domain)
 
@@ -22,33 +24,40 @@ from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
     global Image, ImageFilter, imtools
-    import Image, ImageFilter
+    import Image
+    import ImageFilter
     from lib import imtools
 
-def common(image,radius,amount=100):
+
+def common(image, radius, amount=100):
     """Apply a filter
     - amount: 0-1"""
-    commoned  = image.filter(ImageFilter.ModeFilter(radius))
+    image = imtools.convert_safe_mode(image)
+    commoned = image.filter(ImageFilter.ModeFilter(radius))
     if amount < 100:
-        return imtools.blend(image, commoned, amount/100.0)
+        return imtools.blend(image, commoned, amount / 100.0)
     return commoned
 
 #---Phatch
-class Action(models.Action):
-    label       = _t('Common')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(common)
-    version     = '0.1'
-    tags        = [_t('filter')]
-    __doc__     = _t("Copies the most common pixel value")
 
-    def interface(self,fields):
+
+class Action(models.Action):
+    label = _t('Common')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(common)
+    version = '0.1'
+    tags = [_t('filter')]
+    __doc__ = _t("Copies the most common pixel value")
+
+    def interface(self, fields):
         fields[_t('Radius')] = self.RankSizeField(self.RANK_SIZES[0])
-        fields[_t('Amount')] = self.SliderField(100,1,100)
+        fields[_t('Amount')] = self.SliderField(100, 1, 100)
 
     icon = \
 'x\xda\x01\x14\r\xeb\xf2\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
