@@ -18,53 +18,60 @@
 
 # Embedded icon is taken from www.openclipart.org (public domain)
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 from lib.formField import IMAGE_EFFECTS
 
 #---PIL
+
+
 def init():
     global Image, ImageFilter, imtools
-    import Image, ImageFilter
+    import Image
+    import ImageFilter
     from lib import imtools
 
 
-def effect(image,filter,amount=100,repeat=1):
+def effect(image, filter, amount=100, repeat=1):
     """Apply a filter
     - amount: 0-1
     - repeat: how many times it should be repeated"""
-    filter      = getattr(ImageFilter,filter)
+    filter = getattr(ImageFilter, filter)
     image = imtools.convert_safe_mode(image)
     for i in range(repeat):
-        filtered   = image.filter(filter)
+        filtered = image.filter(filter)
         if imtools.has_alpha(image) and \
-           filter in [ImageFilter.CONTOUR,ImageFilter.EMBOSS]:
-            filtered.putalpha(image.split()[-1])
+           filter in [ImageFilter.CONTOUR, ImageFilter.EMBOSS]:
+            filtered.putalpha(imtools.get_alpha(image))
         if amount < 100:
-            image   = imtools.blend(image, filtered, amount/100.0)
+            image = imtools.blend(image, filtered, amount / 100.0)
         else:
-            image   = filtered
+            image = filtered
     return image
 
 #---Phatch
+
+
 class Action(models.Action):
     """"""
 
-    label       = _t('Effect')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(effect)
-    version     = '0.1'
-    tags        = [_t('filter')]
+    label = _t('Effect')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(effect)
+    version = '0.1'
+    tags = [_t('filter')]
     tags_hidden = IMAGE_EFFECTS
-    __doc__     = _t('Blur, Sharpen, Emboss, Smooth, ...')
+    __doc__ = _t('Blur, Sharpen, Emboss, Smooth, ...')
 
-    def interface(self,fields):
+    def interface(self, fields):
         fields[_t('Filter')] = self.ImageEffectField(
             self.IMAGE_EFFECTS[0])
-        fields[_t('Repeat')] = self.SliderField(1,1,10)
-        fields[_t('Amount')] = self.SliderField(100,1,100)
+        fields[_t('Repeat')] = self.SliderField(1, 1, 10)
+        fields[_t('Amount')] = self.SliderField(100, 1, 100)
 
     icon = \
 'x\xda\x01|\x07\x83\xf8\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
