@@ -10,77 +10,85 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 
 # Embedded icon is taken from www.openclipart.org (public domain)
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
     global Image, ImageOps
-    import Image, ImageOps
+    import Image
+    import ImageOps
     global HTMLColorToRGBA
     from lib.colors import HTMLColorToRGBA
 
+
 def fit(image, size, method, bleed, centering):
     return ImageOps.fit(image, size, method, bleed, centering)
 
 #---Phatch
+
+
 class Action(models.Action):
     """Resize an image"""
-    
-    label       = _t('Fit')
-    author      = 'Stani'
-    all_layers  = True
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(fit)
-    version     = '0.1'
-    tags        = [_t('transform'), _t('size')]
-    __doc__     = _t('Downsize and crop image with fixed ratio')
-    
-    def interface(self,fields):
-        fields[_t('Canvas Width')]     = self.PixelField('<min(width,height)>',
+
+    label = _t('Fit')
+    author = 'Stani'
+    all_layers = True
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(fit)
+    version = '0.1'
+    tags = [_t('transform'), _t('size')]
+    __doc__ = _t('Downsize and crop image with fixed ratio')
+
+    def interface(self, fields):
+        fields[_t('Canvas Width')] = self.PixelField('<min(width,height)>',
                                             choices=self.PIXELS_X)
-        fields[_t('Canvas Height')]    = self.PixelField('<min(width,height)>',
+        fields[_t('Canvas Height')] = self.PixelField('<min(width,height)>',
                                             choices=self.PIXELS_Y)
-        fields[_t('Resolution')]       = self.DpiField(choices=self.DPIS)
-        fields[_t('Align Horizontal')] = self.SliderField(50,0,100)
-        fields[_t('Align Vertical')]   = self.SliderField(50,0,100)
-        fields[_t('Bleed')]            = self.SliderField(0,0,100)
-        fields[_t('Resample Image')]   = self.ImageResampleAutoField('automatic')
-        
-    def values(self,info):
+        fields[_t('Resolution')] = self.DpiField(choices=self.DPIS)
+        fields[_t('Align Horizontal')] = self.SliderField(50, 0, 100)
+        fields[_t('Align Vertical')] = self.SliderField(50, 0, 100)
+        fields[_t('Bleed')] = self.SliderField(0, 0, 100)
+        fields[_t('Resample Image')] = self.ImageResampleAutoField('automatic')
+
+    def values(self, info):
         #dpi
-        dpi         = info['dpi'] = self.get_field('Resolution',info)
+        dpi = info['dpi'] = self.get_field('Resolution', info)
         #size
-        x0, y0      = info['size']
-        x1          = self.get_field_size('Canvas Width',info,x0,dpi)
-        y1          = self.get_field_size('Canvas Height',info,y0,dpi)
-        new_size    = (x1,y1)
+        x0, y0 = info['size']
+        x1 = self.get_field_size('Canvas Width', info, x0, dpi)
+        y1 = self.get_field_size('Canvas Height', info, y0, dpi)
+        new_size = (x1, y1)
         #method
-        method      = self.get_field('Resample Image',info)
+        method = self.get_field('Resample Image', info)
         if method == 'AUTOMATIC':
-            if x1 < x0 and y1 <y0:
-                method      = 'ANTIALIAS'
+            if x1 < x0 and y1 < y0:
+                method = 'ANTIALIAS'
             else:
-                method      = 'BICUBIC'
-        method      = getattr(Image,method)
+                method = 'BICUBIC'
+        method = getattr(Image, method)
         #centering
-        align_hor   = self.get_field('Align Horizontal', info)/100.0
-        align_ver   = self.get_field('Align Vertical', info)/100.0
+        align_hor = self.get_field('Align Horizontal', info) / 100.0
+        align_ver = self.get_field('Align Vertical', info) / 100.0
         #parameters
         return {
-            'size'          : new_size,
-            'method'        : method,
-            'centering'     : (align_hor,align_ver),
-            'bleed'         : self.get_field('Bleed', info)/100.0,
+            'size': new_size,
+            'method': method,
+            'centering': (align_hor, align_ver),
+            'bleed': self.get_field('Bleed', info) / 100.0,
         }
-    
+
     icon = \
 'x\xda\x01(\x0e\xd7\xf1\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
 \x00\x000\x08\x06\x00\x00\x00W\x02\xf9\x87\x00\x00\x00\x04sBIT\x08\x08\x08\
