@@ -19,6 +19,8 @@
 
 # Embedded icon is designed by Alexandre Moore(http://nuovext.pwsp.net).
 
+# Follows PEP8
+
 try:
     _
 except NameError:
@@ -30,59 +32,44 @@ from lib.reverse_translation import _t
 #no need to lazily import these as they are always imported
 from lib import system
 
-AUTOMATIC                   = _t('Automatic (use exif orientation)')
-COPY                        = _t('Copy')
-CROP                        = _t('Crop')
-ROTATE                      = _t('Rotate')
-FLIP                        = _t('Flip')
-GRAYSCALE                   = _t('Grayscale')
-THUMB                       = _t('Regenerate thumbnail')
-TRANSPOSE                   = _t('Transpose')
-TRANSVERSE                  = _t('Transverse')
+AUTOMATIC = _t('Automatic (use exif orientation)')
+COPY = _t('Copy')
+CROP = _t('Crop')
+ROTATE = _t('Rotate')
+FLIP = _t('Flip')
+GRAYSCALE = _t('Grayscale')
+THUMB = _t('Regenerate thumbnail')
+TRANSPOSE = _t('Transpose')
+TRANSVERSE = _t('Transverse')
 
-ROTATE_AMOUNTS              = ('90 degrees','180 degrees','270 degrees')
-HORIZONTAL                  = _t('Horizontal')
-VERTICAL                    = _t('Vertical')
-FLIP_DIRECTIONS             = (HORIZONTAL, VERTICAL)
-LOSSLESS_JPEG_FORMAT_ERROR  = \
+ROTATE_AMOUNTS = ('90 degrees', '180 degrees', '270 degrees')
+HORIZONTAL = _t('Horizontal')
+VERTICAL = _t('Vertical')
+FLIP_DIRECTIONS = (HORIZONTAL, VERTICAL)
+LOSSLESS_JPEG_FORMAT_ERROR = \
     _('Lossless JPEG transformation does not work on a %s image:')
 
+
 class Arguments(list):
+    """List with tweaked append behaviour to make it suitable for
+    command line arguments."""
+
     def __str__(self):
         return ' '.join(self)
 
     def append(self, *options):
-        option = '-%s'%options[0]
-        if len(options)>1:
-            option += ' %s'%' '.join(options[1:])
-        super(Arguments,self).append(option)
+        option = '-%s' % options[0]
+        if len(options) > 1:
+            option += ' %s' % ' '.join(options[1:])
+        super(Arguments, self).append(option)
 
-class Utility(object):
-    name = ''
-    command = ''
 
-    def interface(self, action, fields):
-        super(Utility,self).interface(action,fields)
-
-    def get_relevant_field_labels(self, action):
-        return []
-
-class JpegUtility(Utility):
-    def execute(self, photo):
-        info = photo.info
-        format = info['format']
-        if format == 'JPEG':
-            super(JpegUtility, self).execute(photo)
-        else:
-            raise Exception('%s\n%s' \
-                % (LOSSLESS_JPEG_FORMAT_ERROR%format, info['path']))
-
-class Exiftran(JpegUtility):
-    name            = 'Exiftran (with exif support)'
-    command         = system.find_exe('exiftran')
-    angles          = {'90 degrees': '9', '180 degrees': '1',
+class Exiftran(object):
+    name = 'Exiftran (with exif support)'
+    command = system.find_exe('exiftran')
+    angles = {'90 degrees': '9', '180 degrees': '1',
                         '270 degrees': '2', }
-    directions      = {HORIZONTAL:'F',VERTICAL:'f'}
+    directions = {HORIZONTAL: 'F', VERTICAL: 'f'}
     transformations = (AUTOMATIC, ROTATE, FLIP, THUMB, TRANSPOSE,
                         TRANSVERSE)
 
@@ -101,9 +88,9 @@ class Exiftran(JpegUtility):
 
     def get_relevant_field_labels(self, action):
         advanced = action.get_field_string('Show Advanced Options') \
-            in ('yes','true')
+            in ('yes', 'true')
         relevant = ['Transformation']
-        transformation_fields = {ROTATE:'Angle', FLIP:'Direction'}
+        transformation_fields = {ROTATE: 'Angle', FLIP: 'Direction'}
         transformation = action.get_field_string('Transformation')
         if transformation in transformation_fields:
             relevant.append(transformation_fields[transformation])
@@ -117,12 +104,12 @@ class Exiftran(JpegUtility):
         return relevant
 
     def get_command_line_args(self, action, photo):
-        info    = photo.info
-        values  = action.values(info)
-        args    = Arguments()
+        info = photo.info
+        values = action.values(info)
+        args = Arguments()
         #transformation
-        transformation  = values['transformation']
-        if transformation   == AUTOMATIC:
+        transformation = values['transformation']
+        if transformation == AUTOMATIC:
             args.append('a')
         elif transformation == THUMB:
             args.append('g')
@@ -147,17 +134,19 @@ class Exiftran(JpegUtility):
         return args
 
     def get_command_line(self, action, photo, input, output):
-        return '%s -i %s %s -o %s'%(self.command, system.fix_quotes(input),
-            self.get_command_line_args(action,photo),system.fix_quotes(output))
+        return '%s -i %s %s -o %s' % (self.command, system.fix_quotes(input),
+            self.get_command_line_args(action, photo),
+            system.fix_quotes(output))
 
-class Jpegtran(JpegUtility, models.CropMixin):
-    name            = 'Jpegtran (without exif support)'
-    command         = system.find_exe('jpegtran')
+
+class Jpegtran(models.CropMixin):
+    name = 'Jpegtran (without exif support)'
+    command = system.find_exe('jpegtran')
     transformations = (COPY, CROP, FLIP, GRAYSCALE, ROTATE, TRANSPOSE,
                         TRANSVERSE)
-    copy_choices    = (_t('None'), _t('Comments'), _t('All'))
-    directions      = {HORIZONTAL: 'horizontal', VERTICAL: 'vertical'}
-    angles          = {'90 degrees': '90', '180 degrees': '180',
+    copy_choices = (_t('None'), _t('Comments'), _t('All'))
+    directions = {HORIZONTAL: 'horizontal', VERTICAL: 'vertical'}
+    angles = {'90 degrees': '90', '180 degrees': '180',
                         '270 degrees': '270'}
 
     def interface(self, action, fields):
@@ -168,49 +157,49 @@ class Jpegtran(JpegUtility, models.CropMixin):
             choices=self.copy_choices)
         fields[_t('Angle ')] = action.ChoiceField(ROTATE_AMOUNTS[0],
             choices=ROTATE_AMOUNTS)
-        fields[_t('Direction ')] =action.ChoiceField(FLIP_DIRECTIONS[0],
+        fields[_t('Direction ')] = action.ChoiceField(FLIP_DIRECTIONS[0],
             choices=FLIP_DIRECTIONS)
-        super(Jpegtran,self).interface(fields, action)
+        super(Jpegtran, self).interface(fields, action)
 
     def get_relevant_field_labels(self, action):
-        relevant            = ['Transformation ']
-        transformation      = action.get_field_string('Transformation ')
-        transformation_fields    = {
-            COPY    : ['Copy'],
-            CROP    : \
-                models.CropMixin.get_relevant_field_labels(self,action),
+        relevant = ['Transformation ']
+        transformation = action.get_field_string('Transformation ')
+        transformation_fields = {
+            COPY: ['Copy'],
+            CROP: \
+                models.CropMixin.get_relevant_field_labels(self, action),
                 #specify explicitly from crop mixin
-            ROTATE  : ['Angle '],
-            FLIP    : ['Direction '],
+            ROTATE: ['Angle '],
+            FLIP: ['Direction '],
         }
         if transformation in transformation_fields:
             relevant.extend(transformation_fields[transformation])
         return relevant
 
     def get_command_line_args(self, action, photo):
-        info            = photo.info
-        args    = Arguments()
+        info = photo.info
+        args = Arguments()
         #pixelfields defined in the CropMixin
-        values  = models.CropMixin.values(self,info,action=action)
+        values = models.CropMixin.values(self, info, action=action)
         #transformation
-        transformation  = values['transformation_']
-        if transformation   == COPY:
-            args.append('copy',values['copy'].lower())
+        transformation = values['transformation_']
+        if transformation == COPY:
+            args.append('copy', values['copy'].lower())
         elif transformation == CROP:
-            mode    = values['mode']
+            mode = values['mode']
             if mode == 'Auto':
-                bbox = photo.get_flattened_image().get_bbox()
-                values['left'],values['top'],values['width'],\
+                bbox = photo.get_flattened_image().getbbox()
+                values['left'], values['top'], values['width'], \
                     values['height'] = bbox
             else:
                 if mode == 'All':
-                    values['left'] = values['top'] = values['right'] =\
+                    values['left'] = values['top'] = values['right'] = \
                         values['bottom'] = values['all']
-                values['width'],values['height']=info['size']
-                values['width']  -= values['right']+values['left']+1
-                values['height'] -= values['bottom']+values['top']+1
-            args.append('crop','%(width)sx%(height)s+%(left)s+%(top)s'\
-                %values)
+                values['width'], values['height'] = info['size']
+                values['width'] -= values['right'] + values['left'] + 1
+                values['height'] -= values['bottom'] + values['top'] + 1
+            args.append('crop',
+                '%(width)sx%(height)s+%(left)s+%(top)s' % values)
         elif transformation == ROTATE:
             args.append('rotate', self.angles[values['angle_']])
         elif transformation == FLIP:
@@ -222,79 +211,87 @@ class Jpegtran(JpegUtility, models.CropMixin):
         return args
 
     def get_command_line(self, action, photo, input, output):
-        return '%s %s %s > %s'%(self.command,
-            self.get_command_line_args(action,photo),system.fix_quotes(input),system.fix_quotes(output))
+        return '%s %s %s > %s' % (self.command,
+            self.get_command_line_args(action, photo),
+                system.fix_quotes(input),
+                system.fix_quotes(output))
+
+
+def utilities_dict(*utilities):
+    d = {}
+    for utility in utilities:
+        d[utility.name] = utility
+    return d
 
 
 class UtilityMixin(object):
-    file_in     = 'file_in.tif'
-    file_out    = 'file_out.png'
-
-    @staticmethod
-    def utilities_dict(*utilities):
-        d = {}
-        for utility in utilities:
-            d[utility.name] = utility
-        return d
+    file_in = 'file_in.tif'
+    file_out = 'file_out.png'
 
     def interface(self, fields):
-        super(UtilityMixin,self).interface(fields)
-        names   = self.utilities.keys()
+        super(UtilityMixin, self).interface(fields)
+        names = self.utilities.keys()
         fields[_t('Utility')] = self.ChoiceField(names[0],
             choices=names)
         for utility in self.utilities.values():
             utility.interface(self, fields)
 
-    def get_relevant_field_labels(self,relevant=None):
+    def get_relevant_field_labels(self, relevant=None):
         if relevant is None:
             relevant = []
-        utility_name    = self.get_field_string('Utility')
-        utility         = self.utilities[utility_name]
+        utility_name = self.get_field_string('Utility')
+        utility = self.utilities[utility_name]
         relevant.append('Utility')
         relevant.extend(utility.get_relevant_field_labels(self))
         return relevant
 
     def apply(self, photo, setting, cache):
-        info            = photo.info
-        utility_name    = self.get_field('Utility', info)
-        utility         = self.utilities[utility_name]
-        self.call(photo,info,utility)
+        info = photo.info
+        utility_name = self.get_field('Utility', info)
+        utility = self.utilities[utility_name]
+        self.call(photo, info, utility)
         return photo
 
-    def call(self,photo, info,utility):
-        photo.call(utility.get_command_line(self,photo,
+    def call(self, photo, info, utility):
+        """This is decoupled from the apply method so we can overwrite it."""
+        photo.call(utility.get_command_line(self, photo,
             self.file_in, self.file_out))
 
 
-class LossLessSaveUtilityMixin(models.LosslessSaveMixin,UtilityMixin):
-    """This has to work on the source file immediately, otherwise
-    it makes no sense."""
-    def call(self,photo, info, utility):
-        format = info['format']
-        if format == 'JPEG':
-            super(JpegUtility, self).execute(photo)
-        else:
-            raise Exception('%s:\n%s' \
-                % (LOSSLESS_JPEG_FORMAT_ERROR%format, info['path']))
+class LossLessSaveUtilityMixin(models.LosslessSaveMixin, UtilityMixin):
+    """For lossless JPEG operations, this has to work on the source jpeg files
+    immediately, otherwise it makes no sense. So we need to overwrite the
+    call method."""
 
-        system.call(utility.get_command_line(self,photo, info['path'],
-            self.get_lossless_filename(photo,info)))
+    format = 'JPEG'
+
+    def call(self, photo, info, utility):
+        """This is called by the apply method."""
+        format = info['format']
+        if format != self.format:
+            raise Exception('%s:\n%s' \
+                % (LOSSLESS_JPEG_FORMAT_ERROR % format, info['path']))
+
+        system.call(utility.get_command_line(self, photo, info['path'],
+            self.get_lossless_filename(photo, info)))
 
     def get_relevant_field_labels(self):
-        return super(LossLessSaveUtilityMixin,self)\
-            .get_relevant_field_labels(['File Name','In'])
+        """This should work like a save action. So it needs a filename and
+        folder, while the file type is fixed (e.g. JPEG)."""
+        return super(LossLessSaveUtilityMixin, self)\
+            .get_relevant_field_labels(['File Name', 'In'])
 
 
 #---Phatch
-class Action(LossLessSaveUtilityMixin,models.Action):
-    label       = _t('Lossless JPEG')
-    author      = 'Juho Vepsäläinen'
-    email       = 'bebraw@gmail.com'
-    version     = '0.1'
-    tags        = [_t('transform'), _t('size')]
-    __doc__     = _t('Rotate, flip, grayscale and crop')
+class Action(LossLessSaveUtilityMixin, models.Action):
+    label = _t('Lossless JPEG')
+    author = 'Juho Vepsäläinen'
+    email = 'bebraw@gmail.com'
+    version = '0.1'
+    tags = [_t('transform'), _t('size')]
+    __doc__ = _t('Rotate, flip, grayscale and crop')
 
-    utilities   = UtilityMixin.utilities_dict(Exiftran(), Jpegtran())
+    utilities = utilities_dict(Exiftran(), Jpegtran())
 
     def init(self):
         self.find_exe('exiftran')
