@@ -10,7 +10,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
@@ -18,62 +18,68 @@
 
 # Embedded icon is taken from www.openclipart.org (public domain)
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 from lib.openImage import open as open_image
 from lib.imtools import has_transparency
 
-MASK  = 'http://photobatch.wikidot.com/local--files/action-mask/mask_torn.png'
+MASK = 'http://photobatch.wikidot.com/local--files/action-mask/mask_torn.png'
 MASKS = [MASK]
 #---Pil
+
+
 def init():
-    global Image, ImageMath
+    global Image, ImageMath, imtools
     import Image
     import ImageMath
-    
-def put_mask(image,mask,resample_mask,cache=None):
+    from lib import imtools
+
+
+def put_mask(image, mask, resample_mask, cache=None):
     if cache is None:
-        cache   = {}
-    resample_mask  = getattr(Image,resample_mask)
-    id      = mask+'_w%d_h%d'%image.size
+        cache = {}
+    resample_mask = getattr(Image, resample_mask)
+    id = mask + '_w%d_h%d' % image.size
     try:
-        mask    = cache[id]
+        mask = cache[id]
     except KeyError:
-        mask    = cache[id] = open_image(mask).convert('L').resize(
-                                image.size,resample_mask)
+        mask = cache[id] = open_image(mask).convert('L').resize(
+                                image.size, resample_mask)
     if not has_transparency(image):
-        image   = image.convert('RGBA')
+        image = image.convert('RGBA')
     else:
         if has_transparency(image):
             image = image.convert('RGBA')
-        alpha = image.split()[-1]
-        mask = (
-            ImageMath.eval("convert(min(a, b), 'L')",
+        alpha = imtools.get_alpha(image)
+        mask = (ImageMath.eval("convert(min(a, b), 'L')",
             a=alpha,
-            b=mask)
-        )
+            b=mask))
     image.putalpha(mask)
     return image
 
 #---Phatch
+
+
 class Action(models.Action):
     """Apply a watermark with tiling, scaling and opacity"""
-    
-    label       = _t('Mask')
-    author      = 'Stani'
-    cache       = True
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(put_mask)
-    version     = '0.1'
-    tags        = [_t('filter')]
-    __doc__     = _t('Apply a transparency mask')
-    
-    def interface(self,fields):
-        fields[_t('Mask')]          = self.MaskFileField('Daisy')
+
+    label = _t('Mask')
+    author = 'Stani'
+    cache = True
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(put_mask)
+    version = '0.1'
+    tags = [_t('filter')]
+    __doc__ = _t('Apply a transparency mask')
+
+    def interface(self, fields):
+        fields[_t('Mask')] = self.MaskFileField('Daisy')
         fields[_t('Resample Mask')] = self.ImageResampleField('antialias')
-        
-    icon  = \
+
+    icon = \
 'x\xda\x01\xfa\x07\x05\xf8\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\
 \x00\x00\x000\x08\x06\x00\x00\x00W\x02\xf9\x87\x00\x00\x00\x04sBIT\x08\x08\
 \x08\x08|\x08d\x88\x00\x00\x07\xb1IDATh\x81\xd5\x99\x7fL[\xd7\x15\xc7\xbf\
