@@ -18,39 +18,48 @@
 
 # Embedded icon is taken from www.openclipart.org (public domain)
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
     global Image, ImageFilter, imtools
-    import Image, ImageFilter
+    import Image
+    import ImageFilter
     from lib import imtools
 
-def minimum(image,radius,amount=100):
+
+def minimum(image, radius, amount=100):
     """Apply a filter
     - amount: 0-1"""
-    minimumed  = image.filter(ImageFilter.MinFilter(radius))
+    image = imtools.convert_safe_mode(image)
+    minimumed = image.filter(ImageFilter.MinFilter(radius))
     if amount < 100:
-        return imtools.blend(image, minimumed, amount/100.0)
+        return imtools.blend(image, minimumed, amount / 100.0)
     return minimumed
 
 #---Phatch
+
+
 class Action(models.Action):
     """"""
 
-    label       = _t('Minimum')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(minimum)
-    version     = '0.1'
-    tags        = [_t('filter')]
-    __doc__     = _t("Copies the minimum pixel value")
+    label = _t('Minimum')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(minimum)
+    version = '0.1'
+    tags = [_t('filter')]
+    __doc__ = _t("Copies the minimum pixel value")
 
-    def interface(self,fields):
+    def interface(self, fields):
         fields[_t('Radius')] = self.RankSizeField(self.RANK_SIZES[0])
-        fields[_t('Amount')] = self.SliderField(100,1,100)
+        fields[_t('Amount')] = self.SliderField(100, 1, 100)
 
     icon = \
 'x\xda\x01\x97\x08h\xf7\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
