@@ -18,43 +18,51 @@
 
 # Embedded icon is taken from www.openclipart.org (public domain)
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
     global Image, ImageOps, imtools
-    import Image, ImageOps
+    import Image
+    import ImageOps
     from lib import imtools
 
-def posterize(image,bits,amount=100):
+
+def posterize(image, bits, amount=100):
     """Apply a filter
     - amount: 0-1"""
     image = imtools.convert_safe_mode(image)
     posterized = imtools.remove_alpha(image)
-    posterized   = ImageOps.posterize(posterized, bits)
+    posterized = ImageOps.posterize(posterized, bits)
     if imtools.has_alpha(image):
-        imtools.put_alpha(posterized, image.split()[-1])
+        imtools.put_alpha(posterized, imtools.get_alpha(image))
     if amount < 100:
-        return imtools.blend(image, posterized, amount/100.0)
+        return imtools.blend(image, posterized, amount / 100.0)
     return posterized
 
 #---Phatch
+
+
 class Action(models.Action):
     """"""
 
-    label       = _t('Posterize')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(posterize)
-    version     = '0.1'
-    tags        = [_t('color')]
-    __doc__     = _t('Reduce the number of bits of color channel')
+    label = _t('Posterize')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(posterize)
+    version = '0.1'
+    tags = [_t('color')]
+    __doc__ = _t('Reduce the number of bits of color channel')
 
-    def interface(self,fields):
-        fields[_t('Bits')]   = self.SliderField(1,0,8)
-        fields[_t('Amount')] = self.SliderField(100,1,100)
+    def interface(self, fields):
+        fields[_t('Bits')] = self.SliderField(1, 0, 8)
+        fields[_t('Amount')] = self.SliderField(100, 1, 100)
 
     icon = \
 'x\xda\x01\x10\t\xef\xf6\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
