@@ -18,42 +18,51 @@
 
 # Embedded icon is taken from www.openclipart.org (public domain)
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
     global Image, ImageFilter, imtools
-    import Image, ImageFilter
+    import Image
+    import ImageFilter
     from lib import imtools
 
-def rnk(image,radius,rank=50,amount=100):
+
+def rnk(image, radius, rank=50, amount=100):
     """Apply a filter
     - amount: 0-1"""
-    rank     /= 100.0
-    r       = int((radius*radius-1)*rank)
-    ranked  = image.filter(ImageFilter.RankFilter(radius,r))
+    rank /= 100.0
+    r = int((radius * radius - 1) * rank)
+    image = imtools.convert_safe_mode(image)
+    ranked = image.filter(ImageFilter.RankFilter(radius, r))
     if amount < 100:
-        return imtools.blend(image, ranked, amount/100)
+        return imtools.blend(image, ranked, amount / 100)
     return ranked
 
 #---Phatch
+
+
 class Action(models.Action):
     """"""
 
-    label       = _t('Rank')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(rnk)
-    version     = '0.1'
-    tags        = [_t('filter')]
-    __doc__     = _t("Copies the rank'th pixel value")
+    label = _t('Rank')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(rnk)
+    version = '0.1'
+    tags = [_t('filter')]
+    __doc__ = _t("Copies the rank'th pixel value")
 
-    def interface(self,fields):
+    def interface(self, fields):
         fields[_t('Radius')] = self.RankSizeField(self.RANK_SIZES[0])
-        fields[_t('Rank')]   = self.SliderField(50,0,100)
-        fields[_t('Amount')] = self.SliderField(100,1,100)
+        fields[_t('Rank')] = self.SliderField(50, 0, 100)
+        fields[_t('Amount')] = self.SliderField(100, 1, 100)
 
     icon = \
 'x\xda\x01v\x0c\x89\xf3\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
