@@ -18,45 +18,50 @@
 
 # Embedded icon is designed by Igor Kekeljevic (http://www.admiror-ns.co.yu).
 
+# Follows PEP8
+
 from core import ct, models
 from lib.reverse_translation import _t
 
 #no need to lazily import these as they are always imported
-import os, shutil
+import os
+import shutil
+
 
 class Action(models.Action):
     """Defined variables: <filename> <type> <folder> <width> <height>"""
 
-    label       = _t('Rename')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    version     = '0.1'
-    tags        = [_t('file')]
-    __doc__     = _t('Rename the original image')
-    valid_last  = True
+    label = _t('Rename')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    version = '0.1'
+    tags = [_t('file')]
+    __doc__ = _t('Rename the original image')
+    valid_last = True
 
-    def interface(self,fields):
-        fields[_t('File Name')]    = self.FileNameField(choices=self.FILENAMES)
-        fields[_t('In')]           = self.FolderField(self.DEFAULT_FOLDER,
+    def interface(self, fields):
+        fields[_t('File Name')] = self.FileNameField(choices=self.FILENAMES)
+        fields[_t('In')] = self.FolderField(self.DEFAULT_FOLDER,
                                         choices=self.FOLDERS)
 
-    def apply(self,photo,setting,cache):
+    def apply(self, photo, setting, cache):
         #get info
-        info                    = photo.info
+        info = photo.info
         #get file values
-        folder, filename, typ   = self.is_done_info(info)
-        if setting('overwrite_existing_images') or not os.path.exists(filename):
+        folder, filename, typ = self.is_done_info(info)
+        if setting('overwrite_existing_images') \
+                or not os.path.exists(filename):
             #ensure folder
             filename = self.ensure_path_or_desktop(folder, photo, filename)
             #do it
-            os.rename(info['path'],filename)
+            os.rename(info['path'], filename)
         return photo
 
-    def is_done_info(self,info):
-        folder      = self.get_field('In',info)
-        filename    = self.get_field('File Name',info)
-        typ         = info['type']
-        return folder, os.path.join(folder,'%s.%s'%(filename,typ)), typ
+    def is_done_info(self, info):
+        folder = self.get_field('In', info)
+        filename = self.get_field('File Name', info)
+        typ = info['type']
+        return folder, os.path.join(folder, '%s.%s' % (filename, typ)), typ
 
     def is_overwrite_existing_images_forced(self):
         """Force overwrite when using default values."""
