@@ -12,7 +12,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
@@ -20,71 +20,80 @@
 
 # Embedded icon is designed by Igor Kekeljevic (http://www.admiror-ns.co.yu).
 
+# Follows PEP8
+
 # Always import this:
 from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
-    global Image, ImageChops, ImageDraw
-    import Image, ImageChops, ImageDraw
+    global Image, ImageChops, ImageDraw, imtools
+    import Image
+    import ImageChops
+    import ImageDraw
+    from lib import imtools
 
 
 # Declare constants here
 
-CROSS                   = _t('Cross')
-ROUNDED                 = _t('Rounded')
-SQUARE                  = _t('Square')
+CROSS = _t('Cross')
+ROUNDED = _t('Rounded')
+SQUARE = _t('Square')
 
-CORNERS                 = [ROUNDED,SQUARE,CROSS]
-CORNER_ID               = 'rounded_corner_r%d_f%d'
-CROSS_POS               = (CROSS,CROSS,CROSS,CROSS)
-ROUNDED_POS             = (ROUNDED,ROUNDED,ROUNDED,ROUNDED)
-ROUNDED_RECTANGLE_ID    = 'rounded_rectangle_r%d_f%d_s%s_p%s'
+CORNERS = [ROUNDED, SQUARE, CROSS]
+CORNER_ID = 'rounded_corner_r%d_f%d'
+CROSS_POS = (CROSS, CROSS, CROSS, CROSS)
+ROUNDED_POS = (ROUNDED, ROUNDED, ROUNDED, ROUNDED)
+ROUNDED_RECTANGLE_ID = 'rounded_rectangle_r%d_f%d_s%s_p%s'
 
-def round_image(image,cache={},round_all=True,rounding_type=None,radius=100,opacity=255,pos=ROUNDED_POS,
-        back_color='#FFFFFF'):
+
+def round_image(image, cache={}, round_all=True, rounding_type=None,
+        radius=100, opacity=255, pos=ROUNDED_POS, back_color='#FFFFFF'):
     if image.mode != 'RGBA':
         image = image.convert('RGBA')
 
     if round_all:
         pos = 4 * (rounding_type, )
 
-    mask = create_rounded_rectangle(image.size,cache,radius,opacity,pos)
+    mask = create_rounded_rectangle(image.size, cache, radius, opacity, pos)
 
-    image.paste(Image.new('RGB',image.size,back_color),(0,0),
+    imtools.paste(image, Image.new('RGB', image.size, back_color), (0, 0),
         ImageChops.invert(mask))
     image.putalpha(mask)
     return image
 
-def create_rounded_rectangle(size=(600,400),cache={},radius=100,opacity=255,
-        pos=ROUNDED_POS):
+
+def create_rounded_rectangle(size=(600, 400), cache={}, radius=100,
+        opacity=255, pos=ROUNDED_POS):
     #rounded_rectangle
-    im_x, im_y  = size
-    rounded_rectangle_id    = ROUNDED_RECTANGLE_ID%(radius,opacity,size,pos)
-    if cache.has_key(rounded_rectangle_id):
+    im_x, im_y = size
+    rounded_rectangle_id = ROUNDED_RECTANGLE_ID % (radius, opacity, size, pos)
+    if rounded_rectangle_id in cache:
         return cache[rounded_rectangle_id]
     else:
         #cross
-        cross_id    = ROUNDED_RECTANGLE_ID%(radius,opacity,size,CROSS_POS)
-        if cache.has_key(cross_id):
-            cross   = cache[cross_id]
+        cross_id = ROUNDED_RECTANGLE_ID % (radius, opacity, size, CROSS_POS)
+        if cross_id in cache:
+            cross = cache[cross_id]
         else:
-            cross   = cache[cross_id]   = Image.new('L',size,0)
-            draw    = ImageDraw.Draw(cross)
-            draw.rectangle((radius,0,im_x-radius,im_y),fill=opacity)
-            draw.rectangle((0,radius,im_x,im_y-radius),fill=opacity)
-        if pos==CROSS_POS: 
+            cross = cache[cross_id] = Image.new('L', size, 0)
+            draw = ImageDraw.Draw(cross)
+            draw.rectangle((radius, 0, im_x - radius, im_y), fill=opacity)
+            draw.rectangle((0, radius, im_x, im_y - radius), fill=opacity)
+        if pos == CROSS_POS:
             return cross
         #corner
-        corner_id   = CORNER_ID%(radius,opacity)
-        if cache.has_key(corner_id):
-            corner  = cache[corner_id]
+        corner_id = CORNER_ID % (radius, opacity)
+        if corner_id in cache:
+            corner = cache[corner_id]
         else:
-            corner  = cache[corner_id] = create_corner(radius,opacity)
+            corner = cache[corner_id] = create_corner(radius, opacity)
         #rounded rectangle
-        rectangle   = Image.new('L',(radius,radius),255)
-        rounded_rectangle   = cross.copy()
+        rectangle = Image.new('L', (radius, radius), 255)
+        rounded_rectangle = cross.copy()
         for index, angle in enumerate(pos):
             if angle == CROSS:
                 continue
@@ -92,56 +101,57 @@ def create_rounded_rectangle(size=(600,400),cache={},radius=100,opacity=255,
                 element = corner
             else:
                 element = rectangle
-            if index%2:
-                x       = im_x-radius
+            if index % 2:
+                x = im_x - radius
                 element = element.transpose(Image.FLIP_LEFT_RIGHT)
             else:
-                x       = 0
+                x = 0
             if index < 2:
-                y       = 0
+                y = 0
             else:
-                y       = im_y-radius
+                y = im_y - radius
                 element = element.transpose(Image.FLIP_TOP_BOTTOM)
-            rounded_rectangle.paste(element,(x,y))
+            imtools.paste(rounded_rectangle, element, (x, y))
         cache[rounded_rectangle_id] = rounded_rectangle
         return rounded_rectangle
 
-def create_corner(radius=100,opacity=255,factor=2):
-    corner  = Image.new('L',(factor*radius,factor*radius),0)
-    draw    = ImageDraw.Draw(corner)
-    draw.pieslice((0,0,2*factor*radius,2*factor*radius),180,270,fill=opacity)
-    corner  = corner.resize((radius,radius),Image.ANTIALIAS)
+
+def create_corner(radius=100, opacity=255, factor=2):
+    corner = Image.new('L', (factor * radius, factor * radius), 0)
+    draw = ImageDraw.Draw(corner)
+    draw.pieslice((0, 0, 2 * factor * radius, 2 * factor * radius),
+        180, 270, fill=opacity)
+    corner = corner.resize((radius, radius), Image.ANTIALIAS)
     return corner
 
 #---Phatch
+
+
 class Action(models.Action):
-    
-    label       = _t('Round')
-    author      = 'Stani'
-    cache       = True
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(round_image)
-    version     = '0.1'
-    tags        = [_t('default'), _t('filter')]
-    __doc__     = _t('Rounded or crossed corners')
-    
-    def interface(self,fields):
-        fields[_t('Radius')]                = self.PixelField('2%',
-                                                choices=self.SMALL_PIXELS)
-        fields[_t('Same Method for All Corners')]             = self.BooleanField(True)
-        fields[_t('Method')]                = self.ChoiceField(CORNERS[0],
-                                                CORNERS)
-        fields[_t('Top Left Corner')]       = self.ChoiceField(CORNERS[0],
-                                                CORNERS)
-        fields[_t('Top Right Corner')]      = self.ChoiceField(CORNERS[0],
-                                                CORNERS)
-        fields[_t('Bottom Left Corner')]    = self.ChoiceField(CORNERS[0],
-                                                CORNERS)
-        fields[_t('Bottom Right Corner')]   = self.ChoiceField(CORNERS[0],
-                                                CORNERS)
-        fields[_t('Background Color')]      = self.ColorField('#FFFFFF')
-        fields[_t('Opacity')]               = self.SliderField(100,1,100)
+
+    label = _t('Round')
+    author = 'Stani'
+    cache = True
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(round_image)
+    version = '0.1'
+    tags = [_t('default'), _t('filter')]
+    __doc__ = _t('Rounded or crossed corners')
+
+    def interface(self, fields):
+        fields[_t('Radius')] = self.PixelField('2%',
+            choices=self.SMALL_PIXELS)
+        fields[_t('Same Method for All Corners')] = self.BooleanField(True)
+        fields[_t('Method')] = self.ChoiceField(CORNERS[0], CORNERS)
+        fields[_t('Top Left Corner')] = self.ChoiceField(CORNERS[0], CORNERS)
+        fields[_t('Top Right Corner')] = self.ChoiceField(CORNERS[0], CORNERS)
+        fields[_t('Bottom Left Corner')] = self.ChoiceField(
+            CORNERS[0], CORNERS)
+        fields[_t('Bottom Right Corner')] = self.ChoiceField(
+            CORNERS[0], CORNERS)
+        fields[_t('Background Color')] = self.ColorField('#FFFFFF')
+        fields[_t('Opacity')] = self.SliderField(100, 1, 100)
 
     def get_relevant_field_labels(self):
         """If this method is present, Phatch will only show relevant
@@ -156,40 +166,39 @@ class Action(models.Action):
             the same order as defined in the interface method.
         """
         relevant = ['Radius', 'Same Method for All Corners']
-        if self.get_field_string('Same Method for All Corners') in ('yes','true'):
+        if self.get_field_string('Same Method for All Corners') \
+                in ('yes', 'true'):
             relevant.append('Method')
         else:
-            relevant.extend(['Top Left Corner', 'Top Right Corner', 
+            relevant.extend(['Top Left Corner', 'Top Right Corner',
                 'Bottom Left Corner', 'Bottom Right Corner'])
-        relevant.extend(['Background Color','Opacity'])
+        relevant.extend(['Background Color', 'Opacity'])
         return relevant
 
-    def values(self,info):
+    def values(self, info):
         #get info (always get this)
-        width, height   = info['size']
-        dpi             = info['dpi']
+        width, height = info['size']
+        dpi = info['dpi']
 
-        round_all       = self.get_field('Same Method for All Corners', info)
-        rounding_type   = self.get_field('Method', info)
+        round_all = self.get_field('Same Method for All Corners', info)
+        rounding_type = self.get_field('Method', info)
+
+        average = (width + height / 2)
+        radius = self.get_field_size('Radius', info, average, dpi)
+        opacity = int((self.get_field('Opacity', info) / 100.0) * 255)
+        pos = (
+            self.get_field('Top Left Corner', info),
+            self.get_field('Top Right Corner', info),
+            self.get_field('Bottom Left Corner', info),
+            self.get_field('Bottom Right Corner', info))
 
-        average         = (width+height/2)
-        radius          = self.get_field_size('Radius',info,average,dpi)
-        opacity         = int((self.get_field('Opacity',info)/100.0)*255)
-        pos             = (
-                            self.get_field('Top Left Corner',info),
-                            self.get_field('Top Right Corner',info),
-                            self.get_field('Bottom Left Corner',info),
-                            self.get_field('Bottom Right Corner',info),
-        )
-        
         return {
-            'round_all'     : round_all,
-            'rounding_type' : rounding_type,
-            'radius'        : radius,
-            'opacity'       : opacity,
-            'pos'           : pos,
-            'back_color'    : self.get_field('Background Color',info)
-        }
+            'round_all': round_all,
+            'rounding_type': rounding_type,
+            'radius': radius,
+            'opacity': opacity,
+            'pos': pos,
+            'back_color': self.get_field('Background Color', info)}
 
     icon = \
 'x\xda\x01\x00\x0e\xff\xf1\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\
