@@ -65,9 +65,9 @@ class Action(models.Action):
         fields[_t('PNG Optimize')] = self.BooleanField(False)
         fields[_t('JPEG Quality')] = self.SliderField(85, 1, 100)
         fields[_t('JPEG Size Maximum')] = \
-            self.FileSizeField('0kb', choices=SIZES)
+            self.FileSizeField('0 kb', choices=SIZES)
         fields[_t('JPEG Size Tolerance')] = \
-            self.FileSizeField('5%', choices=TOLERANCES)
+            self.FileSizeField('10 kb', choices=TOLERANCES)
         fields[_t('TIFF Compression')] = \
             self.TiffCompressionField(self.COMPRESSION)
         fields[_t('Metadata')] = self.BooleanField(True)
@@ -129,7 +129,7 @@ class Action(models.Action):
         save_metadata = self.get_field('Metadata', info)
         #filename
         filename = self.ensure_path_or_desktop(folder, photo, filename,
-            desktop = setting('desktop'))
+            desktop=setting('desktop'))
         #construct options
         options = {'dpi': (dpi, dpi)}
         if format == 'PNG':
@@ -145,9 +145,9 @@ class Action(models.Action):
                 #check necessity
                 # only if file is bigger than desired size
                 size = get_size(im, 'JPEG', quality=quality)
-                if size > jpg_size+delta:
-                    quality = get_quality(im, size = jpg_size,
-                        up = quality, format='JPEG', delta=delta)
+                if size > jpg_size + delta:
+                    quality = get_quality(im, size=jpg_size,
+                        up=quality, format='JPEG', delta=delta)
             options['quality'] = quality
         elif format == 'TIFF':
             compression = self.get_field('TIFF Compression', info)
@@ -169,7 +169,7 @@ class Action(models.Action):
         folder = self.get_field('In', info)
         filename = self.get_field('File Name', info)
         typ = self.get_field('As', info)
-        return folder, os.path.join(folder, '%s.%s'%(filename, typ)), typ
+        return folder, os.path.join(folder, '%s.%s' % (filename, typ)), typ
 
     def is_overwrite_existing_images_forced(self):
         return (self.get_field_string('In') == self.FOLDER) and\
