@@ -18,41 +18,49 @@
 
 # Embedded icon is designed by Igor Kekeljevic (http://www.admiror-ns.co.yu)
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
     global Image, ImageOps, imtools
-    import Image, ImageOps
+    import Image
+    import ImageOps
     from lib import imtools
 
-def solarize(image,treshold,amount=100):
+
+def solarize(image, treshold, amount=100):
     """Apply a filter
     - amount: 0-1"""
     image = imtools.convert_safe_mode(image)
-    solarized  = image.convert('RGB')
-    solarized   = ImageOps.solarize(solarized, treshold)
+    solarized = image.convert('RGB')
+    solarized = ImageOps.solarize(solarized, treshold)
     if imtools.has_alpha(image):
-        imtools.put_alpha(solarized, image.split()[-1])
+        imtools.put_alpha(solarized, imtools.get_alpha(image))
     if amount < 100:
-        return imtools.blend(image, solarized, amount/100.0)
+        return imtools.blend(image, solarized, amount / 100.0)
     return solarized
 
 #---Phatch
-class Action(models.Action):
-    label       = _t('Solarize')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(solarize)
-    version     = '0.1'
-    tags        = [_t('filter')]
-    __doc__     = _t('Invert all pixel values above threshold')
 
-    def interface(self,fields):
-        fields[_t('Treshold')]   = self.SliderField(128,0,255)
-        fields[_t('Amount')] = self.SliderField(100,1,100)
+
+class Action(models.Action):
+    label = _t('Solarize')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(solarize)
+    version = '0.1'
+    tags = [_t('filter')]
+    __doc__ = _t('Invert all pixel values above threshold')
+
+    def interface(self, fields):
+        fields[_t('Treshold')] = self.SliderField(128, 0, 255)
+        fields[_t('Amount')] = self.SliderField(100, 1, 100)
 
     icon = \
 'x\xda\x01\xd3\x0b,\xf4\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
