@@ -16,21 +16,26 @@
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
 # Phatch recommends SPE (http://pythonide.stani.be) for editing python.
+
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 from lib.imtools import has_transparency
 
 OTHER_IMAGE = _t('Image')
-FOLDER      = _t('Folder')
-FILL_TYPES  = (OTHER_IMAGE, FOLDER)
+FOLDER = _t('Folder')
+FILL_TYPES = (OTHER_IMAGE, FOLDER)
+
 
 def init():
     #lazily import
     global _tamogen
     import other.tamogen as _tamogen
-    _tamogen.OTHER_IMAGE    = OTHER_IMAGE
-    _tamogen.FOLDER         = FOLDER
-    _tamogen.FILL_TYPES     = FILL_TYPES
+    _tamogen.OTHER_IMAGE = OTHER_IMAGE
+    _tamogen.FOLDER = FOLDER
+    _tamogen.FILL_TYPES = FILL_TYPES
+
 
 def mosaic(image, fill_type, fill_image, fill_folder, columns, rows,
         canvas_width, canvas_height):
@@ -41,37 +46,37 @@ def mosaic(image, fill_type, fill_image, fill_folder, columns, rows,
     return _tamogen.mosaic(image, fill_type, columns, rows,
         canvas_width, canvas_height, fill_image, fill_folder)
 
-class Action(models.Action):
-    label       = _t('Tamogen')
-    author      = 'Juho Vepsäläinen'
-    email       = 'bebraw@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(mosaic)
-    version     = '0.1'
-    tags        = [_t('filter')]
-    __doc__     = _t('Tone altering mosaic generator')
 
-    def interface(self,fields):
+class Action(models.Action):
+    label = _t('Tamogen')
+    author = 'Juho Vepsäläinen'
+    email = 'bebraw@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(mosaic)
+    version = '0.1'
+    tags = [_t('filter')]
+    __doc__ = _t('Tone altering mosaic generator')
+
+    def interface(self, fields):
         fields[_t('Fill Type')] = self.ChoiceField(
             FILL_TYPES[0], choices=FILL_TYPES)
         fields[_t('Fill Image')] = self.ReadFileField('<path>')
         fields[_t('Fill Folder')] = self.FolderField(
             '<folder>/<subfolder>', choices=self.FOLDERS)
-        fields[_t('Rows')]   = self.PositiveNonZeroIntegerField(10)
+        fields[_t('Rows')] = self.PositiveNonZeroIntegerField(10)
         fields[_t('Columns')] = self.PositiveNonZeroIntegerField(10)
         fields[_t('Canvas Width')] = self.PixelField('100%',
             choices=self.PIXELS)
         fields[_t('Canvas Height')] = self.PixelField('100%',
             choices=self.PIXELS)
 
-    def values(self,info):
+    def values(self, info):
         #pixel fields
-        width, height   = info['size']
+        width, height = info['size']
         # pass absolute reference for relative pixel values such as %
-        return super(Action,self).values(info,pixel_fields={
-            'Canvas Width' : width,
-            'Canvas Height' : height,
-        })
+        return super(Action, self).values(info, pixel_fields={
+            'Canvas Width': width,
+            'Canvas Height': height})
 
     def get_relevant_field_labels(self):
         relevant = ['Fill Type', ]
