@@ -10,7 +10,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
@@ -18,38 +18,43 @@
 
 # Embedded icon is taken from www.openclipart.org (public domain)
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 
 def init():
     global Image, ImageDraw, ImageFont
-    import Image, ImageDraw, ImageFont
+    import Image
+    import ImageDraw
+    import ImageFont
     global calculate_location, convert_safe_mode
     from lib.imtools import calculate_location, convert_safe_mode
 
+
 def draw_text(image, text, horizontal_offset, vertical_offset,
               horizontal_justification, vertical_justification, size,
-              color='#FFFFFF',orientation=None, font=None):
+              color='#FFFFFF', orientation=None, font=None):
     """Draws text on an image."""
     image = convert_safe_mode(image)
     if orientation:
         orientation = getattr(Image, orientation)
 
-    draw        = ImageDraw.Draw(image)
+    draw = ImageDraw.Draw(image)
     if font.strip():
-        font    = ImageFont.truetype(font,size)
+        font = ImageFont.truetype(font, size)
     else:
-        font    = ImageFont.load_default()
-        text    = text.encode('ascii','replace')
+        font = ImageFont.load_default()
+        text = text.encode('ascii', 'replace')
 
     if orientation:
-        font    = ImageFont.TransposedFont(font, orientation)
+        font = ImageFont.TransposedFont(font, orientation)
 
-    location    = calculate_location(
+    location = calculate_location(
         horizontal_offset, vertical_offset,
         horizontal_justification, vertical_justification,
-        image.size, draw.textsize(text,font=font))
+        image.size, draw.textsize(text, font=font))
 
     # draw
     draw.text(location, text, font=font, fill=color)
@@ -57,41 +62,40 @@ def draw_text(image, text, horizontal_offset, vertical_offset,
     # composite the watermark with the layer
     return image
 
-class Action(models.OffsetMixin,models.Action):
+
+class Action(models.OffsetMixin, models.Action):
     """Draws text on an image."""
-    
-    label       = _t('Text')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(draw_text)
-    version     = '0.1'
-    tags        = [_t('default'), _t('filter')]
-    __doc__     = _t('Write text at a given position')
+
+    label = _t('Text')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(draw_text)
+    version = '0.1'
+    tags = [_t('default'), _t('filter')]
+    __doc__ = _t('Write text at a given position')
 
     def interface(self, fields):
-        fields[_t('Text')]              = self.CharField( 
+        fields[_t('Text')] = self.CharField(
             choices=self.STAMPS)
-        fields[_t('Font')]          = self.FontFileField('Free Sans')
-        fields[_t('Size')]          = self.PixelField('5%',
+        fields[_t('Font')] = self.FontFileField('Free Sans')
+        fields[_t('Size')] = self.PixelField('5%',
                                             choices=self.SMALL_PIXELS)
-        fields[_t('Color')]         = self.ColorField('#000000')
+        fields[_t('Color')] = self.ColorField('#000000')
 
         super(Action, self).interface(fields)
 
     def get_relevant_field_labels(self):
-        return ['Text','Font','Size','Color']+\
-            super(Action,self).get_relevant_field_labels()
+        return ['Text', 'Font', 'Size', 'Color'] + \
+            super(Action, self).get_relevant_field_labels()
 
     def values(self, info, pixel_fields={}):
-        x, y        = info['size']
-        pixel_fields.update({
-                'Size'              : (x+y)/2,
-            })
+        x, y = info['size']
+        pixel_fields.update({'Size': (x + y) / 2})
         return super(Action, self).values(info,
             pixel_fields=pixel_fields)
-            
-    icon  = \
+
+    icon = \
 'x\xda\x01\xcc\x043\xfb\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
 \x00\x000\x08\x06\x00\x00\x00W\x02\xf9\x87\x00\x00\x00\x04sBIT\x08\x08\x08\
 \x08|\x08d\x88\x00\x00\x04\x83IDATh\x81\xed\x97]h\x1cU\x14\xc7\x7f\xe7n>6\
