@@ -1,7 +1,7 @@
 # Phatch - Photo Batch Processor
-# Copyright (C) 2007-2009 www.stani.be
+# Copyright (C) 2009 www.stani.be
 #
-# This program is free software:you can redistribute it and/or modify
+# This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
-#
+
 # Phatch recommends SPE (http://pythonide.stani.be) for editing python files.
 
 # Follows PEP8
@@ -31,7 +31,6 @@ import glob
 import operator
 import os
 import pprint
-import shutil
 import string
 import time
 import traceback
@@ -49,29 +48,28 @@ from lib.unicoding import ensure_unicode, exception_to_unicode, ENCODING
 
 import ct
 import pil
-from models import Action
 from message import send
-from settings import create_settings
 
 #---constants
-PROGRESS_MESSAGE = 'In: %s\nFile'%('X'*40)
-SEE_LOG = _('See "%s" for more details.')%_('Show Log')
+PROGRESS_MESSAGE = 'In: %s%s\nFile' % (' ' * 100, '.')
+SEE_LOG = _('See "%s" for more details.') % _('Show Log')
 TREE_HEADERS = ['filename', 'type', 'folder', 'subfolder', 'root',
     'foldername']
 TREE_VARS = set(TREE_HEADERS).union(pil.BASE_VARS)
 TREE_HEADERS += ['index', 'folderindex']
-ERROR_INCOMPATIBLE_ACTIONLIST=\
+ERROR_INCOMPATIBLE_ACTIONLIST = \
 _('Sorry, the action list seems incompatible with %(name)s %(version)s.')
 
 ERROR_UNSAFE_ACTIONLIST_INTRO = _('This action list is unsafe:')
 ERROR_UNSAFE_ACTIONLIST_DISABLE_SAFE = \
 _('Disable Safe Mode in the Tools menu if you trust this action list.')
 ERROR_UNSAFE_ACTIONLIST_ACCEPT = \
-_("Never run action lists from untrusted sources.")+' '+\
+_("Never run action lists from untrusted sources.") + ' ' +\
 _("Please check if this action list doesn't contain harmful code.")
 
 #---classes
 
+
 class PathError(Exception):
 
     def __init__(self, filename):
@@ -83,10 +81,11 @@ class PathError(Exception):
         self.filename = filename
 
     def __str__(self):
-        return _('"%s" is not a valid path.')%self.filename
+        return _('"%s" is not a valid path.') % self.filename
 
 #---init/exit
 
+
 def init():
     """Verify user paths and import all actions. This function should
     be called at the start."""
@@ -97,6 +96,7 @@ def init():
 
 #---error logs
 
+
 def init_error_log_file():
     """Reset ERROR_LOG_COUNTER and create the ERROR_LOG_FILE."""
     global ERROR_LOG_FILE, ERROR_LOG_COUNTER
@@ -125,7 +125,7 @@ def log_error(message, filename, action=None, label='Error'):
         details += os.linesep + 'Action:' + \
                     pprint.pformat(action.dump())
     ERROR_LOG_FILE.write(os.linesep.join([
-        u'%s %d:%s'%(label, ERROR_LOG_COUNTER, message),
+        u'%s %d:%s' % (label, ERROR_LOG_COUNTER, message),
         details,
         os.linesep,
     ]))
@@ -136,13 +136,14 @@ def log_error(message, filename, action=None, label='Error'):
         traceback.print_exc(file=stringio)
         traceb = stringio.read()
         ERROR_LOG_FILE.write(unicode(traceb, ENCODING, 'replace'))
-    ERROR_LOG_FILE.write('*'+os.linesep)
+    ERROR_LOG_FILE.write('*' + os.linesep)
     ERROR_LOG_FILE.flush()
     ERROR_LOG_COUNTER += 1
     return details
 
 #---collect vars
 
+
 def get_vars(actions):
     """Extract all used variables from actions.
 
@@ -175,18 +176,19 @@ def assert_safe(actions):
                 field.assert_safe(label, test_info)
             except Exception, details:
                 warning_action += '  %s: %s\n'\
-                    %(label, exception_to_unicode(details))
+                    % (label, exception_to_unicode(details))
         if warning_action:
-            warning += '%s %s:\n%s'%(_(action.label), _('Action'),
+            warning += '%s %s:\n%s' % (_(action.label), _('Action'),
                 warning_action)
     if warning:
         warning += '\n'
     if geek:
-        warning += '%s\n'%(_('Geek actions are not allowed in safe mode.'))
+        warning += '%s\n' % (_('Geek actions are not allowed in safe mode.'))
     return warning
 
 #---collect image files
 
+
 def filter_image_infos(folder, extensions, files, root, info_file):
     """Filter image files by extension and verify if they are files. It
     returns a list of info dictionaries which are generated by
@@ -255,8 +257,8 @@ def get_image_infos_from_folder(folder, info_file, extensions, recursive):
 
     .. see also:: :func:`filter_image_infos`
     """
-    source_parent = folder #do not change (independent of recursion!)
-    #root = os.path.dirname(folder) #do not change (independent of recursion!)
+    source_parent = folder  # do not change (independent of recursion!)
+    # root = os.path.dirname(folder) #do not change (independent of recursion!)
     if recursive:
         image_infos = []
         for folder, dirs, files in os.walk(folder):
@@ -296,14 +298,15 @@ def get_image_infos(paths, info_file, extensions, recursive):
                 path, info_file, extensions, recursive))
         else:
             #not a file or folder?! probably does not exist
-            send.frame_show_error('Sorry, "%s" is not a valid path.'%\
-                    ensure_unicode(path))
+            send.frame_show_error('Sorry, "%s" is not a valid path.' \
+                % ensure_unicode(path))
             return []
     image_infos.sort(key=operator.itemgetter('path'))
     return image_infos
 
 #---check
 
+
 def check_actionlist_file_only(actions):
     """Check whether the action list only exist of file operations
     (such as copy, rename, ...)
@@ -359,21 +362,21 @@ def check_actionlist(actions, settings):
     """
     #Check if there is something to do
     if actions == []:
-        send.frame_show_error('%s %s'%(_('Nothing to do.'),
+        send.frame_show_error('%s %s' % (_('Nothing to do.'),
             _('The action list is empty.')))
         return None
     #Check if the actionlist is safe
     if formField.get_safe():
         warnings = assert_safe(actions)
         if warnings:
-            send.frame_show_error('%s\n\n%s\n%s'%(
+            send.frame_show_error('%s\n\n%s\n%s' % (
                 ERROR_UNSAFE_ACTIONLIST_INTRO, warnings,
                 ERROR_UNSAFE_ACTIONLIST_DISABLE_SAFE))
             return None
     #Skip disabled actions
     actions = [action for action in actions if action.is_enabled()]
     if actions == []:
-        send.frame_show_error('%s %s'%(_('Nothing to do.'),
+        send.frame_show_error('%s %s' % (_('Nothing to do.'),
             _('There is no action enabled.')))
         return None
     #Check if there is a save statement
@@ -401,9 +404,9 @@ def verify_images(image_infos, repeat):
     :returns: None for error, valid image info dictionaries otherwise
     """
     #show dialog
-    send.frame_show_progress(title = _("Checking images"),
-        parent_max = len(image_infos),
-        message = PROGRESS_MESSAGE)
+    send.frame_show_progress(title=_("Checking images"),
+        parent_max=len(image_infos),
+        message=PROGRESS_MESSAGE)
     #verify files
     valid = []
     invalid = []
@@ -418,9 +421,9 @@ def verify_images(image_infos, repeat):
     if invalid:
         result = {}
         send.frame_show_files_message(result,
-            message = _('Phatch can not handle %d image(s):')%len(invalid),
-            title = ct.FRAME_TITLE%('', _('Invalid images')),
-            files = invalid)
+            message=_('Phatch can not handle %d image(s):') % len(invalid),
+            title=ct.FRAME_TITLE % ('', _('Invalid images')),
+            files=invalid)
         if result['cancel']:
             return
     #Display an error when no files are left
@@ -429,18 +432,19 @@ def verify_images(image_infos, repeat):
         return
     #number valid items
     for index, image_info in enumerate(valid):
-        image_info['index'] = index*repeat
+        image_info['index'] = index * repeat
     #show valid images to the user in tree structure
     result = {}
     send.frame_show_image_tree(result, valid,
-        widths = (200, 40, 200, 200, 200, 200, 60),
-        headers = TREE_HEADERS,
-        ok_label = _('C&ontinue'), buttons=True)
+        widths=(200, 40, 200, 200, 200, 200, 60),
+        headers=TREE_HEADERS,
+        ok_label=_('C&ontinue'), buttons=True)
     if result['answer']:
         return valid
 
 #---get
 
+
 def get_paths_and_settings(paths, settings, drop=False):
     """Ask the user for paths and settings. In the GUI this shows
     the execute dialog box.
@@ -493,7 +497,7 @@ def get_photo(info_file, info_not_file, result):
     except Exception, details:
         reason = exception_to_unicode(details)
         #log error details
-        message = u'%s: %s:\n%s'%(_('Unable to open file'),
+        message = u'%s: %s:\n%s' % (_('Unable to open file'),
             info_file['path'], reason)
     ignore = False
     action = None
@@ -503,6 +507,7 @@ def get_photo(info_file, info_not_file, result):
 
 #---apply
 
+
 def process_error(photo, message, image_file, action, result, ignore):
     """Logs error to file with :func:`log_error` and show dialog box
     allowing the user to skip, abort or ignore.
@@ -577,9 +582,9 @@ def init_actions(actions):
             action.init()
         except Exception, details:
             reason = exception_to_unicode(details)
-            message = u'%s\n\n%s'%(
-                _("Can not apply action %(a)s:")%\
-                    {'a': _(action.label)}, reason)
+            message = u'%s\n\n%s' % (
+                _("Can not apply action %(a)s:") \
+                % {'a': _(action.label)}, reason)
             send.frame_show_error(message)
             return False
     return True
@@ -616,9 +621,9 @@ def apply_action_to_photo(action, photo, read_only_settings, cache,
         flush_log(photo, image_file, action)
         folder, image = os.path.split(ensure_unicode(image_file))
         reason = exception_to_unicode(details)
-        message = u'%s\n%s\n\n%s'%(
+        message = u'%s\n%s\n\n%s' % (
             _("Can not apply action %(a)s on image '%(i)s' in folder:")\
-                %{'a': _(action.label), 'i': image},
+                % {'a': _(action.label), 'i': image},
             folder,
             reason,
         )
@@ -647,47 +652,47 @@ def apply_actions_to_photos(actions, settings, paths=None, drop=False,
 
     :type drop: bool
     """
-    #Start log file
+    # Start log file
     init_error_log_file()
 
-    #Check action list
+    # Check action list
     actions = check_actionlist(actions, settings)
     if not actions:
         return
 
-    #Get paths (and update settings) -> show execute dialog
+    # Get paths (and update settings) -> show execute dialog
     paths = get_paths_and_settings(paths, settings, drop=drop)
     if not paths:
         return
 
-    #retrieve all necessary variables in one time
+    # retrieve all necessary variables in one time
     vars = set(pil.BASE_VARS).union(get_vars(actions))
     if settings['check_images_first']:
-        #we need some extra vars for the list control
+        # we need some extra vars for the list control
         vars = TREE_VARS.union(vars)
     vars_file, vars_not_file = metadata.InfoFile.split_vars(list(vars))
     info_file = metadata.InfoFile(vars=list(vars_file))
 
-    #Check if all files exist
-    #folderindex is set here in filter_image_infos
+    # Check if all files exist
+    # folderindex is set here in filter_image_infos
     image_infos = get_image_infos(paths, info_file,
         settings['extensions'], settings['recursive'])
     if not image_infos:
         return
 
-    #Check if all the images are valid
-    # -> show invalid to user
-    # -> show valid to user in tree dialog (optional)
+    # Check if all the images are valid
+    #  -> show invalid to user
+    #  -> show valid to user in tree dialog (optional)
     if settings['check_images_first']:
         image_infos = verify_images(image_infos, settings['repeat'])
         if not image_infos:
             return
 
-    #Initialize actions
+    # Initialize actions
     if not init_actions(actions):
         return
 
-    #Retrieve settings
+    # Retrieve settings
     skip_existing_images = not (settings['overwrite_existing_images'] or\
         settings['overwrite_existing_images_forced']) and\
         not settings['no_save']
@@ -696,33 +701,33 @@ def apply_actions_to_photos(actions, settings, paths=None, drop=False,
         'last_answer': None,
     }
 
-    #only keep static vars
+    # only keep static vars
     vars_not_file = pil.split_vars_static_dynamic(vars_not_file)[0]
 
-    #create parent info instance
-    # -> will be used by different files with the open method
+    # create parent info instance
+    #  -> will be used by different files with the open method
     info_not_file = metadata.InfoExtract(vars=vars_not_file)
 
-    #Execute action list
+    # Execute action list
     image_amount = len(image_infos)
-    actions_amount = len(actions) + 1 #open image is extra action
+    actions_amount = len(actions) + 1  # open image is extra action
     cache = {}
-    is_done = actions[-1].is_done #checking method for resuming
+    is_done = actions[-1].is_done  # checking method for resuming
     read_only_settings = ReadOnlyDict(settings)
 
-    #Start progress dialog
+    # Start progress dialog
     repeat = settings['repeat']
-    send.frame_show_progress(title = _("Executing action list"),
-        parent_max = image_amount*repeat,
-        child_max = actions_amount,
-        message = PROGRESS_MESSAGE)
+    send.frame_show_progress(title=_("Executing action list"),
+        parent_max=image_amount * repeat,
+        child_max=actions_amount,
+        message=PROGRESS_MESSAGE)
     report = []
     start = time.time()
     for image_index, image_info in enumerate(image_infos):
         statement = apply_actions_to_photo(actions, image_info, info_not_file,
             cache, read_only_settings, skip_existing_images, result, report,
             is_done, image_index, repeat)
-        #reraise statement
+        # reraise statement
         if statement == 'return':
             send.progress_close()
             return
@@ -734,30 +739,30 @@ def apply_actions_to_photos(actions, settings, paths=None, drop=False,
     if update:
         update()
 
-    #mention amount of photos and duration
-    delta = time.time()-start
-    duration = timedelta(seconds=int(delta)+48)
+    # mention amount of photos and duration
+    delta = time.time() - start
+    duration = timedelta(seconds=int(delta))
     if image_amount == 1:
-        message = _('One image done in %s')%duration
+        message = _('One image done in %s') % duration
     else:
         message = _('%(amount)d images done in %(duration)s')\
-            %{'amount': image_amount, 'duration': duration}
-    #add error status
+            % {'amount': image_amount, 'duration': duration}
+    # add error status
     if ERROR_LOG_COUNTER == 1:
-        message += '\n'+_('One issue was logged')
+        message += '\n' + _('One issue was logged')
     elif ERROR_LOG_COUNTER:
-        message += '\n'+_('%d issues were logged')\
-            %ERROR_LOG_COUNTER
+        message += '\n' + _('%d issues were logged')\
+            % ERROR_LOG_COUNTER
 
-    #show notification
+    # show notification
     send.frame_show_notification(message, report=report)
 
-    #show status dialog
+    # show status dialog
     if ERROR_LOG_COUNTER == 0:
         if settings['always_show_status_dialog']:
             send.frame_show_status(message, log=False)
     else:
-        message = '%s\n\n%s'%(message, SEE_LOG)
+        message = '%s\n\n%s' % (message, SEE_LOG)
         send.frame_show_status(message)
 
 
@@ -769,25 +774,31 @@ def apply_actions_to_photo(actions, image_info, info_not_file,
     #open image and check for errors
     photo, result = get_photo(image_info, info_not_file, result)
     if result['abort']:
+        photo.close()
         return 'return'
     elif not photo or result['skip']:
+        photo.close()
         return 'continue'
     info = photo.info
     info.set('imageindex', image_index)
     image = photo.get_layer().image
     for r in range(repeat):
-        info.set('index', image_index*repeat+r)
+        info.set('index', image_index * repeat + r)
         info.set('repeatindex', r)
         #update image file & progress dialog box
         progress_result = {}
         send.progress_update_filename(progress_result, info['index'],
             info['path'])
         if progress_result and not progress_result['keepgoing']:
+            photo.close()
             return 'return'
         #check if already not done
         if skip_existing_images and is_done(photo):
             continue
-        photo.get_layer().image = image.copy()
+        if r == repeat - 1:
+            photo.get_layer().image = image
+        elif r > 0:
+            photo.get_layer().image = image.copy()
         #do the actions
         for action_index, action in enumerate(actions):
             #update progress
@@ -795,17 +806,19 @@ def apply_actions_to_photo(actions, image_info, info_not_file,
             send.progress_update_index(progress_result, info['index'],
                 action_index)
             if progress_result and not progress_result['keepgoing']:
+                photo.close()
                 return 'return'
             #apply action
             photo, result = apply_action_to_photo(action, photo,
                 read_only_settings, cache, image_info['path'], result)
             if result['abort']:
+                photo.close()
                 return 'return'
             elif result['skip']:
                 #skip to next image immediately
                 continue
     report.extend(photo.report_files)
-    del photo, progress_result, action_index, action
+    photo.close()
     if result['abort']:
         return 'return'
 
@@ -824,20 +837,17 @@ def import_module(module, folder=None):
     """
     if folder is None:
         return __import__(module)
-    return getattr(__import__('%s.%s'%(folder.replace(os.path.sep, '.'),
+    return getattr(__import__('%s.%s' % (folder.replace(os.path.sep, '.'),
         module)), module)
 
 
 def import_actions():
     """Import all actions from the ``ct.PHATCH_ACTIONS_PATH``."""
     global ACTIONS, ACTION_LABELS, ACTION_FIELDS
-    #if bitmaps
-    from lib.events import send
-    #actions=result
     modules = \
         [import_module(os.path.basename(os.path.splitext(filename)[0]),
             'actions') for filename in \
-            glob.glob(os.path.join(ct.PHATCH_ACTIONS_PATH, '*.py'))]+\
+            glob.glob(os.path.join(ct.PHATCH_ACTIONS_PATH, '*.py'))] + \
         [import_module(os.path.basename(os.path.splitext(filename)[0])) for
             filename in glob.glob(os.path.join(ct.USER_ACTIONS_PATH, '*.py'))]
     ACTIONS = {}
@@ -881,7 +891,7 @@ def save_actionlist(filename, data):
     #prepare data
     data['actions'] = [action.dump() for action in data['actions']]
     #backup previous
-    previous = filename+'~'
+    previous = filename + '~'
     if os.path.exists(previous):
         os.remove(previous)
     if os.path.isfile(filename):
@@ -916,7 +926,7 @@ def open_actionlist(filename):
         actionLabel = action['label']
         actionFields = action['fields']
         newAction = ACTIONS[actionLabel]()
-        invalid_labels.extend(['- %s (%s)'%(label, actionLabel)
+        invalid_labels.extend(['- %s (%s)' % (label, actionLabel)
                                 for label in newAction.load(actionFields)])
         result.append(newAction)
     warning = assert_safe(result)
