@@ -32,6 +32,7 @@ from lib.unicoding import ensure_unicode
 
 #-- nosetests
 
+
 class Paths:
 
     def __getitem__(self, key):
@@ -64,21 +65,23 @@ USER_MASKS_PATH = os.path.join(USER_DATA_PATH, 'masks')
 USER_HIGHLIGHTS_PATH = os.path.join(USER_DATA_PATH, 'highlights')
 USER_WATERMARKS_PATH = os.path.join(USER_DATA_PATH, 'watermarks')
 
+SYSTEM_INSTALL = False
+
 
 def verify_app_user_paths():
     """Create user path structure if it does not exist yet. If there
     are new action lists in the phatch library, copy them to the user
     folder.
     """
-    #fixme:better use setting, path retrieval should be cleaned
+    # fixme: better use setting, path retrieval should be cleaned
     for path in [USER_DATA_PATH, USER_CONFIG_PATH,
             USER_CACHE_PATH, USER_ACTIONLISTS_PATH,
             USER_ACTIONS_PATH, USER_BIN_PATH, USER_BIN_PATH,
             USER_FONTS_PATH, USER_MASKS_PATH,
             USER_HIGHLIGHTS_PATH, USER_WATERMARKS_PATH]:
-        if 0:# and path == USER_ACTIONLISTS_PATH:
-            #DISABLED
-            #copy action lists from the phatch root to user
+        if 0:  # and path == USER_ACTIONLISTS_PATH:
+            # DISABLED
+            # copy action lists from the phatch root to user
             if os.path.exists(path):
                 existing = os.listdir(path)
                 for al in os.listdir(PHATCH_ACTIONLISTS_PATH):
@@ -108,11 +111,11 @@ def check_config_paths(config_paths):
         SYSTEM_INSTALL = False
         PHATCH_DATA_PATH = config_paths['PHATCH_DATA_PATH']
         PHATCH_FONTS_PATH = config_paths['PHATCH_FONTS_PATH']
-        PHATCH_FONTS_CACHE_PATH= config_paths['PHATCH_FONTS_CACHE_PATH']
-        PHATCH_ACTIONLISTS_PATH= config_paths['PHATCH_ACTIONLISTS_PATH']
+        PHATCH_FONTS_CACHE_PATH = config_paths['PHATCH_FONTS_CACHE_PATH']
+        PHATCH_ACTIONLISTS_PATH = config_paths['PHATCH_ACTIONLISTS_PATH']
         return config_paths
     SYSTEM_INSTALL = True
-    ROOT_SHARE_PATH = os.path.join(sys.prefix, "share")#for win?
+    ROOT_SHARE_PATH = os.path.join(sys.prefix, "share")  # for win?
     PHATCH_SHARE_PATH = os.path.join(ROOT_SHARE_PATH, "phatch")
     PHATCH_DATA_PATH = os.path.join(PHATCH_SHARE_PATH, "data")
     PHATCH_ACTIONLISTS_PATH = os.path.join(PHATCH_DATA_PATH,
@@ -133,8 +136,8 @@ def check_config_paths(config_paths):
                                     'images'),
             'PHATCH_LOCALE_PATH': os.path.join(ROOT_SHARE_PATH,
                                     'locale'),
-            'PHATCH_DOCS_PATH': os.path.join(PHATCH_SHARE_PATH,
-                                    'phatch', 'docs'),
+            'PHATCH_DOCS_PATH': os.path.join(ROOT_SHARE_PATH,
+                                    'doc', 'phatch', 'html'),
             #cache
             'PHATCH_FONTS_CACHE_PATH': PHATCH_FONTS_CACHE_PATH,
             #data
@@ -188,10 +191,10 @@ def load_locale(app, path, canonical='default', unicode=True):
             canonical = 'en'
     #canonical = 'zh' #to test unicode languages
     #expand with similar translations
-    base = canonical.split('_')[0] #eg pt_BR -> pt
+    base = canonical.split('_')[0]  # eg pt_BR -> pt
     base_path = os.path.join(path, base)
     languages = [base_path] + \
-        [os.path.basename(x) for x in glob.glob(base_path+'_*')]
+        [os.path.basename(x) for x in glob.glob(base_path + '_*')]
     #ensure canonical is the first element (base the second)
     if canonical in languages:
         languages.remove(canonical)
@@ -212,7 +215,7 @@ def init_config_paths(config_paths=None):
     #patches for pil <= 1.1.6 (ImportError=skip during build process)
     try:
         import Image
-        if Image.VERSION <= '1.1.6':
+        if Image.VERSION < '1.1.7':
             fix_python_path(os.path.join(phatch_path, 'other', 'pil_1_1_6'))
     except ImportError:
         pass
