@@ -16,18 +16,22 @@
 #
 # Phatch recommends SPE (http://pythonide.stani.be) for editing python files.
 
+# Follows PEP8
+
 #---import modules
 
 #gui-independent
 import os
-from lib.events import send, Receiver
+from lib.events import send, Receiver  # send is used when message is imported
 from lib.unicoding import ensure_unicode
 
 #---classes
+
+
 class FrameReceiver(Receiver):
     #---pubsub
     def _pubsub(self):
-        Receiver.__init__(self,'frame')
+        Receiver.__init__(self, 'frame')
         #Pubsub events
         self.subscribe('append_save_action')
         self.subscribe('show_execute_dialog')
@@ -42,72 +46,72 @@ class FrameReceiver(Receiver):
         self.subscribe('show_image_tree')
         self.subscribe('show_status')
 
-    def append_save_action(self,actions):
+    def append_save_action(self, actions):
         """To be overwritten."""
         pass
 
-    def show_execute_dialog(self,result,settings,files=None):
+    def show_execute_dialog(self, result, settings, files=None):
         """To be overwritten."""
         pass
 
-    def show_error(self,message):
+    def show_error(self, message):
         """To be overwritten."""
         pass
 
-    def show_files_message(self,result,message,title,files):
+    def show_files_message(self, result, message, title, files):
         """To be overwritten."""
         pass
 
-    def show_progress(self,title,parent_max,child_max,message=''):
+    def show_progress(self, title, parent_max, child_max, message=''):
         """To be overwritten.
         parent_max -> parent loop, eg images
         child_max  -> child loop, eg actions & open"""
         pass
 
-    def show_progress_error(self,result,message,ignore=True):
+    def show_progress_error(self, result, message, ignore=True):
         """To be overwritten."""
         pass
 
-    def show_scrolled_message(self,message,title,**keyw):
+    def show_scrolled_message(self, message, title, **keyw):
         """To be overwritten."""
         pass
 
+
 class ProgressReceiver(Receiver):
-    def __init__(self,parent_max,child_max):
-        self.set_max(parent_max,child_max)
+    def __init__(self, parent_max, child_max):
+        self.set_max(parent_max, child_max)
         self._pubsub()
 
-    def set_max(self,parent_max,child_max):
+    def set_max(self, parent_max, child_max):
         self.parent_max = parent_max
-        self.child_max  = child_max
-        self.max        = parent_max*child_max
+        self.child_max = child_max
+        self.max = parent_max * child_max
 
     def _pubsub(self):
-        Receiver.__init__(self,'progress')
+        Receiver.__init__(self, 'progress')
         self.subscribe('close')
         self.subscribe('update')
         self.subscribe('update_filename')
         self.subscribe('update_index')
 
-    def update_filename(self,result,parent_index,filename):
-        dirname, basename   = os.path.split(filename)
-        dirname             = ensure_unicode(dirname)
-        basename            = ensure_unicode(basename)
-        message             = u"%s: %s\n%s: %s\n"\
-            %(_('In'),dirname,_('File'),basename)
-        self.update(result,parent_index*self.child_max,newmsg=message)
+    def update_filename(self, result, parent_index, filename):
+        dirname, basename = os.path.split(filename)
+        dirname = ensure_unicode(dirname)
+        basename = ensure_unicode(basename)
+        message = u"%s: %s\n%s: %s\n" \
+            % (_('In'), dirname, _('File'), basename)
+        self.update(result, parent_index * self.child_max, newmsg=message)
         self.sleep()
 
-    def update_index(self,result,parent_index,child_index):
-        self.update(result,parent_index*self.child_max + child_index + 1)
+    def update_index(self, result, parent_index, child_index):
+        self.update(result, parent_index * self.child_max + child_index + 1)
 
     #---overwrite
     def close(self):
         pass
 
-    def update(self,result,value,newmsg=''):
+    def update(self, result, value, newmsg=''):
         pass
 
     def sleep(self):
         pass
-
