@@ -32,9 +32,9 @@ import os
 
 import Image
 
-from lib.formField import files_dictionary, Form, Field, CharField, \
-    ImageDictionaryReadFileField, ValidationError,\
-    RE_FILE_IN, RE_FILE_OUT, ImageDictionaryField, rotation_title_parser
+from lib.formField import files_dictionary, Form, Field, \
+    ImageDictionaryReadFileField, \
+    ImageDictionaryField, rotation_title_parser
 from lib.reverse_translation import _t
 from config import PATHS
 from lib import openImage
@@ -68,7 +68,7 @@ def negative(value):
         if negative_value[0] == '-':
             negative_value = negative_value[1:]
         else:
-            negative_value = '-'+negative_value
+            negative_value = '-' + negative_value
     else:
         negative_value = value
     return negative_value
@@ -121,8 +121,8 @@ class Action(Form):
         #check if file is valid
         return openImage.verify_image({'path': filename}, [], [])
 
+    # for save actions
 
-    #for save actions
     def ensure_path_or_desktop(self, folder, photo, filename, desktop=False):
         """Ensures that folder exists. If it can't create the path,
         it will log an error in the photo and propose to save it in the
@@ -149,53 +149,53 @@ class Action(Form):
             base = os.path.basename(filename)
             if error:
                 photo.log('Could not save "%s" in "%s":\n%s\n'\
-                    %(base, folder, message))
+                    % (base, folder, message))
                 photo.log('Will try to save in "%s" instead.\n'\
-                    %DESKTOP_FOLDER)
+                    % DESKTOP_FOLDER)
             self.ensure_path(DESKTOP_FOLDER)
             filename = os.path.join(DESKTOP_FOLDER, base)
         return filename
 
-    #field classes which are specific to Phatch and
-    #do not belong to formField
+    # field classes which are specific to Phatch and
+    # do not belong to formField
     class HighlightFileField(ImageDictionaryReadFileField):
-        dialog = PATHS["USER_HIGHLIGHTS_PATH"]#_('Select Highlight')
+        dialog = PATHS["USER_HIGHLIGHTS_PATH"]  # _('Select Highlight')
 
         def init_dictionary(self):
             self.dictionary = files_dictionary(
-                paths = [PATHS["PHATCH_HIGHLIGHTS_PATH"],
+                paths=[PATHS["PHATCH_HIGHLIGHTS_PATH"],
                                PATHS["USER_HIGHLIGHTS_PATH"]],
-                extensions = self.extensions)
+                extensions=self.extensions)
 
     class MaskFileField(ImageDictionaryReadFileField):
-        dialog = PATHS["USER_MASKS_PATH"]#_('Select Mask')
+        dialog = PATHS["USER_MASKS_PATH"]  # _('Select Mask')
 
         def init_dictionary(self):
             self.dictionary = files_dictionary(
-                paths = [PATHS["PHATCH_MASKS_PATH"],
+                paths=[PATHS["PHATCH_MASKS_PATH"],
                         PATHS["USER_MASKS_PATH"]],
-                extensions = self.extensions)
+                extensions=self.extensions)
 
     class WatermarkFileField(ImageDictionaryReadFileField):
-        dialog = PATHS["USER_WATERMARKS_PATH"]#_('Select Watermark')
+        dialog = PATHS["USER_WATERMARKS_PATH"]  # _('Select Watermark')
 
         def init_dictionary(self):
             self.dictionary = files_dictionary(
-                paths = [
+                paths=[
                     PATHS["PHATCH_IMAGE_PATH"],
                     PATHS["USER_WATERMARKS_PATH"],
                 ],
-                extensions = self.extensions)
+                extensions=self.extensions)
 
     class PerspectiveField(ImageDictionaryField):
         dialog = _t('Select Projection')
 
         def init_dictionary(self):
             self.dictionary = files_dictionary(
-                paths = [
+                paths=[
                     PATHS["PHATCH_PERSPECTIVE_PATH"],
                 ],
-                extensions = self.extensions)
+                extensions=self.extensions)
 
     class BlenderField(ImageDictionaryField):
         icon_size = (128, 128)
@@ -208,8 +208,8 @@ class Action(Form):
                 self.option_name)
 
         def init_dictionary(self):
-            self.dictionary = files_dictionary(paths = [self.get_path(), ],
-                extensions = self.extensions, title_parser = self.title_parser)
+            self.dictionary = files_dictionary(paths=[self.get_path(), ],
+                extensions=self.extensions, title_parser=self.title_parser)
 
             if self.use_user_option:
                 self.dictionary['User'] = os.path.join(
@@ -223,7 +223,7 @@ class Action(Form):
         dialog = _t('Select Rotation')
         option_name = 'rotation'
         title_parser = rotation_title_parser
-        #FIXME: these should be instance, not class variables!
+        # FIXME: these should be instance, not class variables!
         use_user_option = True
         selected_object = 'Box'
 
@@ -236,7 +236,7 @@ class OffsetMixin(object):
     CENTER = _t('Center')
     CUSTOM = _t('Custom')
     MIDDLE = _t('Middle')
-    LEFT =_t('Left')
+    LEFT = _t('Left')
     RIGHT = _t('Right')
     TOP = _t('Top')
     BOTTOM = _t('Bottom')
@@ -278,31 +278,31 @@ class OffsetMixin(object):
         #transform position, offset to custom
         position = self.get_field_string('Position')
         exclude.extend(['Position', 'Offset'])
-        #place in center of image
+        # place in center of image
         if position == self.CENTER:
             self.set_field_as_string('Horizontal Offset', '50%')
             self.set_field_as_string('Horizontal Justification', self.MIDDLE)
             self.set_field_as_string('Vertical Offset', '50%')
             self.set_field_as_string('Vertical Justification', self.MIDDLE)
-        #place in a corner of the image
+        # place in a corner of the image
         elif position != self.CUSTOM:
             offset = self.get_field_string('Offset')
-            #horizontal
+            # horizontal
             if 'Left' in position:
                 self.set_field_as_string('Horizontal Offset', offset)
                 self.set_field_as_string('Horizontal Justification', self.LEFT)
-            else: #Right
+            else:  # Right
                 self.set_field_as_string('Horizontal Offset', negative(offset))
                 self.set_field_as_string('Horizontal Justification',
                     self.RIGHT)
-            #vertical
+            # vertical
             if 'Top' in position:
                 self.set_field_as_string('Vertical Offset', offset)
                 self.set_field_as_string('Vertical Justification', self.TOP)
-            else: #Bottom
+            else:  # Bottom
                 self.set_field_as_string('Vertical Offset', negative(offset))
                 self.set_field_as_string('Vertical Justification', self.BOTTOM)
-        #continue as normal values but exclude position & offset
+        # continue as normal values but exclude position & offset
         if pixel_fields is None:
             pixel_fields = {}
         x, y = info['size']
@@ -346,7 +346,7 @@ class LosslessSaveMixin(object):
         filename = self.get_field('File Name', info)
         folder = self.get_field('In', info)
         typ = info['type']
-        filename = os.path.join(folder, '%s.%s'%(filename, typ))
+        filename = os.path.join(folder, '%s.%s' % (filename, typ))
         #ensure folder
         filename = self.ensure_path_or_desktop(folder, photo, filename)
         photo.append_to_report(filename)
@@ -373,7 +373,7 @@ class CropMixin(object):
             action = self
         fields[_t('Mode')] = action.ChoiceField(self.crop_modes[0],
             choices=self.crop_modes)
-        fields[_t('All')] = action.PixelField('30%', #works with jpegtran
+        fields[_t('All')] = action.PixelField('30%',  # works with jpegtran
             choices=self._choices)
         fields[_t('Left')] = action.PixelField('0px',
             choices=self._choices)
@@ -411,10 +411,10 @@ class CropMixin(object):
             action = self
         if pixel_fields is None:
             pixel_fields = {}
-        #pixel fields
+        # pixel fields
         width, height = info['size']
         pixel_fields.update({
-            'All': (width+height) / 2,
+            'All': (width + height) / 2,
             'Left': width,
             'Right': width,
             'Top': height,
