@@ -27,10 +27,7 @@
 
 import datetime
 import os
-import operator
 import re
-import tempfile
-import time
 import types
 
 import Image
@@ -43,8 +40,6 @@ from lib import openImage
 from lib import system
 from lib import thumbnail
 from lib import unicoding
-from lib.desktop import DESKTOP_FOLDER
-from lib.unicoding import ensure_unicode
 from lib.reverse_translation import _t
 from lib.formField import RE_FILE_IN, RE_FILE_OUT
 
@@ -55,12 +50,6 @@ from config import USER_BIN_PATH
 
 system.set_bin_paths([USER_BIN_PATH])
 
-try:
-    from ExifTags import TAGS as EXIFTAGS
-except:
-    #older versions of PIL
-    EXIFTAGS = {}
-
 try:
     import pyexiv2
     from lib import _pyexiv2 as exif
@@ -68,14 +57,14 @@ except:
     pyexiv2 = None
     exif = False
 WWW_PYEXIV2 = 'http://tilloy.net/dev/pyexiv2/'
-NEEDS_PYEXIV2 = _('pyexiv2 needs to be installed')+' (%s)'%WWW_PYEXIV2
+NEEDS_PYEXIV2 = _('pyexiv2 needs to be installed') + ' (%s)' % WWW_PYEXIV2
 
 CONVERTED_MODE = \
 _('%(mode)s has been converted to %(mode_copy)s to save as %(format)s.')
 
 DYNAMIC_VARS = set(('width', 'height', 'size', 'mode', 'transparency'))
 IMAGE_DEFAULT_DPI = 72
-SEPARATOR = '_' #should be same as in core.translations
+SEPARATOR = '_'  # should be same as in core.translations
 MONTHS = (_t('January'), _t('February'), _t('March'), _t('April'),
     _t('May'), _t('June'), _t('July'), _t('August'), _t('September'),
     _t('October'), _t('November'), _t('December'))
@@ -116,7 +105,7 @@ def split_data(d):
         if len(value) > 1:
             for k, v in d.items():
                 for i, x in enumerate(v):
-                    d['%s.%d'%(k, i)] = v[i]
+                    d['%s.%d' % (k, i)] = v[i]
         return
     #datetime strings
     done = False
@@ -125,7 +114,7 @@ def split_data(d):
             dt = re_DATETIME.match(v)
             if dt:
                 for key in DATETIME_KEYS:
-                    d['%s.%s'%(k, key)] = dt.group(key)
+                    d['%s.%s' % (k, key)] = dt.group(key)
                     done = True
     if done:
         return
@@ -133,12 +122,12 @@ def split_data(d):
     if type(value) == datetime.datetime:
         for k, v in d.items():
             for key in DATETIME_KEYS:
-                d['%s.%s'%(k, key)] = getattr(v, key)
+                d['%s.%s' % (k, key)] = getattr(v, key)
 
 
 def fix_EXIF(tag):
     if not tag.startswith('EXIF'):
-        tag = 'EXIF.'+tag
+        tag = 'EXIF.' + tag
     return tag.replace(' ', SEPARATOR)
 
 
@@ -205,21 +194,25 @@ class InfoPhoto(dict):
             self.writable = self.writable_exif = self.writable_iptc = False
         #retrieve dump info
         try:
-            info_dumped = info_to_dump.open(path, sources).dump()
+            info_dumped = info_to_dump.open(path, sources).dump(free=True)
         except Exception, details:
             reason = unicoding.exception_to_unicode(details)
             #log error details
-            message = u'%s:%s:\n%s'%(_('Unable extract variables from file'),
+            message = u'%s:%s:\n%s' % (_('Unable extract variables from file'),
                 path, reason)
             raise Exception(message)
         self.update(info, explicit=False)
         self.update(info_dumped, explicit=False)
         #private vars
-        self._original_size = image.size #to compare if changed later
+        self._original_size = image.size  # to compare if changed later
         self._dirty = False
         self._log = ''
         self._flushed = True
 
+    def close(self):
+        """Remove circular reference."""
+        del self.get_pil
+
     def is_dirty(self):
         """The photo can become dirty in two ways:
 
@@ -284,7 +277,7 @@ class InfoPhoto(dict):
                 self.assert_transparency()
                 return self.get_pil().info['transparency']
             else:
-                raise KeyError('Fatal Error: tag "%s" is not dynamic?!'%tag)
+                raise KeyError('Fatal Error: tag "%s" is not dynamic?!' % tag)
         elif tag in metadata.ORIENTATION_TAGS:
             #give priority to writable tag
             if 'Exif_Image_Orientation' in self:
@@ -315,7 +308,7 @@ class InfoPhoto(dict):
             self.assert_transparency()
             del self.get_pil().info[tag]
             return
-        pyexiv2_tag = self._fix(tag) #pexiv2 demands str
+        pyexiv2_tag = self._fix(tag)  # pexiv2 demands str
         # a bit clumsy but pyexiv2 does not support get or in
         try:
             pyexiv2_tag_value = self.pyexiv2[pyexiv2_tag]
@@ -341,11 +334,11 @@ class InfoPhoto(dict):
             #redirect to writable tag
             tag = 'Exif_Image_Orientation'
         if tag in DYNAMIC_VARS:
-            if tag=='transparency':
+            if tag == 'transparency':
                 self.assert_transparency()
                 self.get_pil().info['transparency'] = value
             else:
-                raise KeyError(_('Tag "%s" is read only.')%tag)
+                raise KeyError(_('Tag "%s" is read only.') % tag)
         else:
             super(InfoPhoto, self).__setitem__(tag, value)
         if metadata.RE_PYEXIV2_TAG_EDITABLE.match(tag):
@@ -353,7 +346,7 @@ class InfoPhoto(dict):
                 self.pyexiv2[self._fix(tag)] = value
             except Exception, message:
                 raise KeyError('%s:\n%s'
-                    %(_('Impossible to write tag "%s"')%tag, message))
+                    % (_('Impossible to write tag "%s"') % tag, message))
         self._dirty = True
         self._flushed = False
 
@@ -370,7 +363,7 @@ class InfoPhoto(dict):
         :param message: message
         :type message: string
         """
-        self._log+= message + '\n'
+        self._log += message + '\n'
 
     def clear_log(self):
         """Clears the log."""
@@ -413,13 +406,13 @@ class InfoPhoto(dict):
         :rtype: bool
         """
         if not metadata.is_writable_tag(tag):
-            raise NotWritableTagError(_('Tag "%s" is not writable.')%tag)
+            raise NotWritableTagError(_('Tag "%s" is not writable.') % tag)
         if not ((self.writable_exif and tag.startswith('Exif'))
             or (self.writable_iptc and tag.startswith('Iptc'))
             or metadata.is_writeable_not_exif_tag(tag, self['mode'])):
             raise NotWritableTagError(
                 _('Format %(format)s does not support overwriting "%(tag)s".')\
-                %{'format': self['format'], 'tag': tag})
+                % {'format': self['format'], 'tag': tag})
 
     def save(self, target, target_format=None, thumbdata=None):
         """
@@ -437,7 +430,7 @@ class InfoPhoto(dict):
             #but save as exif jpg
             return
         if target == self['path']:
-            if self.is_dirty() and not self._flushed: #includes update_size
+            if self.is_dirty() and not self._flushed:  # includes update_size
                 warnings = exif.flush(self.pyexiv2, thumbdata)
                 self._flushed = True
         else:
@@ -451,9 +444,9 @@ class Photo:
     """Use :func:`get_photo` to obtain a photo from a filename."""
 
     def __init__(self, info, info_to_dump=None):
-        self.modify_date = None # for time shift action
-        self.report_files = [] # for reports
-        self._exif_transposition_reverse= None
+        self.modify_date = None  # for time shift action
+        self.report_files = []  # for reports
+        self._exif_transposition_reverse = None
         #layer
         path = info['path']
         name = self.current_layer_name = _t('background')
@@ -464,6 +457,11 @@ class Photo:
             layer.image)
         self.rotate_exif()
 
+    def close(self):
+        """Remove circular references."""
+        self.info.close()
+        del self.info
+
     def log(self, message):
         self.info.log(message)
 
@@ -474,8 +472,8 @@ class Photo:
         return self.info.get_log()
 
     def get_filename(self, folder, filename, typ):
-        return os.path.join(folder, '%s.%s'%(filename, typ))\
-            .replace('<', '%(').replace('>', ')s')%self.__dict__
+        return os.path.join(folder, '%s.%s' % (filename, typ))\
+            .replace('<', '%(').replace('>', ')s') % self.__dict__
 
     #---layers
     def get_flattened_image(self):
@@ -508,7 +506,7 @@ class Photo:
 
         if image_copy.mode != image.mode:
             self.log(CONVERTED_MODE % {'mode': image.mode,
-                'mode_copy': image_copy.mode, 'format': format}+'\n')
+                'mode_copy': image_copy.mode, 'format': format} + '\n')
 
         #reverse exif previously applied exif orientation
         #exif thumbnails are usually within 160x160
@@ -554,18 +552,19 @@ class Photo:
                         file_mode = imtools.save_check_mode(image_copy,
                             filename, **options)
                         if file_mode:
-                            #RGBA failed
-                            self.log(CONVERTED_MODE%{'mode': mode,
-                                'mode_copy': file_mode, 'format': format}+'\n')
+                            # RGBA failed
+                            self.log(CONVERTED_MODE % {'mode': mode,
+                                'mode_copy': file_mode, 'format': format} \
+                                + '\n')
                         else:
-                            #RGBA succeeded
-                            self.log(CONVERTED_MODE%{'mode': mode,
-                                'mode_copy': 'RGBA', 'format': format}+'\n')
+                            # RGBA succeeded
+                            self.log(CONVERTED_MODE % {'mode': mode,
+                                'mode_copy': 'RGBA', 'format': format} + '\n')
                     else:
                         self.log(CONVERTED_MODE % {'mode': image_copy.mode,
-                            'mode_copy': file_mode, 'format': format}+'\n')
+                            'mode_copy': file_mode, 'format': format} + '\n')
                 elif thumbnail.is_needed(image_copy, format):
-                    #save thumbnail in system cache if needed
+                    # save thumbnail in system cache if needed
                     if thumb is None:
                         thumb = image_copy
                     thumb_info = {
@@ -573,13 +572,13 @@ class Photo:
                         'height': image.size[1]}
                     thumbnail.save_to_cache(filename, thumb,
                         thumb_info=thumb_info, **options)
-                #copy metadata if needed (problematic for tiff)
-                #FIXME: if metdata corrupts the image, there should be
-                #no thumbnail
+                # copy metadata if needed (problematic for tiff)
+                # FIXME: if metdata corrupts the image, there should be
+                # no thumbnail
                 if save_metadata:
                     self.info.save(filename, thumbdata=thumbdata)
             else:
-                #save with pil>libtiff
+                # save with pil>libtiff
                 openImage.check_libtiff(compression)
                 self.log(openImage.save_libtiff(image_copy, filename,
                     compression=compression, **options))
@@ -674,43 +673,43 @@ class Photo:
                 done.append(source)
                 if error:
                     break
-        #check if we have a file_in
-        #clean up in case of error
+        # check if we have a file_in
+        # clean up in case of error
         if error:
             for source, target in temp_files:
-                target.close()#os.remove(target)
+                target.close()  # os.remove(target)
             raise error
-        #loop over output
+        # loop over output
         output = None
         for index, match in \
                 enumerate(RE_FILE_OUT.finditer(command)):
             if index > 0:
-                #only 1 is allowed
+                # only 1 is allowed
                 raise Exception('Only one file_out.* is allowed.')
             source = match.group()
             ext = match.group(1)
             output = system.TempFile(ext, output_filename)
             command = command.replace(source, system.fix_quotes(output.path))
 
-        #tweak command line
+        # tweak command line
         for source, target in temp_files:
             command = command.replace(source, system.fix_quotes(target.path))
-        #execute
+        # execute
         system.call(command, shell=shell)
-        #give back filename
+        # give back filename
         if output and not os.path.exists(output.path):
             error = True
         else:
             error = False
         for source, target in temp_files:
-            target.close()#os.remove(target)
+            target.close()  # os.remove(target)
         if error:
             raise Exception(
                 _('Command did not produce an output image:\n%s')\
-                %command)
+                % command)
         if output:
             layer.open(output.path)
-            #DO NOT REMOVE image.load() or output.close will fail on windows
+            # DO NOT REMOVE image.load() or output.close will fail on windows
             layer.image.load()
             output.close()
 
