@@ -16,8 +16,6 @@
 # Follows PEP8
 
 import os
-import re
-import sys
 from cStringIO import StringIO
 from itertools import cycle
 from urllib import urlopen
@@ -25,9 +23,11 @@ from urllib import urlopen
 import Image
 import ImageDraw
 import ImageEnhance
+import ImageOps
 
 import system
 
+ALL_PALETTE_INDICES = set(range(256))
 CHECKBOARD = {}
 COLOR_MAP = [255] * 128 + [0] * 128
 WWW_CACHE = {}
@@ -139,7 +139,8 @@ class _ByteCounter:
     >>> bc.bytes
     5
     """
-    bytes = 0
+    def __init__(self):
+        self.bytes = 0
 
     def write(self, data):
         self.bytes += len(data)
@@ -192,11 +193,11 @@ def get_quality(im, size, format, down=0, up=100, delta=1000, options=None):
     """
     if options is None:
         options = {}
-    q = options['quality'] = (down+up)/2
-    if q==down or q==up:
+    q = options['quality'] = (down + up) / 2
+    if q == down or q == up:
         return max(q, 1)
     s = get_size(im, format, **options)
-    if abs(s-size)<delta:
+    if abs(s - size) < delta:
         return q
     elif s > size:
         return get_quality(im, size, format, down, up=q, options=options)
@@ -219,15 +220,15 @@ def fill_background_color(image, color):
     elif image.mode != 'RGBA' and\
         not (image.mode == 'P' and 'transparency' in image.info):
         return image
-    if len(color) == 4 and color[-1]!=255:
+    if len(color) == 4 and color[-1] != 255:
         mode = 'RGBA'
     else:
         mode = 'RGB'
     back = Image.new(mode, image.size, color)
     if (image.mode == 'P' and mode == 'RGBA'):
         image = image.convert('RGBA')
-    if image.mode in ['RGBA', 'LA']:
-        back.paste(image, image)
+    if has_alpha(image):
+        paste(back, image, mask=image)
     elif image.mode == 'P':
         palette = image.getpalette()
         index = image.info['transparency']
@@ -236,7 +237,7 @@ def fill_background_color(image, color):
         del image.info['transparency']
         back = image
     else:
-        back.paste(image)
+        paste(back, image)
     return back
 
 
@@ -270,14 +271,14 @@ def generate_layer(image_size, mark, method,
 
     .. see also:: :func:`reduce_opacity`
     """
-    mark = open_image(mark)
+    mark = convert_safe_mode(open_image(mark))
     opacity /= 100.0
     mark = reduce_opacity(mark, opacity)
     layer = Image.new('RGBA', image_size, (0, 0, 0, 0))
     if method == 'Tile':
         for y in range(0, image_size[1], mark.size[1]):
             for x in range(0, image_size[0], mark.size[0]):
-                layer.paste(mark, (x, y))
+                paste(layer, mark, (x, y))
     elif method == 'Scale':
         # scale, but preserve the aspect ratio
         ratio = min(float(image_size[0]) / mark.size[0],
@@ -285,7 +286,7 @@ def generate_layer(image_size, mark, method,
         w = int(mark.size[0] * ratio)
         h = int(mark.size[1] * ratio)
         mark = mark.resize((w, h))
-        layer.paste(mark, ((image_size[0] - w) / 2,
+        paste(layer, mark, ((image_size[0] - w) / 2,
             (image_size[1] - h) / 2))
     elif method == 'By Offset':
         location = calculate_location(
@@ -295,9 +296,9 @@ def generate_layer(image_size, mark, method,
         if orientation:
             orientation_value = getattr(Image, orientation)
             mark = mark.transpose(orientation_value)
-        layer.paste(mark, location)
+        paste(layer, mark, location, force=True)
     else:
-        raise ValueError('Unknown method "%s" for generate_layer.'%method)
+        raise ValueError('Unknown method "%s" for generate_layer.' % method)
     return layer
 
 
@@ -345,7 +346,8 @@ def blend(im1, im2, amount, color=None):
         im1 = im1.convert(expanded.mode)
         we, he = expanded.size
         wi, hi = im1.size
-        expanded.paste(im1, ((we-wi)/2, (he-hi)/2), im1.convert('RGBA'))
+        paste(expanded, im1, ((we - wi) / 2, (he - hi) / 2),
+            im1.convert('RGBA'))
         im1 = expanded
     return Image.blend(im1, im2, amount)
 
@@ -428,47 +430,25 @@ def calculate_location(horizontal_offset, vertical_offset,
         vertical_offset + vertical_delta
 
 
-def checkboard(size, delta=8, fg=(128, 128, 128), bg=(204, 204, 204)):
-    """Draw an n x n checkboard, which is often used as background
-    for transparent images. The checkboards are stored in the
-    ``CHECKBOARD`` cache.
-
-    :param delta: dimension of one square
-    :type delta: int
-    :param fg: foreground color
-    :type fg: tuple of int
-    :param bg: background color
-    :type bg: tuple of int
-    :returns: checkboard image
-    :rtype: pil.Image
-    """
-    if not (size in CHECKBOARD):
-        dim = max(size)
-        n = int(dim/delta)+1 #FIXME: now acts like square->nx, ny
-
-        def sq_start(i):
-            "Return the x/y start coord of the square at column/row i."
-            return i * delta
-
-        def square(i, j):
-            "Return the square corners"
-            return map(sq_start, [i, j, i + 1, j + 1])
-
-        image = Image.new("RGB", size, bg)
-        draw_square = ImageDraw.Draw(image).rectangle
-        squares = (square(i, j)
-           for i_start, j in zip(cycle((0, 1)), range(n))
-           for i in range(i_start, n, 2))
-        for sq in squares:
-            draw_square(sq, fill=fg)
-        CHECKBOARD[size] = image
-    return CHECKBOARD[size].copy()
-
-
 ####################################
 ####    PIL helper functions    ####
 ####################################
 
+
+def flatten(l):
+    """Flatten a list.
+
+    :param l: list to be flattened
+    :type l: list
+    :returns: flattened list
+    :rtype: list
+
+    >>> flatten([[1, 2], [3]])
+    [1, 2, 3]
+    """
+    return [item for sublist in l for item in sublist]
+
+
 def has_alpha(image):
     """Checks if the image has an alpha band.
     i.e. the image mode is either RGBA or LA.
@@ -479,7 +459,7 @@ def has_alpha(image):
     :returns: True or False
     :rtype: boolean
     """
-    return image.mode in ['RGBA', 'LA']
+    return image.mode.endswith('A')
 
 
 def has_transparency(image):
@@ -495,6 +475,31 @@ def has_transparency(image):
             has_alpha(image)
 
 
+if Image.VERSION == '1.1.7':
+
+    def split(image):
+        """Work around for bug in Pil 1.1.7
+
+        :param image: input image
+        :type image: PIL image object
+        :returns: the different color bands of the image (eg R, G, B)
+        :rtype: tuple
+        """
+        image.load()
+        return image.split()
+else:
+
+    def split(image):
+        """Work around for bug in Pil 1.1.7
+
+        :param image: input image
+        :type image: PIL image object
+        :returns: the different color bands of the image (eg R, G, B)
+        :rtype: tuple
+        """
+        return image.split()
+
+
 def get_alpha(image):
     """Gets the image alpha band. Can handles P mode images with transpareny.
     Returns a band with all values set to 255 if no alpha band exists.
@@ -505,9 +510,9 @@ def get_alpha(image):
     :rtype: single band image object
     """
     if has_alpha(image):
-        return image.split()[-1]
+        return split(image)[-1]
     if image.mode == 'P' and 'transparency' in image.info:
-        return image.convert('LA').split()[-1]
+        return image.convert('RGBA').split()[-1]
     # No alpha layer, create one.
     return Image.new('L', image.size, 255)
 
@@ -530,6 +535,114 @@ def get_format_data(image, format):
     return f.getvalue()
 
 
+def get_palette(image):
+    """Gets the palette of an image as a sequence of (r, g, b) tuples.
+
+    :param image: image with a palette
+    :type impage: pil.Image
+    :returns: palette colors
+    :rtype: a sequence of (r, g, b) tuples
+    """
+    palette = image.resize((256, 1))
+    palette.putdata(range(256))
+    return list(palette.convert("RGB").getdata())
+
+
+def get_used_palette_indices(image):
+    """Get used color indices in an image palette.
+
+    :param image: image with a palette
+    :type impage: pil.Image
+    :returns: used colors of the palette
+    :rtype: set of integers (0-255)
+    """
+    return set(image.getdata())
+
+
+def get_used_palette_colors(image):
+    """Get used colors in an image palette as a sequence of (r, g, b) tuples.
+
+    :param image: image with a palette
+    :type impage: pil.Image
+    :returns: used colors of the palette
+    :rtype: sequence of (r, g, b) tuples
+    """
+    used_indices = get_used_palette_indices(image)
+    if 'transparency' in image.info:
+        used_indices -= set([image.info['transparency']])
+    n = len(used_indices)
+    palette = image.resize((n, 1))
+    palette.putdata(used_indices)
+    return palette.convert("RGB").getdata()
+
+
+def get_unused_palette_indices(image):
+    """Get unused color indices in an image palette.
+
+    :param image: image with a palette
+    :type impage: pil.Image
+    :returns: unused color indices of the palette
+    :rtype: set of 0-255
+    """
+    return ALL_PALETTE_INDICES - get_used_palette_indices(image)
+
+
+def fit_color_in_palette(image, color):
+    """Fit a color into a palette. If the color exists already in the palette
+    return its current index, otherwise add the color to the palette if
+    possible. Returns -1 for color index if all colors are used already.
+
+    :param image: image with a palette
+    :type image: pil.Image
+    :param color: color to fit
+    :type color: (r, g, b) tuple
+    :returns: color index, (new) palette
+    :rtype: (r, g, b) tuple, sequence of (r, g, b) tuples
+    """
+    palette = get_palette(image)
+    try:
+        index = palette.index(color)
+    except ValueError:
+        index = -1
+    if index > -1:
+        # Check if it is not the transparent index, as that doesn't qualify.
+        try:
+            transparent = index == image.info['transparency']
+        except KeyError:
+            transparent = False
+        # If transparent, look further
+        if transparent:
+            try:
+                index = palette[index + 1:].index(color) + index + 1
+            except ValueError:
+                index = -1
+    if index == -1:
+        unused = list(get_unused_palette_indices(image))
+        if unused:
+            index = unused[0]
+            palette[index] = color  # add color to palette
+        else:
+            palette = None  # palette is full
+    return index, palette
+
+
+def put_palette(image_to, image_from, palette=None):
+    """Copies the palette and transparency of one image to another.
+
+    :param image_to: image with a palette
+    :type image_to: pil.Image
+    :param image_from: image with a palette
+    :type image_from: pil.Image
+    :param palette: image palette
+    :type palette: sequence of (r, g, b) tuples or None
+    """
+    if palette == None:
+        palette = get_palette(image_from)
+    image_to.putpalette(flatten(palette))
+    if 'transparency' in image_from.info:
+        image_to.info['transparency'] = image_from.info['transparency']
+
+
 def put_alpha(image, alpha):
     """Copies the given band to the alpha layer of the given image.
 
@@ -541,7 +654,7 @@ def put_alpha(image, alpha):
     if image.mode in ['CMYK', 'YCbCr', 'P']:
         image = image.convert('RGBA')
     elif image.mode in ['1', 'F']:
-        image = image.convert('LA')
+        image = image.convert('RGBA')
     image.putalpha(alpha)
 
 
@@ -559,11 +672,90 @@ def remove_alpha(image):
     if image.mode == 'LA':
         return image.convert('L')
     if image.mode == 'P' and 'transparency' in image.info:
-        del image.info['transparency']
-        return image.convert('RGB')
+        img = image.convert('RGB')
+        del img.info['transparency']
+        return img
     return image
 
 
+def paste(destination, source, box=(0, 0), mask=None, force=False):
+    """"Pastes the source image into the destination image while using an
+    alpha channel if available.
+
+    :param destination: destination image
+    :type destination:  PIL image object
+    :param source: source image
+    :type source: PIL image object
+    :param box:
+
+        The box argument is either a 2-tuple giving the upper left corner,
+        a 4-tuple defining the left, upper, right, and lower pixel coordinate,
+        or None (same as (0, 0)). If a 4-tuple is given, the size of the
+        pasted image must match the size of the region.
+
+    :type box: tuple
+    :param mask: mask or None
+
+    :type mask: bool or PIL image object
+    :param force:
+
+        With mask: Force the invert alpha paste or not.
+
+        Without mask:
+
+        - If ``True`` it will overwrite the alpha channel of the destination
+          with the alpha channel of the source image. So in that case the
+          pixels of the destination layer will be abandonned and replaced
+          by exactly the same pictures of the destination image. This is mostly
+          what you need if you paste on a transparant canvas.
+        - If ``False`` this will use a mask when the image has an alpha
+          channel. In this case pixels of the destination image will appear
+          through where the source image is transparent.
+
+    :type force: bool
+    """
+    # Paste on top
+    if source == mask:
+        if has_alpha(source):
+            # invert_alpha = the transparant pixels of the destination
+            if has_alpha(destination) and (destination.size == source.size
+                    or force):
+                invert_alpha = ImageOps.invert(get_alpha(destination))
+                if invert_alpha.size != source.size:
+                    # if sizes are not the same be careful!
+                    # check the results visually
+                    if len(box) == 2:
+                        w, h = source.size
+                        box = (box[0], box[1], box[0] + w, box[1] + h)
+                    invert_alpha = invert_alpha.crop(box)
+            else:
+                invert_alpha = None
+            # we don't want composite of the two alpha channels
+            source_without_alpha = remove_alpha(source)
+            # paste on top of the opaque destination pixels
+            destination.paste(source_without_alpha, box, source)
+            if invert_alpha != None:
+                # the alpha channel is ok now, so save it
+                destination_alpha = get_alpha(destination)
+                # paste on top of the transparant destination pixels
+                # the transparant pixels of the destination should
+                # be filled with the color information from the source
+                destination.paste(source_without_alpha, box, invert_alpha)
+                # restore the correct alpha channel
+                destination.putalpha(destination_alpha)
+        else:
+            destination.paste(source, box)
+    elif mask:
+        destination.paste(source, box, mask)
+    else:
+        destination.paste(source, box)
+        if force and has_alpha(source):
+            destination_alpha = get_alpha(destination)
+            source_alpha = get_alpha(source)
+            destination_alpha.paste(source_alpha, box)
+            destination.putalpha(destination_alpha)
+
+
 def auto_crop(image):
     """Crops all transparent or black background from the image
     :param image: input image
@@ -597,10 +789,10 @@ def convert(image, mode, *args, **keyw):
         if image.mode in ['1', 'F']:
             return image.convert('L').convert(mode, *args, **keyw)
         if image.mode in ['RGBA', 'LA']:
-            alpha = image.split()[-1]
+            alpha = get_alpha(image)
             output = image.convert('RGB').convert(
                 mode, colors=255, *args, **keyw)
-            output.paste(
+            paste(output,
                 255, alpha.point(COLOR_MAP))
             output.info['transparency'] = 255
             return output
@@ -630,8 +822,9 @@ def convert_safe_mode(image):
     if image.mode in ['1', 'F']:
         return image.convert('L')
     if image.mode == 'P' and 'transparency' in image.info:
-        del image.info['transparency']
-        return image.convert('RGBA')
+        img = image.convert('RGBA')
+        del img.info['transparency']
+        return img
     if image.mode in ['P', 'YCbCr', 'CMYK', 'RGBX']:
         return image.convert('RGB')
     return image
@@ -673,10 +866,8 @@ def convert_save_mode_by_format(image, format):
     elif format == 'GIF':
         return convert(image, 'P', palette=Image.ADAPTIVE)
     elif format == 'PBM':
-        if image.mode in ['P', 'CMYK', 'YCbCr']:
-            return image.convert('RGB')
-        if image.mode in ['LA']:
-            return image.convert('L')
+        if image.mode != '1':
+            return image.convert('1')
     elif format == 'PCX':
         if image.mode in ['RGBA', 'CMYK', 'YCbCr']:
             return image.convert('RGB')
@@ -688,9 +879,7 @@ def convert_save_mode_by_format(image, format):
         if image.mode in ['RGBA', 'YCbCr']:
             return image.convert('RGB')
     elif format == 'PGM':
-        if image.mode in ['P', 'CMYK', 'YCbCr']:
-            return image.convert('RGB')
-        if image.mode in ['LA']:
+        if image.mode != 'L':
             return image.convert('L')
     elif format == 'PPM':
         if image.mode in ['P', 'CMYK', 'YCbCr']:
@@ -718,7 +907,7 @@ def convert_save_mode_by_format(image, format):
 def save(image, filename, **options):
     """Saves an image with a filename and raise the specific
     ``InvalidWriteFormatError`` in case of an error instead of a
-    ``KeyError``.
+    ``KeyError``. Also can hack around UnicodeEncodeError (eg for IM format)
 
     :param image: image
     :type image: pil.Image
@@ -729,15 +918,23 @@ def save(image, filename, **options):
         image.save(filename, **options)
     except KeyError, format:
         raise InvalidWriteFormatError(format)
+    except UnicodeEncodeError:
+        temp = system.TempFile(suffix=os.path.splitext(filename)[-1])
+        image.save(temp.path, **options)
+        temp.close(dest=filename)
 
 
 def save_check_mode(image, filename, **options):
     #save image with pil
     save(image, filename, **options)
     #verify saved file
-    image_file = Image.open(filename)
-    image_file.verify()
-    if image.mode!= image_file.mode:
+    try:
+        image_file = Image.open(filename)
+        image_file.verify()
+    except IOError:
+        # We can't verify the image mode with PIL, so issue no warnings.
+        return ''
+    if image.mode != image_file.mode:
         return image_file.mode
     return ''
 
@@ -745,15 +942,15 @@ def save_check_mode(image, filename, **options):
 def save_safely(image, filename):
     """Saves an image with a filename and raise the specific
     ``InvalidWriteFormatError`` in case of an error instead of a
-    ``KeyError``.
+    ``KeyError``. It can also save IM files with unicode.
 
     :param image: image
     :type image: pil.Image
     :param filename: image filename
     :type filename: string
     """
-    ext = os.path.splitext(filename)[-1][1:]
-    format = get_format(ext)
+    ext = os.path.splitext(filename)[-1]
+    format = get_format(ext[1:])
     image = convert_save_mode_by_format(image, format)
     save(image, filename)
 
@@ -881,7 +1078,7 @@ def checkboard(size, delta=8, fg=(128, 128, 128), bg=(204, 204, 204)):
     """
     if not (size in CHECKBOARD):
         dim = max(size)
-        n = int(dim/delta)+1 #FIXME: now acts like square->nx, ny
+        n = int(dim / delta) + 1  # FIXME: now acts like square->nx, ny
 
         def sq_start(i):
             "Return the x/y start coord of the square at column/row i."
@@ -922,11 +1119,7 @@ def add_checkboard(image):
         #transparant image
         image = image.convert('RGBA')
         image_bg = checkboard(image.size)
-        image_bg.paste(image, (0, 0), image)
+        paste(image_bg, image, (0, 0), image)
         return image_bg
     else:
         return image
-
-
-if __name__ == '__main__':
-    example()
