@@ -41,9 +41,7 @@ except ImportError:
 
 import imtools
 import odict
-import operator
 import unicoding
-import system
 from desktop import DESKTOP_FOLDER
 from metadataTest import DateTime, INFO_TEST, is_string, MONTHS, now, WEEKDAYS
 from reverse_translation import _t
@@ -52,14 +50,14 @@ RE_VAR = re.compile('<.+?>')
 
 
 DATETIME_KEYS = ['year', 'month', 'day', 'hour', 'minute', 'second']
-RE_DATETIME_KEYS = re.compile('(%s)$'%('|'.join(['[.]'+key
+RE_DATETIME_KEYS = re.compile('(%s)$' % ('|'.join(['[.]' + key
     for key in DATETIME_KEYS])))
 
 RE_PYEXIV2_TAG = re.compile('^(Exif|Iptc)_.+')
 RE_PYEXIV2_TAG_EDITABLE = re.compile('^(Exif|Iptc)_\w+$')
 
 ORIENTATION_TAGS = ['orientation', 'Pexif_Orientation', 'Zexif_Orientation']
-WRITABLE_TAGS = ['dpi', 'transparency']+ORIENTATION_TAGS
+WRITABLE_TAGS = ['dpi', 'transparency'] + ORIENTATION_TAGS
 
 
 def is_editable_tag(tag):
@@ -94,6 +92,24 @@ class InfoProvideError(Exception):
     pass
 
 
+# Keep this outside _InfoCache to avoid self reference
+def _update_static_source(self):
+    """Update static cache does not do anything. This is just
+    a dummy function which can be assigned to
+    :method:``_update_source`` if the source is not callable."""
+    pass
+
+
+def _update_callable_source(self):
+    """Update dynamic cache updates ``self._source`` with
+    ``self._get_source_dynamic``. This can be assigned to
+    :method:``_update_source`` if the source is callable.
+
+    .. see also: :method:`_set_source`
+    """
+    self._set_source(self._get_source_dynamic())
+
+
 class _InfoCache(object):
 
     def __init__(self, source=None, vars=None):
@@ -156,11 +172,11 @@ class _InfoCache(object):
             source = self.get_source_from_file(source)
         if callable(source):
             self._get_source_dynamic = source
-            self._update_source = self._update_callable_source
+            self._update_source = _update_callable_source
             source = None
         else:
             self._get_source_dynamic = None
-            self._update_source = self._update_static_source
+            self._update_source = _update_static_source
         self._set_source(source)
         self.disable_cache()
         self.dict = self.empty_dict.copy()
@@ -184,30 +200,15 @@ class _InfoCache(object):
 
         This makes only sense for callable sources.
         """
-        self._update_source()
-        type(self).__getitem__ = self._get_var_from_source_without_update
+        self._update_source(self)
+        type(self).__getitem__ = type(self)._get_var_from_source_without_update
 
     def disable_cache(self):
         """Turn off static caching.
 
         This makes only sense for callable sources.
         """
-        type(self).__getitem__ = self._get_var_from_source_with_update
-
-    def _update_static_source(self):
-        """Update static cache does not do anything. This is just
-        a dummy function which can be assigned to
-        :method:``_update_source`` if the source is not callable."""
-        pass
-
-    def _update_callable_source(self):
-        """Update dynamic cache updates ``self._source`` with
-        ``self._get_source_dynamic``. This can be assigned to
-        :method:``_update_source`` if the source is callable.
-
-        .. see also: :method:`_set_source`
-        """
-        self._set_source(self._get_source_dynamic())
+        type(self).__getitem__ = type(self)._get_var_from_source_with_update
 
     def _get_var_from_source_with_update(self, var):
         """If the variable ``var`` is not present in the ``dict``,
@@ -220,7 +221,7 @@ class _InfoCache(object):
         try:
             return self.dict[var]
         except KeyError:
-            self._update_source()
+            self._update_source(self)
             return self._get_var_from_source(var)
 
     def _get_var_from_source_without_update(self, var):
@@ -271,7 +272,7 @@ class _InfoCache(object):
         :param var: variable
         :type var: string
         """
-        raise KeyError(self.prefix+var)
+        raise KeyError(self.prefix + var)
 
     def _extract_others(self):
         """Extract all other vars. Does nothing by default.
@@ -347,7 +348,7 @@ class _InfoCache(object):
     type = 'cache'
     _extract_methods = {}
 
-    prefix = type+'_'
+    prefix = type + '_'
     _prefix_n = len(prefix)
     possible_vars = sorted(_extract_methods.keys())
 
@@ -414,19 +415,19 @@ class InfoFile(_InfoCache):
             st_mtime = time.localtime(file_stat.st_mtime)[:7]
         except:
             self.dict['filesize'] = 0
-            st_mtime = (0, )*7
+            st_mtime = (0, ) * 7
         self.dict['year'], self.dict['month'], self.dict['day'], \
             self.dict['hour'], self.dict['minute'], self.dict['second'], \
             self.dict['weekday'] = st_mtime
         self.dict['weekdayname'] = WEEKDAYS[self.dict['weekday']]
-        self.dict['monthname'] = MONTHS[self.dict['month']-1]
+        self.dict['monthname'] = MONTHS[self.dict['month'] - 1]
 
     def _extract_subfolder(self):
         """Extracts the ``subfolder`` from the source. ``subfolder`` is the
         child folder from ``folder``.
         """
         self.dict['subfolder'] = \
-            os.path.dirname(self._source_path)[len(self._source_parent)+1:]
+            os.path.dirname(self._source_path)[len(self._source_parent) + 1:]
 
     def _extract_desktop(self):
         self.dict['desktop'] = DESKTOP_FOLDER
@@ -460,7 +461,7 @@ class InfoFile(_InfoCache):
         _t('year'): _extract_stat,
         }
 
-    prefix = type+'_'
+    prefix = type + '_'
     _prefix_n = len(prefix)
     possible_vars = sorted(_extract_methods.keys())
 
@@ -595,13 +596,13 @@ class InfoPil(_InfoPil):
         try:
             return self._source.info[var]
         except KeyError:
-            raise KeyError(self.prefix+var)
+            raise KeyError(self.prefix + var)
 
     def _extract_others(self):
         """Extract all other possible vars"""
         for key, value in self._source.info.items():
             if not(key in self.vars_skip):
-                self.dict[self.prefix+key] = value
+                self.dict[self.prefix + key] = value
 
     def reset_geometry(self):
         for var in ('width', 'height', 'size'):
@@ -638,10 +639,10 @@ class InfoPil(_InfoPil):
         _t('size'): _extract_size,
         _t('transparency'): _extract_transparency}
 
-    prefix = type+'_'
+    prefix = type + '_'
     _prefix_n = len(prefix)
     possible_vars = sorted(_extract_methods.keys())
-    vars_skip = possible_vars+['exif'] #skip for writing png metadata
+    vars_skip = possible_vars + ['exif']  # skip for writing png metadata
 
 #Initialize PIL metadata
 #This can't be lazily loaded as it is needed by the provide method.
@@ -706,24 +707,24 @@ class InfoPexif(_InfoPilMetadata):
     """Wraps a lazy PIL exif var access to an image.
 
     >>> import pprint
-    >>> filename = '../tests/images/input/exif.jpg'
+    >>> filename = '../tests/input/exĩf ïptç.jpg'
     >>> info = InfoPexif(filename)
     >>> info['orientation']
-    1
+    8
     >>> info['Pexif_DateTimeOriginal']
-    DateTime('2009:09:02 13:15:17')
+    DateTime('2010:03:03 11:03:08')
     >>> pprint.pprint(info.dict.keys())
     ['Pexif_DateTimeOriginal', 'orientation']
     >>> import Image
     >>> image = Image.open(filename)
     >>> info = InfoPexif(image)
     >>> info['Pexif_DateTimeOriginal']
-    DateTime('2009:09:02 13:15:17')
+    DateTime('2010:03:03 11:03:08')
     >>> pprint.pprint(info.dict.keys())
     ['Pexif_DateTimeOriginal']
     >>> info.extract_all()
     >>> info['Pexif_DateTimeOriginal']
-    DateTime('2009:09:02 13:15:17')
+    DateTime('2010:03:03 11:03:08')
     >>> pprint.pprint(info.dict.keys())
     ['orientation',
      'Pexif_Make',
@@ -777,20 +778,20 @@ class InfoPexif(_InfoPilMetadata):
         try:
             key = EXIFTAGS_REVERSE[var]
         except KeyError:
-            #re raise: give full name to key error
-            raise KeyError(self.prefix+var)
-        #import rpdb2; rpdb2.start_embedded_debugger('x')
+            # re raise: give full name to key error
+            raise KeyError(self.prefix + var)
         return convert_from_string(self._source[key])
 
     def _extract_others(self):
         """Extract all other possible vars"""
         for key, value in self._source.items():
             if key in EXIFTAGS:
-                self.dict['Pexif_'+EXIFTAGS[key]] = convert_from_string(value)
+                self.dict['Pexif_' + EXIFTAGS[key]] = \
+                    convert_from_string(value)
 
     type = 'Pexif'
 
-    prefix = type+'_'
+    prefix = type + '_'
     _prefix_n = len(prefix)
 
 
@@ -798,7 +799,7 @@ class InfoZexif(_InfoPilMetadata):
     """Wraps a lazy PIL exif var access to an image.
 
     >>> import pprint
-    >>> filename = '../tests/images/input/exif.jpg'
+    >>> filename = '../tests/input/exĩf ïptç.jpg'
     >>> info = InfoZexif(filename)
     >>> info['Zexif_0x9202']
     (128, 32)
@@ -870,12 +871,12 @@ class InfoZexif(_InfoPilMetadata):
     def _extract_others(self):
         """Extract all other vars"""
         for key, value in self._source.items():
-            self.dict['Zexif_0x%04x'%key] = convert_from_string(value)
+            self.dict['Zexif_0x%04x' % key] = convert_from_string(value)
 
     type = 'Zexif'
     regex = re.compile('0x[a-f0-9]{4,4}')
 
-    prefix = type+'_'
+    prefix = type + '_'
     _prefix_n = len(prefix)
 
 
@@ -898,7 +899,7 @@ class _InfoPyexiv2(_InfoCache):
         :type var: string
         """
         return self.convert(self._source['%s.%s' \
-            %(self.type, var.replace('_', '.'))])
+            % (self.type, var.replace('_', '.'))])
 
     def _extract_others_from_keys(self, exif_keys):
         """Extract all other vars"""
@@ -943,20 +944,20 @@ class _InfoPyexiv2(_InfoCache):
 class InfoExif(_InfoPyexiv2):
     """
     >>> import pprint
-    >>> filename = '../tests/images/input/exif.jpg'
+    >>> filename = '../tests/input/exĩf ïptç.jpg'
     >>> info = InfoExif(filename)
     >>> info['Exif_Image_DateTime']
-    DateTime('2009:09:02 13:15:17')
+    DateTime('2010:03:03 11:03:08')
     >>> import pyexiv2
     >>> exif = pyexiv2.Image(filename)
     >>> exif.readMetadata()
     >>> info = InfoExif(exif)
     >>> info['Exif_Image_DateTime']
-    DateTime('2009:09:02 13:15:17')
+    DateTime('2010:03:03 11:03:08')
     >>> print info['Exif_Image_DateTime']
-    2009:09:02 13:15:17
+    2010:03:03 11:03:08
     >>> info['Exif_Image_Orientation']
-    1
+    8
     >>> info['Exif_Photo_MaxApertureValue'].__class__ == pyexiv2.Rational
     True
     >>> print info['Exif_Photo_MaxApertureValue']
@@ -1136,7 +1137,7 @@ class InfoExif(_InfoPyexiv2):
     _extract_methods = {
         _t('orientation'): _extract_orientation}
 
-    prefix = type+'_'
+    prefix = type + '_'
     _prefix_n = len(prefix)
     possible_vars = sorted(_extract_methods.keys())
 
@@ -1144,18 +1145,18 @@ class InfoExif(_InfoPyexiv2):
 class InfoIptc(_InfoPyexiv2):
     """
     >>> import pprint
-    >>> filename = '../tests/images/input/iptc.jpg'
+    >>> filename = '../tests/input/exĩf ïptç.jpg'
     >>> info = InfoIptc(filename)
     >>> info['Iptc_Application2_RecordVersion']
-    2
+    0
     >>> import pyexiv2
     >>> exif = pyexiv2.Image(filename)
     >>> exif.readMetadata()
     >>> info = InfoIptc(exif)
     >>> info['Iptc_Application2_RecordVersion']
-    2
+    0
     >>> info['Iptc_Application2_Copyright']
-    'Copyright 2006, e2interactive'
+    'Copyright 2010, www.stani.be'
     >>> pprint.pprint(sorted(info.dict.keys()))
     ['Iptc_Application2_Copyright', 'Iptc_Application2_RecordVersion']
     >>> info.extract_all()
@@ -1174,14 +1175,14 @@ class InfoIptc(_InfoPyexiv2):
     type = 'Iptc'
     regex = re.compile('^Iptc_')
 
-    prefix = type+'_'
+    prefix = type + '_'
     _prefix_n = len(prefix)
 
 
 class InfoEXIF(_InfoCache):
     """
     >>> import pprint
-    >>> filename = '../tests/images/input/exif2.jpg'
+    >>> filename = '../tests/input/exĩf ïptç.jpg'
     >>> info = InfoEXIF(filename)
     >>> pprint.pprint(sorted(info.dict.keys()))
     []
@@ -1330,7 +1331,7 @@ class InfoEXIF(_InfoCache):
         """
         var = var.replace('_', ' ')
         try:
-            return self._source['EXIF '+var]
+            return self._source['EXIF ' + var]
         except KeyError:
             return self._source[var]
 
@@ -1339,7 +1340,7 @@ class InfoEXIF(_InfoCache):
         for tag, value in self._source.items():
             tag = tag.replace(' ', '_')
             if not tag.startswith('EXIF'):
-                tag = 'EXIF_'+tag
+                tag = 'EXIF_' + tag
             self.dict[tag] = value
 
     @classmethod
@@ -1370,7 +1371,7 @@ class InfoEXIF(_InfoCache):
         'Mirrored horizontal then rotated 90 CW': 7,
         'Rotated 90 CCW': 8}
 
-    prefix = type+'_'
+    prefix = type + '_'
     _prefix_n = len(prefix)
     possible_vars = sorted(_extract_methods.keys())
 
@@ -1424,14 +1425,16 @@ class InfoExtract:
     """Create an info like dictionary which uses a collection of several
     info instances and can evaluate Python expressions.
 
+    >>> import Image
     >>> import pprint
     >>> list(InfoExtract.get_vars_by_info(['mode'])[0].values())
     [['mode', 'orientation']]
     >>> list(InfoExtract.get_vars_by_info(['width'])[0].values())
     [['width', 'orientation']]
     >>> vars = ['format', 'width', 'subfolder', 'orientation', 'crazy']
-    >>> info = InfoExtract('../tests/images/input/exif.jpg',
-    ...     vars+['Pexif_DateTimeOriginal'])
+    >>> filename = '../tests/input/exĩf ïptç.jpg'
+    >>> image = Image.open(filename)
+    >>> info = InfoExtract(filename, vars + ['Pexif_DateTimeOriginal'])
     >>> info.types()
     ['File', 'Exif', 'Pil', 'Pexif']
     >>> info.vars_unknown
@@ -1439,49 +1442,39 @@ class InfoExtract:
     >>> info['format']
     'JPEG'
     >>> pprint.pprint(sorted(info.dump(expand=False).items()))
-    [('Pexif_DateTimeOriginal', DateTime('2009:09:02 13:15:17')),
+    [('Pexif_DateTimeOriginal', DateTime('2010:03:03 11:03:08')),
      ('format', 'JPEG'),
-     ('height', 480),
-     ('orientation', 1),
-     ('size', (640, 480)),
+     ('height', 640),
+     ('orientation', 8),
+     ('size', (480, 640)),
      ('subfolder', u''),
-     ('width', 640)]
-    >>> info['width']
-    640
-    >>> info['weekdayname']
-    'Friday'
+     ('width', 480)]
+    >>> info['size']  # uses orientation
+    (480, 640)
+    >>> image.size  # ignores orientation
+    (640, 480)
     >>> info['Pexif_DateTimeOriginal']
-    DateTime('2009:09:02 13:15:17')
+    DateTime('2010:03:03 11:03:08')
     >>> pprint.pprint(sorted(info.dump(expand=True).items()))
-    [('Pexif_DateTimeOriginal', DateTime('2009:09:02 13:15:17')),
-     ('Pexif_DateTimeOriginal.day', 2),
-     ('Pexif_DateTimeOriginal.hour', 13),
+    [('Pexif_DateTimeOriginal', DateTime('2010:03:03 11:03:08')),
+     ('Pexif_DateTimeOriginal.day', 3),
+     ('Pexif_DateTimeOriginal.hour', 11),
      ('Pexif_DateTimeOriginal.microsecond', 0),
-     ('Pexif_DateTimeOriginal.minute', 15),
-     ('Pexif_DateTimeOriginal.month', 9),
-     ('Pexif_DateTimeOriginal.monthname', 'September'),
-     ('Pexif_DateTimeOriginal.second', 17),
+     ('Pexif_DateTimeOriginal.minute', 3),
+     ('Pexif_DateTimeOriginal.month', 3),
+     ('Pexif_DateTimeOriginal.monthname', 'March'),
+     ('Pexif_DateTimeOriginal.second', 8),
      ('Pexif_DateTimeOriginal.weekday', 2),
      ('Pexif_DateTimeOriginal.weekdayname', 'Wednesday'),
-     ('Pexif_DateTimeOriginal.year', 2009),
-     ('day', 2),
-     ('filesize', 61547),
+     ('Pexif_DateTimeOriginal.year', 2010),
      ('format', 'JPEG'),
-     ('height', 480),
-     ('hour', 2),
-     ('minute', 38),
-     ('month', 10),
-     ('monthname', 'October'),
-     ('orientation', 1),
-     ('second', 32),
-     ('size', (640, 480)),
-     ('size[0]', 640),
-     ('size[1]', 480),
+     ('height', 640),
+     ('orientation', 8),
+     ('size', (480, 640)),
+     ('size[0]', 480),
+     ('size[1]', 640),
      ('subfolder', u''),
-     ('weekday', 4),
-     ('weekdayname', 'Friday'),
-     ('width', 640),
-     ('year', 2009)]
+     ('width', 480)]
     >>> info.extract_all()
     >>> pprint.pprint(sorted(info.dump(expand=False).keys()))
     ['Exif_CanonCs_0x0000',
@@ -1701,45 +1694,190 @@ class InfoExtract:
      'weekdayname',
      'width',
      'year']
-    >>> info.set(filename='../tests/images/input/iptc.jpg',
+    >>> info.set(filename='../tests/input/exĩf ïptç.jpg',
     ...     vars=vars) #exclude Pexif.* vars
     >>> pprint.pprint(sorted(info.dump(expand=False).items()))
     [('format', 'JPEG'),
-     ('height', 399),
-     ('orientation', 1),
-     ('size', (600, 399)),
+     ('height', 640),
+     ('orientation', 8),
+     ('size', (480, 640)),
      ('subfolder', u''),
-     ('width', 600)]
-
+     ('width', 480)]
     >>> info['root']
-    u'../tests/images'
+    u'../tests'
     >>> d = info.dump(expand=False)
     >>> pprint.pprint(sorted(d.items()))
     [('foldername', u'input'),
      ('format', 'JPEG'),
-     ('height', 399),
-     ('orientation', 1),
-     ('root', u'../tests/images'),
-     ('size', (600, 399)),
+     ('height', 640),
+     ('orientation', 8),
+     ('root', u'../tests'),
+     ('size', (480, 640)),
      ('subfolder', u''),
-     ('width', 600)]
+     ('width', 480)]
     >>> type(d) == dict
     True
-    >>> info.set(vars=vars+['Iptc_Application2_Copyright'])
+    >>> info.set(vars=vars + ['Iptc_Application2_Copyright'])
     >>> info.extract_all()
     >>> pprint.pprint(sorted(info.dump(expand=False).keys()))
-    ['Exif_Image_Artist',
-     'Exif_Image_Copyright',
-     'Exif_Image_ImageDescription',
+    ['Exif_CanonCs_0x0000',
+     'Exif_CanonCs_0x0006',
+     'Exif_CanonCs_0x0008',
+     'Exif_CanonCs_0x0009',
+     'Exif_CanonCs_0x0015',
+     'Exif_CanonCs_0x001e',
+     'Exif_CanonCs_0x001f',
+     'Exif_CanonCs_0x0026',
+     'Exif_CanonCs_0x0027',
+     'Exif_CanonCs_0x0029',
+     'Exif_CanonCs_0x002b',
+     'Exif_CanonCs_0x002c',
+     'Exif_CanonCs_0x002d',
+     'Exif_CanonCs_AESetting',
+     'Exif_CanonCs_AFPoint',
+     'Exif_CanonCs_ColorTone',
+     'Exif_CanonCs_Contrast',
+     'Exif_CanonCs_DigitalZoom',
+     'Exif_CanonCs_DisplayAperture',
+     'Exif_CanonCs_DriveMode',
+     'Exif_CanonCs_EasyMode',
+     'Exif_CanonCs_ExposureProgram',
+     'Exif_CanonCs_FlashActivity',
+     'Exif_CanonCs_FlashDetails',
+     'Exif_CanonCs_FlashMode',
+     'Exif_CanonCs_FocusContinuous',
+     'Exif_CanonCs_FocusMode',
+     'Exif_CanonCs_FocusType',
+     'Exif_CanonCs_ISOSpeed',
+     'Exif_CanonCs_ImageSize',
+     'Exif_CanonCs_ImageStabilization',
+     'Exif_CanonCs_Lens',
+     'Exif_CanonCs_LensType',
+     'Exif_CanonCs_Macro',
+     'Exif_CanonCs_MaxAperture',
+     'Exif_CanonCs_MeteringMode',
+     'Exif_CanonCs_MinAperture',
+     'Exif_CanonCs_PhotoEffect',
+     'Exif_CanonCs_Quality',
+     'Exif_CanonCs_Saturation',
+     'Exif_CanonCs_Selftimer',
+     'Exif_CanonCs_Sharpness',
+     'Exif_CanonCs_ZoomSourceWidth',
+     'Exif_CanonCs_ZoomTargetWidth',
+     'Exif_CanonSi_0x0000',
+     'Exif_CanonSi_0x0001',
+     'Exif_CanonSi_0x0003',
+     'Exif_CanonSi_0x0006',
+     'Exif_CanonSi_0x0008',
+     'Exif_CanonSi_0x000a',
+     'Exif_CanonSi_0x000b',
+     'Exif_CanonSi_0x000c',
+     'Exif_CanonSi_0x000d',
+     'Exif_CanonSi_0x0010',
+     'Exif_CanonSi_0x0011',
+     'Exif_CanonSi_0x0012',
+     'Exif_CanonSi_0x0014',
+     'Exif_CanonSi_0x0017',
+     'Exif_CanonSi_0x0018',
+     'Exif_CanonSi_0x0019',
+     'Exif_CanonSi_0x001a',
+     'Exif_CanonSi_0x001b',
+     'Exif_CanonSi_0x001c',
+     'Exif_CanonSi_0x001d',
+     'Exif_CanonSi_0x001e',
+     'Exif_CanonSi_0x001f',
+     'Exif_CanonSi_0x0020',
+     'Exif_CanonSi_0x0021',
+     'Exif_CanonSi_AFPointUsed',
+     'Exif_CanonSi_ApertureValue',
+     'Exif_CanonSi_FlashBias',
+     'Exif_CanonSi_ISOSpeed',
+     'Exif_CanonSi_Sequence',
+     'Exif_CanonSi_ShutterSpeedValue',
+     'Exif_CanonSi_SubjectDistance',
+     'Exif_CanonSi_TargetAperture',
+     'Exif_CanonSi_TargetShutterSpeed',
+     'Exif_CanonSi_WhiteBalance',
+     'Exif_Canon_0x0000',
+     'Exif_Canon_0x0003',
+     'Exif_Canon_0x000d',
+     'Exif_Canon_0x0013',
+     'Exif_Canon_0x0018',
+     'Exif_Canon_0x0019',
+     'Exif_Canon_0x001c',
+     'Exif_Canon_0x001d',
+     'Exif_Canon_0x001e',
+     'Exif_Canon_0x001f',
+     'Exif_Canon_0x0022',
+     'Exif_Canon_0x0023',
+     'Exif_Canon_0x0024',
+     'Exif_Canon_0x0025',
+     'Exif_Canon_0x0026',
+     'Exif_Canon_0x0027',
+     'Exif_Canon_0x0028',
+     'Exif_Canon_FirmwareVersion',
+     'Exif_Canon_FocalLength',
+     'Exif_Canon_ImageNumber',
+     'Exif_Canon_ImageType',
+     'Exif_Canon_ModelID',
+     'Exif_Canon_OwnerName',
+     'Exif_Image_DateTime',
+     'Exif_Image_ExifTag',
+     'Exif_Image_Make',
+     'Exif_Image_Model',
+     'Exif_Image_Orientation',
+     'Exif_Image_ResolutionUnit',
+     'Exif_Image_XResolution',
+     'Exif_Image_YCbCrPositioning',
+     'Exif_Image_YResolution',
+     'Exif_Iop_InteroperabilityIndex',
+     'Exif_Iop_InteroperabilityVersion',
+     'Exif_Iop_RelatedImageLength',
+     'Exif_Iop_RelatedImageWidth',
+     'Exif_MakerNote_ByteOrder',
+     'Exif_MakerNote_Offset',
+     'Exif_Photo_ApertureValue',
+     'Exif_Photo_ColorSpace',
+     'Exif_Photo_ComponentsConfiguration',
+     'Exif_Photo_CompressedBitsPerPixel',
+     'Exif_Photo_CustomRendered',
+     'Exif_Photo_DateTimeDigitized',
+     'Exif_Photo_DateTimeOriginal',
+     'Exif_Photo_DigitalZoomRatio',
+     'Exif_Photo_ExifVersion',
+     'Exif_Photo_ExposureBiasValue',
+     'Exif_Photo_ExposureMode',
+     'Exif_Photo_ExposureTime',
+     'Exif_Photo_FNumber',
+     'Exif_Photo_FileSource',
+     'Exif_Photo_Flash',
+     'Exif_Photo_FlashpixVersion',
+     'Exif_Photo_FocalLength',
+     'Exif_Photo_FocalPlaneResolutionUnit',
+     'Exif_Photo_FocalPlaneXResolution',
+     'Exif_Photo_FocalPlaneYResolution',
+     'Exif_Photo_InteroperabilityTag',
+     'Exif_Photo_MakerNote',
+     'Exif_Photo_MaxApertureValue',
+     'Exif_Photo_MeteringMode',
+     'Exif_Photo_PixelXDimension',
+     'Exif_Photo_PixelYDimension',
+     'Exif_Photo_SceneCaptureType',
+     'Exif_Photo_SensingMethod',
+     'Exif_Photo_ShutterSpeedValue',
+     'Exif_Photo_UserComment',
+     'Exif_Photo_WhiteBalance',
+     'Exif_Thumbnail_Compression',
+     'Exif_Thumbnail_JPEGInterchangeFormat',
+     'Exif_Thumbnail_JPEGInterchangeFormatLength',
+     'Exif_Thumbnail_ResolutionUnit',
+     'Exif_Thumbnail_XResolution',
+     'Exif_Thumbnail_YResolution',
      'Iptc_Application2_Byline',
      'Iptc_Application2_Caption',
      'Iptc_Application2_Copyright',
      'Iptc_Application2_ObjectName',
      'Iptc_Application2_RecordVersion',
-     'Pil_jfif',
-     'Pil_jfif_density',
-     'Pil_jfif_unit',
-     'Pil_jfif_version',
      'aspect',
      'compression',
      'day',
@@ -1784,19 +1922,22 @@ class InfoExtract:
         if vars is None:
             vars = []
         self.list = []
-        self._vars = None #list of possible vars which can occur
+        self._vars = None  # list of possible vars which can occur
         self._vars_by_info = None
         self.set_vars(vars, filename)
         if filename:
             self.open(filename, sources)
 
     def __getitem__(self, var):
+        # force var as string, otherwise py2exiv fails (eg with unicode)
+        # eg u'Exif_Photo_DateTimeOriginal'
+        var = str(var)
         for info in self.list:
             if info.provides(var):
                 return info[var]
         raise KeyError(var)
 
-    def set(self, filename=None, vars=None, sources = None):
+    def set(self, filename=None, vars=None, sources=None):
         """Set new parameters for the info.
 
         :param filename: filename of the source file
@@ -1810,7 +1951,7 @@ class InfoExtract:
         elif not(filename is None):
             self.open(filename, sources)
 
-    def open(self, filename, sources = None):
+    def open(self, filename, sources=None):
         """Feeds a new file as source for all info types.
 
         :param filename: filename of the source file
@@ -1821,16 +1962,16 @@ class InfoExtract:
         if filename:
             self.filename = filename.replace('file://', '')
         if not self._vars:
-            #->all variables, which are image dependent
+            # ->all variables, which are image dependent
             self._vars_by_info = get_vars_by_info(filename)
         self.clear_cache()
-        #ensure sources is a dict
+        # ensure sources is a dict
         if not sources:
             sources = {}
-        #load files
+        # load files
         self.list = [
             Info(sources.get(Info, self.filename), self._vars_by_info[Info])
-            for Info in self._vars_by_info.keys()]#use keys to respect order
+            for Info in self._vars_by_info.keys()]  # use keys to respect order
         self.set_orientation()
         return self
 
@@ -1851,14 +1992,13 @@ class InfoExtract:
         :param old_vars: previous variables
         :type old_vars: list of strings
         """
-        #import rpdb2; rpdb2.start_embedded_debugger('x')
-        #collect all requested infos
+        # collect all requested infos
         if vars:
             vars_by_info, vars_unknown = cls.scan_infos(vars)
         else:
             vars_by_info = get_vars_by_info(filename)
             vars_unknown = []
-        #check orientation
+        # check orientation
         set_vars_by_info = set(vars_by_info)
         if not set_vars_by_info.intersection(INFOS_WITH_ORIENTATION):
             needs_orientation = [Info
@@ -1866,7 +2006,7 @@ class InfoExtract:
                 if Info.needs_orientation(vars_by_info[Info])]
             if needs_orientation:
                 if not(vars_by_info[InfoPil] is None):
-                    #orientation is included in None already
+                    # orientation is included in None already
                     vars_by_info[InfoPil] += ['orientation']
         return vars_by_info, vars_unknown
 
@@ -1877,11 +2017,11 @@ class InfoExtract:
         :param vars: variables that have to be extracted (e.g. orientation)
         :type vars: list
         """
-        #collect all requested infos
+        # collect all requested infos
         if vars != self._vars:
             self._vars_by_info, self.vars_unknown = \
                 self.get_vars_by_info(vars, self._vars, filename)
-        #update vars (needs to be after previous collect)
+        # update vars (needs to be after previous collect)
         if not vars:
             vars = []
         self._vars = list(set(vars).difference(self.vars_unknown))
@@ -1891,7 +2031,7 @@ class InfoExtract:
             try:
                 orientation = self['orientation']
             except:
-                #no orientation needed
+                # no orientation needed
                 return
         for info in self.list:
             if info.needs_orientation(info.vars):
@@ -1907,9 +2047,9 @@ class InfoExtract:
         :rtype: dict of lists
         """
         Infos = odict.odict()
-        todo = vars[:] #we don't want to change the orignal vars
+        todo = vars[:]  # we don't want to change the orignal vars
         todo_temp = vars[:]
-        #loop first over Infos so that the info order is kept
+        # loop first over Infos so that the info order is kept
         for Info in INFOS:
             for var in todo:
                 if Info.provides(var):
@@ -1917,14 +2057,14 @@ class InfoExtract:
                         Infos[Info].append(var)
                     else:
                         Infos[Info] = [var]
-                    #var is provided, so don't look for it anymore
+                    # var is provided, so don't look for it anymore
                     todo_temp.remove(var)
-            #make a copy as we can't modify an looping iterable
+            # make a copy as we can't modify an looping iterable
             if todo_temp:
                 todo = todo_temp[:]
             else:
                 break
-        #return vars by info, unknown vars
+        # return vars by info, unknown vars
         return Infos, todo_temp
 
     def provides(self, var):
@@ -1952,7 +2092,7 @@ class InfoExtract:
         """Clear alfl info types."""
         self.list = []
 
-    def dump(self, filename=None, expand = False):
+    def dump(self, filename=None, expand=False, free=False):
         """Dump as a dictionary.
 
         :param vars: list of variables as arguments
@@ -1975,6 +2115,8 @@ class InfoExtract:
             d.update(info.dict)
         if expand:
             self.expand(d)
+        if free:
+            self.list = []
         return d
 
     @classmethod
@@ -1986,13 +2128,13 @@ class InfoExtract:
     def expand_var(cls, d, key, value):
         if isinstance(value, DateTime):
             for attr in DateTime.attrs:
-                d['%s.%s'%(key, attr)] = getattr(value, attr)
+                d['%s.%s' % (key, attr)] = getattr(value, attr)
         elif type(value) in (tuple, list) and len(value) < 10:
             for index, value_index in enumerate(value):
-                d['%s[%d]'%(key, index)] = value[index]
-        elif hasattr(value, 'denominator') and value.denominator!= 1:
-            d['%s.denominator'%key] = value.denominator
-            d['%s.numerator'%key] = value.numerator
+                d['%s[%d]' % (key, index)] = value[index]
+        elif hasattr(value, 'denominator') and value.denominator != 1:
+            d['%s.denominator' % key] = value.denominator
+            d['%s.numerator' % key] = value.numerator
 
     def set_source(self, d):
         """Set source of an info from the collection. Raises an
