@@ -69,7 +69,7 @@ THUMB_SIZE = (128, 128)
 TAGS = [SELECT, ALL, 'Pil']
 if pyexiv2:
     TAGS.extend(['Exif', 'Iptc'])
-TAGS.extend(['Pexif', 'Zexif'])#'EXIF',
+TAGS.extend(['Pexif', 'Zexif'])  # 'EXIF',
 TITLE = _('Image Inspector')
 
 WX_ENCODING = wx.GetDefaultPyEncoding()
@@ -248,7 +248,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
         super(Grid, self).__init__(parent)
         #table
         self.table = self.Table(thumb_size)
-        self.image_table= self.table.table
+        self.image_table = self.table.table
         self.SetTable(self.table, True)
         self.SetRowLabelSize(260)
         self._rows_number = self.GetNumberRows()
@@ -315,11 +315,11 @@ class Grid(droplet.Mixin, gridlib.Grid):
         ]:
             if new < current:
                 msg = gridlib.GridTableMessage(self.table, delmsg, new,
-                    current-new)
+                    current - new)
                 self.ProcessTableMessage(msg)
             elif new > current:
                 msg = gridlib.GridTableMessage(self.table, addmsg,
-                    new-current)
+                    new - current)
                 self.ProcessTableMessage(msg)
         self._rows_number = self.GetNumberRows()
         self._cols_number = self.GetNumberCols()
@@ -338,7 +338,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
                 if force_thumbs or not hasattr(image, 'thumb_wx'):
                     image.thumb_wx = wxPil.pil_wxBitmap(image.thumb)
                 heights.append(image.thumb.size[1])
-            self.SetColLabelSize(max(heights)+2*self.border)
+            self.SetColLabelSize(max(heights) + 2 * self.border)
 
     def RefreshAll(self, update_column=False, force_thumbs=False):
         self.BeginBatch()
@@ -371,8 +371,8 @@ class Grid(droplet.Mixin, gridlib.Grid):
         dc.Clear()
         pen = dc.GetPen()
         dc.SetPen(self.GRAY_PEN)
-        dc.DrawLine(rect[0], rect[1]+rect[3]-1,
-            rect[0]+rect[2], rect[1]+rect[3]-1)
+        dc.DrawLine(rect[0], rect[1] + rect[3] - 1,
+            rect[0] + rect[2], rect[1] + rect[3] - 1)
 
         def label_rect(position, col):
             col_width = self.GetColSize(col)
@@ -384,7 +384,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
 
         self._LabelPaint(dc, co=0, amount=self.GetNumberCols(),
             label_rect=label_rect, get_size=self.GetColSize,
-            get_label=None, #self.GetColLabelValue,
+            get_label=None,  # self.GetColLabelValue,
             get_bitmap=get_bitmap, border=False, center_bitmap=True,
             pen=pen)
 
@@ -398,8 +398,8 @@ class Grid(droplet.Mixin, gridlib.Grid):
         dc = wx.PaintDC(window)
         pen = dc.GetPen()
         dc.SetPen(self.GRAY_PEN)
-        dc.DrawLine(rect[0], rect[1]+rect[3]-1,
-            rect[0]+rect[2], rect[1]+rect[3]-1)
+        dc.DrawLine(rect[0], rect[1] + rect[3] - 1,
+            rect[0] + rect[2], rect[1] + rect[3] - 1)
 
         def label_rect(position, col):
             return rect
@@ -409,7 +409,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
 
         self._LabelPaint(dc, co=0, amount=1,
             label_rect=label_rect, get_size=self.GetColSize,
-            get_label=None, #self.GetColLabelValue,
+            get_label=None,  # self.GetColLabelValue,
             get_bitmap=get_bitmap, border=False, center_bitmap=True,
             pen=pen)
 
@@ -430,6 +430,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
         event.Skip()
         row, col = event.GetRow(), event.GetCol()
         #bind menu events
+
         def on_copy(event):
             self.CopyCellValue(row, col)
 
@@ -476,8 +477,10 @@ class Grid(droplet.Mixin, gridlib.Grid):
         self._AppendMenuItem(menu, _('Open &Url...'), self.OnOpenUrl,
             'Shift+Ctrl+O')
         #remove image
+
         def on_remove(event):
             self.DeleteCols(col)
+
         self._AppendMenuItem(menu, _('&Remove Image'), on_remove)
         #show menu
         self.PopupMenu(menu)
@@ -486,7 +489,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
     def _AppendMenuItem(self, menu, label, method, shortcut='', id=None):
         if id is None:
             id = wx.NewId()
-        menu.Append(id, '%s\t%s'%(label, shortcut))
+        menu.Append(id, '%s\t%s' % (label, shortcut))
         self.Bind(wx.EVT_MENU, method, id=id)
 
     def OnGridRowLabelRightClicked(self, row):
@@ -532,7 +535,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
                 on_set_row_values, 'Shift+Ctrl+M')
 
     def CopyRowLabel(self, row):
-        clipboard.copy_text('<%s>'%self.table.GetRowLabelValue(row))
+        clipboard.copy_text('<%s>' % self.table.GetRowLabelValue(row))
 
     def AddRow(self):
         key, value = AddTagDialog(self, self.image_table.keys).GetModal()
@@ -541,7 +544,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
             col = self.GetGridCursorCol()
             log = self.image_table.add_key(key, value)
             if log:
-                self.ShowError(log, _('Unable to add tag <%s>')%key)
+                self.ShowError(log, _('Unable to add tag <%s>') % key)
             self.RefreshAll()
             wx.CallAfter(self.MakeCellVisible, row, col)
 
@@ -552,27 +555,27 @@ class Grid(droplet.Mixin, gridlib.Grid):
             image = self.image_table.images[col]
             log = self.image_table.add_image_key(image, key, value)
             if log:
-                self.ShowError(log, _('Unable to add tag <%s>')%key)
+                self.ShowError(log, _('Unable to add tag <%s>') % key)
             self.RefreshAll()
             wx.CallAfter(self.MakeCellVisible, row, col)
 
     def DeleteCell(self, row, col):
         key = self.GetRowLabelValue(row)
         image_name = self.GetColLabelValue(col)
-        if self.Ask('%s\n<%s>'%(CONFIRM_DELETE_TAG%image_name, key)) \
+        if self.Ask('%s\n<%s>' % (CONFIRM_DELETE_TAG % image_name, key)) \
                 == wx.ID_YES:
             log = self.image_table.delete_cell(row, col)
             if log:
-                self.ShowError(log, _('Unable to delete tag <%s>')%key)
+                self.ShowError(log, _('Unable to delete tag <%s>') % key)
             self.RefreshAll()
 
     def DeleteRows(self, pos=0, num=1):
         key = self.GetRowLabelValue(pos)
-        if self.Ask('%s\n<%s>'%(CONFIRM_DELETE_TAG_ALL, key)) \
+        if self.Ask('%s\n<%s>' % (CONFIRM_DELETE_TAG_ALL, key)) \
                 == wx.ID_YES:
             log = self.table.DeleteRows(pos, num)
             if log:
-                self.ShowError(log, _('Unable to delete tag <%s>')%key)
+                self.ShowError(log, _('Unable to delete tag <%s>') % key)
             self.RefreshAll()
 
     def DeleteCols(self, pos=0, num=1):
@@ -590,7 +593,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
             log = self.table.SetRowLabelValue(row, key_new)
             if log:
                 self.ShowError(log, _('Unable to rename tag <%s>')\
-                    %key_old)
+                    % key_old)
             self.RefreshAll()
 
     def ChangeRowValues(self, row):
@@ -601,7 +604,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
             log = self.image_table.set_key_value(key, value)
             if log:
                 self.ShowError(log, _('Unable to change tag <%s>')\
-                    %key)
+                    % key)
             self.RefreshAll()
 
     def OnKeyDown(self, event):
@@ -649,8 +652,8 @@ class Grid(droplet.Mixin, gridlib.Grid):
         dc = wx.PaintDC(window)
         pen = dc.GetPen()
         dc.SetPen(self.GRAY_PEN)
-        dc.DrawLine(rect[0]+rect[2]-1, rect[1],
-            rect[0]+rect[2]-1, rect[1]+rect[3])
+        dc.DrawLine(rect[0] + rect[2] - 1, rect[1],
+            rect[0] + rect[2] - 1, rect[1] + rect[3])
 
         def label_rect(position, row):
             row_width = self.GetRowLabelSize()
@@ -671,7 +674,7 @@ class Grid(droplet.Mixin, gridlib.Grid):
     def _LabelPaint(self, dc, co, amount, label_rect, get_size,
             get_label, get_bitmap, border, center_bitmap, pen):
         position = -self.GetViewStart()[co]\
-            *self.GetScrollPixelsPerUnit()[co]
+            * self.GetScrollPixelsPerUnit()[co]
         dc.SetBrush(self.GRAY_BRUSH)
         for index in range(amount):
             size = get_size(index)
@@ -680,33 +683,33 @@ class Grid(droplet.Mixin, gridlib.Grid):
             if position < 0:
                 continue
             if border:
-                dc.DrawLine(rect[0], rect[1]+rect[3]-1,
-                    rect[0]+rect[2], rect[1]+rect[3]-1)
+                dc.DrawLine(rect[0], rect[1] + rect[3] - 1,
+                    rect[0] + rect[2], rect[1] + rect[3] - 1)
             bitmap = get_bitmap(index)
             if bitmap:
                 bitmap_size = bitmap.GetSize()
                 if center_bitmap:
                     #centered
-                    offset_x = (rect[2]-bitmap_size[0])/2
+                    offset_x = (rect[2] - bitmap_size[0]) / 2
                 else:
                     #right aligned
-                    offset_x = rect[2]-bitmap_size[0]-self.border
-                offset_y = (rect[3]-bitmap_size[1])/2
+                    offset_x = rect[2] - bitmap_size[0] - self.border
+                offset_y = (rect[3] - bitmap_size[1]) / 2
                 dc.DrawBitmap(bitmap,
-                    rect[0]+offset_x,
-                    rect[1]+offset_y,
+                    rect[0] + offset_x,
+                    rect[1] + offset_y,
                     True)
             else:
-                offset_y = (rect[3]-self.PENCIL_BITMAP_SIZE[1])/2
+                offset_y = (rect[3] - self.PENCIL_BITMAP_SIZE[1]) / 2
             dc.SetPen(pen)
             if get_label:
-                dc.DrawText(get_label(index), rect[0]+self.border,
-                    rect[1]+offset_y)
+                dc.DrawText(get_label(index), rect[0] + self.border,
+                    rect[1] + offset_y)
 
     #---dialogs
     def Ask(self, message, title=''):
         return self.ShowMessage(message, title,
-            style=wx.YES_NO|wx.ICON_QUESTION)
+            style=wx.YES_NO | wx.ICON_QUESTION)
 
     def AskText(self, question, value='', title=''):
         dlg = wx.TextEntryDialog(self, question, title, value)
@@ -729,14 +732,14 @@ class Grid(droplet.Mixin, gridlib.Grid):
         return answer
 
     def ShowError(self, message, title=TITLE):
-        return self.ShowMessage(message, title, style=wx.OK|wx.ICON_ERROR)
+        return self.ShowMessage(message, title, style=wx.OK | wx.ICON_ERROR)
 
     def OpenImage(self, filename):
         try:
             self.image_table.open_image(filename, encoding=WX_ENCODING)
         except IOError, message:
-            self.show_error(_('Sorry, %s.')%str(message),
-                title = _('Image Inspector'))
+            self.show_error(_('Sorry, %s.') % str(message),
+                title=_('Image Inspector'))
             return
         self.image_table.update()
         self.UpdateThumbs()
@@ -749,10 +752,9 @@ class Grid(droplet.Mixin, gridlib.Grid):
             encoding=WX_ENCODING)
         if invalid:
             wx.CallAfter(wx.EndBusyCursor)
-            self.show_error('%s:\n\n%s'%(
+            self.show_error('%s:\n\n%s' % (
                     _('Sorry, unable to open these images:'),
-                    '\n'.join(invalid)),
-                title = TITLE)
+                    '\n'.join(invalid)), title=TITLE)
             wx.BeginBusyCursor()
         if len(invalid) != len(filenames):
             self.UpdateThumbs()
@@ -769,9 +771,10 @@ class Grid(droplet.Mixin, gridlib.Grid):
             return self.GetGridCursorRow(), self.GetGridCursorCol()
 
     def show_error(self, message, title):
-        return self.show_message(message, title, style=wx.OK|wx.ICON_ERROR)
+        return self.show_message(message, title, style=wx.OK | wx.ICON_ERROR)
 
-    def show_message(self, message, title='', style=wx.OK|wx.ICON_EXCLAMATION):
+    def show_message(self, message, title='',
+            style=wx.OK | wx.ICON_EXCLAMATION):
         if self.IsShown():
             parent = wx.GetTopLevelParent(self)
         else:
@@ -794,10 +797,9 @@ class OpenMixin(object):
             style |= wx.FD_PREVIEW
         path = os.path.dirname(self.image_table.images[-1].filename)
         dlg = wx.FileDialog(self, _("Choose an image"),
-            defaultDir = path,
-            wildcard = self.wildcard,
-            style = style,
-            )
+            defaultDir=path,
+            wildcard=self.wildcard,
+            style=style)
         if dlg.ShowModal() == wx.ID_OK:
             self.OpenImage(dlg.GetPath())
         dlg.Destroy()
@@ -854,26 +856,25 @@ class Browser(tag.Browser):
     def GetPaintMessage(self):
         content = self.GetContent()
         if not content.image_table.images:
-            return _('drag & drop any image here')
+            return _('drag & drop any images here')
         tag = self.tag.GetStringSelection().lower()
         if tag == 'Exif' and not pyexiv2:
             return _('please install pyexiv2')
         if content.image_table.key_amount_tag:
             return _('broaden your search')
-        return _('no %s tags found')%tag
+        return _('no %s tags found') % tag
 
 
 class Frame(wx.Frame):
     Browser = Browser
 
-    def __init__(self, parent, filename='', icon = None,
+    def __init__(self, parent, filename='', icon=None,
             thumb_size=THUMB_SIZE, *args, **kwds):
         #adapt style
-        if not('style' in kwds):
-            kwds["style"] = wx.DEFAULT_DIALOG_STYLE|wx.RESIZE_BORDER
-        if parent:
-            kwds["style"] |= \
-                wx.FRAME_FLOAT_ON_PARENT|wx.FRAME_NO_TASKBAR
+        if not('style' in kwds) and parent:
+            kwds["style"] = wx.DEFAULT_DIALOG_STYLE | wx.RESIZE_BORDER | \
+                wx.FRAME_FLOAT_ON_PARENT | wx.FRAME_NO_TASKBAR | \
+                wx.MAXIMIZE_BOX
         super(Frame, self).__init__(parent, *args, **kwds)
         if icon:
             self.SetIcon(icon)
@@ -885,6 +886,7 @@ class Frame(wx.Frame):
         elif os.path.isdir(filename):
             self.GetGrid().OpenImages([filename])
         #bind events
+        self.browser.EnableResize()
         self.Bind(wx.EVT_ACTIVATE, self.OnActivate)
         self.Bind(UPDATE_EVENT, self.UpdateIfNeeded)
 
@@ -905,12 +907,12 @@ class Frame(wx.Frame):
         #main_sizer
         main_sizer = wx.BoxSizer(wx.VERTICAL)
         #browser
-        main_sizer.Add(self.browser, 1, wx.ALL|wx.EXPAND, 4)
+        main_sizer.Add(self.browser, 1, wx.ALL | wx.EXPAND, 4)
         #layout
         self.panel.SetSizer(main_sizer)
         #panel_sizer
         panel_sizer = wx.BoxSizer(wx.VERTICAL)
-        panel_sizer.Add(self.panel, 1, wx.ALL|wx.EXPAND, 0)
+        panel_sizer.Add(self.panel, 1, wx.ALL | wx.EXPAND, 0)
         self.SetSizer(panel_sizer)
         #layout
         self.Layout()
@@ -928,7 +930,7 @@ class Frame(wx.Frame):
         """To be called from the grid."""
         if filename.strip():
             di, ba = os.path.split(filename)
-            self.SetTitle('%s %s'%(ba, di))
+            self.SetTitle('%s %s' % (ba, di))
         else:
             self.SetTitle(TITLE)
 
