@@ -24,7 +24,7 @@ GetValue(english)
 The bridge between fields and ctrls is done as follows:
 formField.Field <-> treeEdit.create_popup <-> popup.Ctrl"""
 
-if __name__=='__main__':
+if __name__ == '__main__':
     import sys
     sys.path.insert(0, '..')
     sys.path.insert(0, '../..')
@@ -36,7 +36,7 @@ import wx
 import wx.lib.colourselect
 
 from lib.colors import RGBToHTMLColor, HTMLColorToRGB
-from lib.fonts import font_dictionary, font_names
+from lib.fonts import font_dictionary
 from lib.reverse_translation import _t
 
 from autoCompleteCtrls import AutoCompleteTextCtrl, AutoCompleteIconCtrl
@@ -52,7 +52,7 @@ except NameError:
 
 
 ICON_SIZE = (64, 64)
-LOADING = _('loading')+' ...'
+LOADING = _('loading') + ' ...'
 FONT_PATHS = ['/usr/share/fonts/truetype']
 if sys.platform.startswith('linux'):
     TEXTCTRL_BORDER = 2
@@ -64,7 +64,7 @@ else:
 
 def SetMinVerSize(item, size, border=0):
     item_size = item.GetSize()
-    min_size = (size[0], min(item.GetSize()[1], size[1]-2*border))
+    min_size = (size[0], min(item.GetSize()[1], size[1] - 2 * border))
     item.SetMinSize(min_size)
     item.SetSize(min_size)
 
@@ -76,8 +76,8 @@ class ForcedBoxSizer(wx.BoxSizer):
         self._size = (height, height)
         self._border = border
 
-    def AddForced(self, item, proportion, flag=wx.ALL|wx.ALIGN_CENTER_VERTICAL,
-            border=None, size=None):
+    def AddForced(self, item, proportion,
+            flag=wx.ALL | wx.ALIGN_CENTER_VERTICAL, border=None, size=None):
         if not border:
             border = self._border
         if not size:
@@ -96,8 +96,8 @@ class NotImplementedError(Exception):
         self.method = method
 
     def __str__(self):
-        return 'Class "%s" did not implement method "%s".'\
-            %(self.instance.__class__.__name__, self.method)
+        return 'Class "%s" did not implement method "%s".' \
+            % (self.instance.__class__.__name__, self.method)
 
 
 #---base controls
@@ -152,13 +152,15 @@ class _CtrlRelevantMixin:
             self.on_change(unicode(self.Get()))
         #other option in case troubles pop up (see also Close method)
         #wx.CallAfter(self.OnAfterChange)
+
     def OnAfterChange(self):
         self.on_change(unicode(self.Get()))
 
 
-class TextCtrl(_CtrlChoices, wx.ComboBox):
+class TextCtrl(_CtrlRelevantMixin, _CtrlChoices, wx.ComboBox):
 
-    def __init__(self, parent, value, id=-1, choices=None, **keyw):
+    def __init__(self, parent, value, id=-1, choices=None, on_change=None,
+            **keyw):
         if choices is None:
             choices = []
         local_choices = self.RegisterChoices(choices)
@@ -172,6 +174,8 @@ class TextCtrl(_CtrlChoices, wx.ComboBox):
         super(TextCtrl, self).__init__(parent, id, value,
             choices=local_choices, **keyw)
         self.Set(value)
+        self.SetRelevant(wx.EVT_TEXT, on_change)
+        self.OnChange()
 
 
 class _ComposedCtrl(_Ctrl, wx.Panel):
@@ -217,7 +221,8 @@ class _PathCtrl(_ComposedCtrl):
     def _CreateCtrls(self, value, extensions=[], **extra):
         #folder
         self.path = self.InputCtrl(self, id=-1, value=value, **extra)
-        if self.InputCtrl==wx.TextCtrl and not sys.platform.startswith('win'):
+        if self.InputCtrl == wx.TextCtrl \
+                and not sys.platform.startswith('win'):
             self.path.SetSelection(-1, -1)
         #browse button
         bmp = wx.ArtProvider_GetBitmap(wx.ART_FOLDER_OPEN, wx.ART_OTHER,
@@ -234,7 +239,8 @@ class _PathCtrl(_ComposedCtrl):
             #windows & mac like some distance
             b = 4
         #don't force button, as crop is preferred to being crippled
-        sizer.Add(self.browse, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, b)
+        sizer.Add(self.browse, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL | wx.RIGHT,
+            b)
         sizer.AddForced(self.path, 1)
 
     def _CreateEvents(self):
@@ -244,7 +250,7 @@ class _PathCtrl(_ComposedCtrl):
         if default_path is None:
             default_path = os.path.dirname(self.path.GetValue())
         old = None
-        while not os.path.exists(default_path) and (default_path!=old):
+        while not os.path.exists(default_path) and (default_path != old):
             old = default_path
             default_path = os.path.dirname(default_path)
         return default_path
@@ -266,6 +272,7 @@ METRICS = ['px', '%', 'cm', 'mm', 'inch']
 
 #---Main Controls (will be automatically registered through meta-class)
 
+
 class BooleanCtrl(_CtrlRelevantMixin, _Ctrl, wx.CheckBox):
 
     def __init__(self, parent, value, size, on_change=None):
@@ -312,7 +319,7 @@ class ComboCtrl(_CtrlWithItems, wx.ComboBox):
         self.style = style
         result = 0
         for s in style:
-            result |= getattr(wx, 'CB_'+s)
+            result |= getattr(wx, 'CB_' + s)
         return result
 
 
@@ -341,6 +348,8 @@ class ImageDictionaryFileCtrl(_CtrlRelevantMixin, _Ctrl, wx.Button):
         if self.title in self.dialogs:
             dlg = ImageDictionaryFileCtrl.dialogs[self.title]
         else:
+            dlg = None
+        if not dlg:
             if self.icon_size == (128, 128):
                 height = 350
             else:
@@ -348,11 +357,11 @@ class ImageDictionaryFileCtrl(_CtrlRelevantMixin, _Ctrl, wx.Button):
             frame = wx.GetApp().GetTopWindow()
             dlg = self.dialogs[self.title] = \
                 imageFileBrowser.Dialog(
-                    parent = frame,
-                    files = self.dictionary,
-                    title = self.title,
-                    size = (frame.GetSize()[0], height),
-                    icon_size = self.icon_size,
+                    parent=frame,
+                    files=self.dictionary,
+                    title=self.title,
+                    size=(frame.GetSize()[0], height),
+                    icon_size=self.icon_size,
                 )
             dlg.ShowPath(self.show_path)
         if value is None:
@@ -403,16 +412,16 @@ class ColorCtrl(_Ctrl, wx.lib.colourselect.ColourSelect):
 
 
 class FileCtrl(_PathCtrl):
-    wildcard = _t('All files')+'|*'
+    wildcard = _t('All files') + '|*'
 
     def OnBrowse(self, event):
         style = wx.OPEN | wx.CHANGE_DIR
         if hasattr(wx, 'FD_PREVIEW'):
             style |= wx.FD_PREVIEW
         dlg = wx.FileDialog(self, self._to_local("Choose a file"),
-            defaultFile = self.GetDefaultPath(),
-            wildcard = self.GetWildcard(),
-            style = style,
+            defaultFile=self.GetDefaultPath(),
+            wildcard=self.GetWildcard(),
+            style=style,
             )
         if dlg.ShowModal() == wx.ID_OK:
             value = dlg.GetPath()
@@ -436,14 +445,14 @@ class LabelFileCtrl(FileCtrl):
     def GetWildcard(self):
         if self._extensions:
             if len(self._extensions) < 5:
-                label = '%s (%s)'%(self._label,
+                label = '%s (%s)' % (self._label,
                     ','.join(self._extensions))
             else:
                 label = self._label
             menu = [wildcard_list(self._to_local(label), self._extensions)]
         else:
             menu = []
-        menu.append(self._all_files+'|*')
+        menu.append(self._all_files + '|*')
         return '|'.join(menu)
 
 
@@ -451,8 +460,8 @@ class FolderCtrl(_PathCtrl):
 
     def OnBrowse(self, event):
         dlg = wx.DirDialog(self, self._to_local("Choose a folder"),
-            defaultPath = self.GetDefaultPath(),
-            style = wx.DEFAULT_DIALOG_STYLE)
+            defaultPath=self.GetDefaultPath(),
+            style=wx.DEFAULT_DIALOG_STYLE)
         if dlg.ShowModal() == wx.ID_OK:
             self.path.SetValue(dlg.GetPath())
         dlg.Destroy()
@@ -466,7 +475,7 @@ class DictionaryFileCtrl(LabelFileCtrl):
         choices = dictionary.keys()
         choices.sort()
         super(DictionaryFileCtrl, self).__init__(parent, value, size,
-            choices = choices, **extra)
+            choices=choices, **extra)
 
     def GetDefaultPath(self, default_path=None):
         if default_path is None:
@@ -481,8 +490,8 @@ class AutoCompleteDictionaryFileCtrl(DictionaryFileCtrl):
     def _CreateCtrls(self, value, extensions=[], **extra):
         super(AutoCompleteDictionaryFileCtrl, self)._CreateCtrls(value,
             extensions,
-            style=wx.CB_DROPDOWN,#for compatibility with dropdown
-            **extra)
+            style=wx.CB_DROPDOWN,  # for compatibility with dropdown
+            ** extra)
         if hasattr(self.path, "StartEvents"):
             self.path.StartEvents()
 
@@ -525,7 +534,7 @@ class PixelCtrl(_ComposedCtrl):
         sizer.AddForced(self.size, 1)
         width = self.unit.GetSize()[0]
         if wx.Platform == '__WXGTK__':
-            width = int(width*0.8)
+            width = int(width * 0.8)
         sizer.AddForced(self.unit, 0, size=(width, height))
 
     def _CreateEvents(self):
@@ -550,14 +559,14 @@ class PixelCtrl(_ComposedCtrl):
     def GetValue(self):
         value = self.size.GetValue()
         if value:
-            return '%s %s'%(value, self.unit.GetStringSelection())
+            return '%s %s' % (value, self.unit.GetStringSelection())
         else:
             return ''
 
     def SetFocus(self):
         self.size.SetFocus()
 
-FILE_SIZE_UNITS = ['kb', '%', 'bt', 'mb', 'gb']
+FILE_SIZE_UNITS = ['kb', 'bt', 'mb', 'gb']
 
 
 class FileSizeCtrl(PixelCtrl):
@@ -578,7 +587,7 @@ class SliderCtrl(_ComposedCtrl):
                         style=wx.SL_HORIZONTAL)
 
     def _AddCtrls(self, sizer, height):
-        sizer.AddForced(self.spin, 0, size=(int(height*1.85), height))
+        sizer.AddForced(self.spin, 0, size=(int(height * 1.85), height))
         sizer.AddForced(self.slider, 1)
 
     def _CreateEvents(self):
@@ -615,8 +624,8 @@ class FloatSliderCtrl(SliderCtrl):
         #spin ctrl
         self.spin = wx.TextCtrl(self, -1, str(value))
         #slider
-        self.slider = wx.Slider(self, -1, int(value*self.unit),
-            int(minValue*self.unit), int(maxValue*self.unit),
+        self.slider = wx.Slider(self, -1, int(value * self.unit),
+            int(minValue * self.unit), int(maxValue * self.unit),
             style=wx.SL_HORIZONTAL)
 
     def _CreateEvents(self):
@@ -631,13 +640,13 @@ class FloatSliderCtrl(SliderCtrl):
     def OnSpin(self, event):
         s = event.GetString()
         try:
-            value = int(float(s)*self.unit)
+            value = int(float(s) * self.unit)
         except ValueError:
             return
         self.slider.SetValue(value)
 
     def OnScroll(self, event):
-        self.spin.SetValue(str(self.slider.GetValue()/self.unit))
+        self.spin.SetValue(str(self.slider.GetValue() / self.unit))
 
 #todo implement all controls as panel with custom BoxSizer
 #or maybe PopupControl should take care of this
@@ -652,7 +661,7 @@ def ctrl_factory(name, CtrlMixin):
     except KeyError:
         #example: name = FontFile (derived from class name)
         _globals = globals()
-        ctrl_name = name+'Ctrl'
+        ctrl_name = name + 'Ctrl'
         if ctrl_name in _globals:
             #this control is defined in this module
             Ctrl = _globals[ctrl_name]
@@ -661,11 +670,11 @@ def ctrl_factory(name, CtrlMixin):
             Ctrl = globals().get(ctrl_name, TextCtrl)
         if not (CtrlMixin is None):
             if isinstance(CtrlMixin, list):
-                bases = tuple(CtrlMixin+[Ctrl])
+                bases = tuple(CtrlMixin + [Ctrl])
             else:
                 bases = (CtrlMixin, Ctrl)
             Ctrl = type(name, bases, {})
-        CTRL_CACHE[ctrl_key]= Ctrl
+        CTRL_CACHE[ctrl_key] = Ctrl
     return Ctrl
 
 
@@ -700,7 +709,7 @@ class EditPanel(wx.Panel):
         if Ctrl._busy_cursor:
             wx.BeginBusyCursor()
         self.edit = Ctrl(self, value=Ctrl._to_english(value_as_string),
-                            size=(height, height-2*border), **extra)
+                            size=(height, height - 2 * border), **extra)
         #check min size
         if self.edit.GetSize()[1] > height:
             self.edit.SetMinSize((self.edit.GetMinSize()[0], height))
@@ -715,7 +724,7 @@ class EditPanel(wx.Panel):
         sizer.Add((offset, offset), 0)
         if label:
             sizer.Add(self.labelCtrl, proportion=0,
-                flag = wx.ALL|wx.ALIGN_CENTER_VERTICAL)
+                flag=wx.ALL | wx.ALIGN_CENTER_VERTICAL)
         sizer.AddForced(self.edit, proportion=1, border=border)
         if border < TEXTCTRL_BORDER and wx.Platform != '__WXGTK__':
             border = min(TEXTCTRL_BORDER, border)
@@ -758,7 +767,7 @@ def example():
             sizer = wx.BoxSizer(wx.VERTICAL)
 
             def on_change(*args):
-                print('on_change %s'%str(args))
+                print('on_change %s' % str(args))
 
             for typ, ctrl in ctrls:
                 if issubclass(ctrl, SliderCtrl):
