@@ -23,7 +23,6 @@
 #---first test
 import os
 import time
-import types
 
 if __name__ == '__main__':
     import sys
@@ -31,7 +30,6 @@ if __name__ == '__main__':
     sys.path.insert(0, os.path.dirname(os.getcwd()))
     #test environment
     import gettext
-    import sys
     gettext.install("test")
 
 #---begin
@@ -42,10 +40,8 @@ from lib.reverse_translation import _r
 from core import pil
 
 #core.lib
-from lib import formField
 from lib import system
 from core.message import send, ProgressReceiver
-from core.pil import exif
 
 #gui-dependent
 from lib.pyWx import clipboard
@@ -60,14 +56,15 @@ import images
 from wxGlade import dialogs
 
 VLIST_ICON_SIZE = (48, 48)
+_MAX_HEIGHT = None  # cache
 
 
 def get_max_height(height=510):
     global _MAX_HEIGHT
-    try:
+    if _MAX_HEIGHT is None:
+        _MAX_HEIGHT = min(height, wx.Display(0).GetGeometry().GetHeight() - 50)
         return _MAX_HEIGHT
-    except NameError:
-        _MAX_HEIGHT = min(height, wx.Display(0).GetGeometry().GetHeight()-50)
+    else:
         return _MAX_HEIGHT
 
 
@@ -76,8 +73,8 @@ class BrowseMixin:
     def show_dir_dialog(self, defaultPath, message=_('Choose a folder'),
             style=wx.DEFAULT_DIALOG_STYLE):
         dlg = wx.DirDialog(self, message,
-            defaultPath = defaultPath,
-            style = wx.DEFAULT_DIALOG_STYLE)
+            defaultPath=defaultPath,
+            style=wx.DEFAULT_DIALOG_STYLE)
         if dlg.ShowModal() == wx.ID_OK:
             path = dlg.GetPath()
         else:
@@ -86,15 +83,15 @@ class BrowseMixin:
         return path
 
 
-class _IconDialog:
+class IconMixin:
 
     if wx.Platform == '__WXGTK__':
-        _icon_size = (32, 32)#(48, 48)
+        _icon_size = (32, 32)  # (48, 48)
     else:
         _icon_size = (32, 32)
 
     def _icon(self, name='information'):
-        name = 'ART_%s'%name.upper()
+        name = 'ART_%s' % name.upper()
         #title icon
         bitmap = graphics.bitmap(name, (16, 16))
         _ic = wx.EmptyIcon()
@@ -106,7 +103,7 @@ class _IconDialog:
         self.icon.Show(True)
 
 
-class ErrorDialog(dialogs.ErrorDialog, _IconDialog):
+class ErrorDialog(dialogs.ErrorDialog, IconMixin):
 
     def __init__(self, parent, message, ignore=True, **keyw):
         super(ErrorDialog, self).__init__(parent, -1, **keyw)
@@ -134,22 +131,17 @@ class ExecuteDialog(BrowseMixin, dialogs.ExecuteDialog):
     def __init__(self, parent, drop=False, **options):
         super(ExecuteDialog, self).__init__(parent, -1, **options)
         self.set_drop(drop)
-        if wx.Platform == '__WXGTK__':
-            width = 600
-        else:
-            width = 450
-        self.SetSize((width, self.GetSize()[1]))
 
     def browse_files(self):
         style = wx.OPEN | wx.MULTIPLE | wx.CHANGE_DIR
         if hasattr(wx, 'FD_PREVIEW'):
             style |= wx.FD_PREVIEW
         dlg = wx.FileDialog(
-            self, message = _("Choose File(s)"),
-            defaultDir = self.get_default_path(),
-            defaultFile = "",
-            wildcard = self.wildcard(),
-            style = style,
+            self, message=_("Choose File(s)"),
+            defaultDir=self.get_default_path(),
+            defaultFile="",
+            wildcard=self.wildcard(),
+            style=style,
             )
         if dlg.ShowModal() == wx.ID_OK:
             self.path.SetValue(ct.PATH_DELIMITER.join(dlg.GetPaths()))
@@ -157,8 +149,8 @@ class ExecuteDialog(BrowseMixin, dialogs.ExecuteDialog):
 
     def browse_folder(self):
         path = self.show_dir_dialog(
-            defaultPath = self.get_default_path(),
-            message = _("Choose an image folder"))
+            defaultPath=self.get_default_path(),
+            message=_("Choose an image folder"))
         if path != None:
             self.path.SetValue(path)
 
@@ -247,8 +239,8 @@ class ExecuteDialog(BrowseMixin, dialogs.ExecuteDialog):
         read = wildcard_list(_('All readable types'),
                         pil.IMAGE_READ_EXTENSIONS)
         result = [selected, default, read]
-        result.extend([('%s '+_('images')+'|%s')\
-                    %(ext, _wildcard_extension(ext))
+        result.extend([('%s ' + _('images') + '|%s')\
+                    % (ext, _wildcard_extension(ext))
                     for ext in extensions])
         return '|'.join(result)
 
@@ -278,10 +270,10 @@ class ExecuteDialog(BrowseMixin, dialogs.ExecuteDialog):
                 .replace('\n', ct.PATH_DELIMITER))
         else:
             self.browse.Enable()
-            self.browse.SetLabel(_('Browse %s')%source)
+            self.browse.SetLabel(_('Browse %s') % source)
 
 
-class FilesDialog(dialogs.FilesDialog, _IconDialog):
+class FilesDialog(dialogs.FilesDialog, IconMixin):
 
     def __init__(self, parent, message, title, files, icon='warning', **keyw):
         super(FilesDialog, self).__init__(parent, -1, **keyw)
@@ -305,14 +297,14 @@ class ProgressDialog(wx.ProgressDialog, ProgressReceiver):
 
     def __init__(self, parent, title, parent_max=1, child_max=1, message=''):
         if message == '':
-            message = '.'*80
+            message = '.' * 80
         ProgressReceiver.__init__(self, parent_max, child_max)
         wx.ProgressDialog.__init__(self,
-                title = title,
-                message = message,
-                maximum = self.max,
-                parent = parent,
-                style = wx.PD_CAN_ABORT
+                title=title,
+                message=message,
+                maximum=self.max,
+                parent=parent,
+                style=wx.PD_CAN_ABORT
                             | wx.PD_APP_MODAL
                             | wx.PD_REMAINING_TIME
                             | wx.PD_SMOOTH)
@@ -356,8 +348,8 @@ class ActionListBox(ContentMixin, vlistTag.Box):
             self.tag_actions = [a for a in self.all_actions
                 if tag_i18n in a.tags_i18n]
         #sort
-        self.tag_actions.sort(cmp =
-            lambda x, y: cmp(_(x.label_i18n), _(y.label_i18n)))
+        self.tag_actions.sort(cmp=lambda \
+            x, y: cmp(_(x.label_i18n), _(y.label_i18n)))
         #take filter in account
         self.SetFilter(self.GetFilter().GetValue())
 
@@ -373,7 +365,7 @@ class ActionListBox(ContentMixin, vlistTag.Box):
         self.SetItemCount(len(self.actions))
         self.GetParent().CheckEmpty()
         self.RefreshAll()
-        wx.GetTopLevelParent(self).ok.Enable(bool(self.actions))
+        wx.GetTopLevelParent(self).ok.Enable(not self.IsEmpty())
 
     def _filter_actions(self, filter, actions):
         selected = self._filter_attr(filter, 'label_i18n', actions)
@@ -391,7 +383,7 @@ class ActionListBox(ContentMixin, vlistTag.Box):
             if filter in unicode(getattr(action, attr))]
         for action in selected2:
             actions.remove(action)
-        return selected1+selected2
+        return selected1 + selected2
 
     def _events(self):
         self.Bind(wx.EVT_CONTEXT_MENU, self.OnContextMenu)
@@ -401,8 +393,8 @@ class ActionListBox(ContentMixin, vlistTag.Box):
         self.all_actions = actions.values()
         for action in self.all_actions:
             self.TranslateAction(action)
-        self.all_actions.sort(cmp =
-            lambda x, y: cmp(_(x.label_i18n), _(y.label_i18n)))
+        self.all_actions.sort(cmp=lambda x, y: \
+            cmp(_(x.label_i18n), _(y.label_i18n)))
 
     def TranslateAction(self, action):
         action.label_i18n = _(action.label).lower()
@@ -427,13 +419,12 @@ class ActionListBox(ContentMixin, vlistTag.Box):
         menu.Destroy()
 
     def OnViewSource(self, event):
-        import actions
         action = self.actions[self.GetSelection()]
         module = action.__module__.split('.')[-1]
-        filename = os.path.join(ct.PHATCH_ACTIONS_PATH, '%s.py'%module)
+        filename = os.path.join(ct.PHATCH_ACTIONS_PATH, '%s.py' % module)
         message = open(filename).read()
         dir, base = os.path.split(filename)
-        send.frame_show_scrolled_message(message, '%s - %s'%(base, dir),
+        send.frame_show_scrolled_message(message, '%s - %s' % (base, dir),
             size=(600, 300))
 
     def RefreshList(self):
@@ -460,6 +451,7 @@ class ActionBrowser(Browser):
     paint_color = images.LOGO_COLOUR
     #paint_logo = images.LOGO
 
+
 class ActionDialog(paint.Mixin, vlistTag.Dialog):
     ContentBrowser = ActionBrowser
 
@@ -480,7 +472,7 @@ class ActionDialog(paint.Mixin, vlistTag.Dialog):
         tags = vlistTag.extract_tags(actions)
         tags.remove(_('default'))
         tags.sort()
-        tags = [imageInspector.SELECT, imageInspector.ALL]+tags
+        tags = [imageInspector.SELECT, imageInspector.ALL] + tags
         return tags
 
     def GetListBox(self):
@@ -497,14 +489,14 @@ class ActionDialog(paint.Mixin, vlistTag.Dialog):
             wx.CallAfter(self.GetListBox().GetFilter().SetFocus)
 
 
-class WritePluginDialog(dialogs.WritePluginDialog, _IconDialog):
+class WritePluginDialog(dialogs.WritePluginDialog, IconMixin):
 
     def __init__(self, parent, message, **keyw):
         super(WritePluginDialog, self).__init__(parent, -1, **keyw)
         path = os.path.join(ct.PATH, 'templates', 'action.py')
         self._icon('information')
         self.message.SetLabel(message)
-        self.path.SetLabel('%s: %s'%(_('Path'), path))
+        self.path.SetLabel('%s: %s' % (_('Path'), path))
         self._code(path)
         self.template_show(False)
 
@@ -623,7 +615,7 @@ class ImageTreeDialog(dialogs.ImageTreeDialog):
     def _AppendMenuItem(self, menu, label, method, shortcut='', id=None):
         if id is None:
             id = wx.NewId()
-        menu.Append(id, '%s\t%s'%(label, shortcut))
+        menu.Append(id, '%s\t%s' % (label, shortcut))
         self.Bind(wx.EVT_MENU, method, id=id)
 
     def inspect_list_item(self, index):
@@ -634,14 +626,15 @@ class ImageTreeDialog(dialogs.ImageTreeDialog):
 
     def inspect(self, path):
         frame = ImageInspectorFrame(None,
-            filename = path,
-            size = (470, get_max_height(510)),
-            icon = images.get_icon('inspector'))
+            filename=path,
+            size=(470, get_max_height(510)),
+            icon=images.get_icon('inspector'))
         frame.Show()
 
     def on_tree_item_right_click(self, event):
         item = event.GetItem()
         #menu events handlers
+
         def on_open(event):
             self.browser.start_tree_item(item)
 
@@ -662,6 +655,7 @@ class ImageTreeDialog(dialogs.ImageTreeDialog):
     def on_list_item_right_click(self, event):
         index = event.GetIndex()
         #menu events handlers
+
         def on_open(event):
             self.browser.start_list_item(index)
 
@@ -704,14 +698,15 @@ class ImageInspectorGrid(imageInspector.GridTag):
 
     def CreateRowLabelMenu(self, menu, row):
         super(ImageInspectorGrid, self).CreateRowLabelMenu(menu, row)
-        id_insert = wx.NewId()
-        menu.Append(id_insert,
-            _('&Insert Tag in Action List...')+'\tCtrl+Shift+I')
+        if self.HasActionList():
+            id_insert = wx.NewId()
+            menu.Append(id_insert,
+                _('&Insert Tag in Action List...') + '\tCtrl+Shift+I')
 
-        def on_insert(event):
-            self.InsertTagInActionList(row)
+            def on_insert(event):
+                self.InsertTagInActionList(row)
 
-        self.Bind(wx.EVT_MENU, on_insert, id=id_insert)
+            self.Bind(wx.EVT_MENU, on_insert, id=id_insert)
 
     def ProcessKey(self, key_code, row, col, shift, ctrl, alt):
         if ctrl and shift and key_code == 73:
@@ -720,10 +715,14 @@ class ImageInspectorGrid(imageInspector.GridTag):
             shift, ctrl, alt)
 
     def InsertTagInActionList(self, row):
-        key = '<%s>'%self.GetRowLabelValue(row)
+        key = '<%s>' % self.GetRowLabelValue(row)
         frame = wx.GetApp().GetTopWindow()
         frame.tree.set_form_field_value_selected(key)
 
+    def HasActionList(self):
+        frame = wx.GetApp().GetTopWindow()
+        return hasattr(frame, 'tree')
+
 
 class ImageInspectorBrowser(imageInspector.Browser):
     ContentCtrl = ImageInspectorGrid
