@@ -10,31 +10,35 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
-
+#
 # Embedded icons (48x48) are from NuoveXt 1.6:
 # - Author: Alexandre Moore
 # - Author website: http://nuovext.pwsp.net/
 # - Icon website: http://www.gnome-look.org/content/show.php?content=26448
-# - Icon download: http://www.gnome-look.org/content/download.php?content=26448&id=1&tan=15504822&PHPSESSID=34ec3de1af33e253ee03357a124bfbeb
+# - Icon download: http://www.gnome-look.org/content/download.php?
+# content=26448&id=1&tan=15504822&PHPSESSID=34ec3de1af33e253ee03357a124bfbeb
 # - License: GPL
+#
+# Follow PEP8
 
 import wx
 from lib.pyWx import graphics
 
+
 class Provider(wx.ArtProvider):
-    def CreateBitmap(self,artid,client,size):
-        if PROVIDER.has_key(artid):
+    def CreateBitmap(self, artid, client, size):
+        if artid in PROVIDER:
             return graphics.bitmap(PROVIDER[artid])
         else:
             return wx.NullBitmap
-        
+
 PROVIDER = {}
-        
+
 #---wx.ART_ADD_BOOKMARK
-PROVIDER[wx.ART_ADD_BOOKMARK]=\
+PROVIDER[wx.ART_ADD_BOOKMARK] = \
 'x\xda\x01\xe7\x06\x18\xf9\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \
 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08\
 |\x08d\x88\x00\x00\x06\x9eIDATX\x85\xcdVkl\\G\x15\xfe\xce\xcc\xdc\xdd\xeb}x\
@@ -107,7 +111,7 @@ i\xb7\xe6<\xf0\xa5\xe7+~U\xdb\xc1\x9e\xde\xba\xad\x16\x9fo\xedF\xcc\r/\x9f]\
 \x00\x00IEND\xaeB`\x82%\xdaW\x14'
 
 #---wx.ART_COPY
-PROVIDER[wx.ART_COPY]=\
+PROVIDER[wx.ART_COPY] = \
 'x\xda\x01\xa1\x03^\xfc\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
 \x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
 \x08d\x88\x00\x00\x03XIDATX\x85\xc5W=O\x1bA\x10}3w\x1b\x03\x85\x95\x08$$\xda\
@@ -144,10 +148,10 @@ oo_\xc6\xc7l\xdb\xc7M\x08^\xad\x16"\n\x8f\xe3yL)\x95\\)mE\xeb\xe4t\xe0L\x84\
 \x00x\x1f\xa7\xf3\xd8\xc1\xc1\xc1[\xa5\xd4\xd6d\xa7\x13f\x16"\x92\xc9\x1d\
 \xc0\xb5\x85\x88\xack\x03\xb0\x00d0\x18<\x9c\x9c\x9c\xf4\xcf\xce\xce\x1e\x8f\
 \x8e\x8e\x9e\xb7\xb6\xb6\x00\x00\x7f\x003\xf8\x06\x93\x9f\x8duC\x00\x00\x00\
-\x00IEND\xaeB`\x82\xfd\x1c\xa3\xd7' 
+\x00IEND\xaeB`\x82\xfd\x1c\xa3\xd7'
 
 #---wx.ART_DEL_BOOKMARK
-PROVIDER[wx.ART_DEL_BOOKMARK]=\
+PROVIDER[wx.ART_DEL_BOOKMARK] = \
 'x\xda\x01 \x07\xdf\xf8\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
 \x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
 \x08d\x88\x00\x00\x06\xd7IDATX\x85\xcd\x96MlT\xd7\x15\xc7\x7f\xe7\xbe\xf7f\
@@ -222,7 +226,7 @@ WqWU=&\x0f\xad\x0b\xb8\x05U\xe7\x1b\xd5PUED\x12"\xe2\x01!\x10ZkC\x111\x95\
 D\xaeB`\x82\xf0\x13j\xa4'
 
 #---wx.ART_EXECUTABLE_FILE
-PROVIDER[wx.ART_EXECUTABLE_FILE]=\
+PROVIDER[wx.ART_EXECUTABLE_FILE] = \
 'x\xda\x01/\x07\xd0\xf8\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
 \x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
 \x08d\x88\x00\x00\x06\xe6IDATX\x85\xcd\x96]l\\G\x15\xc7\xff3w\xee\xee\xb5w\
@@ -296,7 +300,7 @@ JS)\xc5\xb4\xd6Lk\xcd\x000\xad\xb5\xb1\xfcm\x18^\x98\xa5a\x94A\x03\xd9i,H\
 \x82\x854Z\x7f'
 
 #---wx.ART_FILE_OPEN, wx.ART_FOLDER_OPEN
-PROVIDER[wx.ART_FILE_OPEN]=PROVIDER[wx.ART_FOLDER_OPEN]=\
+PROVIDER[wx.ART_FILE_OPEN] = PROVIDER[wx.ART_FOLDER_OPEN] = \
 'x\xda\x01\xca\x055\xfa\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
 \x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
 \x08d\x88\x00\x00\x05\x81IDATX\x85\xb5W\xdfk\x1cU\x14\xfe\xee\xee\xcc\xec\
@@ -357,7 +361,7 @@ F\x89\x93\'O\x8a\xd6\xda$\xa2\x0e\xefaVD\xb2\xcc\x9c%\x12s\xe7\xc1\xa3\xe8\
 |\x1a\tj\x00\x00\x00\x00IEND\xaeB`\x82c\x98\xa2\xce'
 
 #---wx.ART_FIND
-PROVIDER[wx.ART_FIND]=\
+PROVIDER[wx.ART_FIND] = \
 'x\xda\x01U\x06\xaa\xf9\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
 \x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
 \x08d\x88\x00\x00\x06\x0cIDATX\x85\xc5\x97]lT\xd7\x11\xc7\xff\xe7\x9c{\xed\
@@ -424,7 +428,7 @@ u\xba\xb1\xb1\x91\xaf_\xbf\xce\xc7\x8f\x1f\x7f\xb9\xbd\xbd\xfd\xfeM\xe9W%\
 \n'
 
 #---wx.ART_GO_DOWN
-PROVIDER[wx.ART_GO_DOWN]=\
+PROVIDER[wx.ART_GO_DOWN] = \
 'x\xda\x01,\x07\xd3\xf8\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
 \x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
 \x08d\x88\x00\x00\x06\xe3IDATX\x85\xcd\x96[l\x1cW\x1d\xc6\xbfsffw\xf6\xbe\
@@ -498,7 +502,7 @@ nWYy\xa1T\xc4\xe5\xd1~\xc4\xaf\'\x91\x1a\x94\xbf\xfc\xeb\xf3\xc5\xef\xaf\xe6\
 \x00\x00\x00IEND\xaeB`\x82$q\\\xb6'
 
 #---wx.ART_GO_HOME
-PROVIDER[wx.ART_GO_HOME]=\
+PROVIDER[wx.ART_GO_HOME] = \
 'x\xda\x01x\x07\x87\xf8\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
 \x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
 \x08d\x88\x00\x00\x07/IDATX\x85\xb5\x96[\x8c$e\x15\xc7\x7fU\xd5\xd5]}\x99K\
@@ -575,7 +579,7 @@ d\xd6J\x85\xec)1\x82\xe3\xfaL\xce}\xfaGG\xeex\xe8\xa9~y\x80\x9d\xc1\xb1\x97\
 \xd6\xb7\xfe\x03\x14 -\x99u}%\xb9\x00\x00\x00\x00IEND\xaeB`\x82\x01%\xa1V'
 
 #---wx.ART_GO_UP
-PROVIDER[wx.ART_GO_UP]=\
+PROVIDER[wx.ART_GO_UP] = \
 'x\xda\x019\x07\xc6\xf8\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
 \x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
 \x08d\x88\x00\x00\x06\xf0IDATX\x85\xcd\x96]lT\xc7\x15\xc7\xff\xf3qw\xef~\xd9\
@@ -650,7 +654,7 @@ g\x0c\xc6.J\x93\x19\xc5\xd1\xcdu;\x7f\xf1\xbb\x17:\xf4\x17\x02\xb8k\xbb^\x0e\
 \xa5\xfd\x1b\xac\x1e\x82\x18@\xe9\xdd\xa1\x00\x00\x00\x00IEND\xaeB`\x82XuXz'\
 
 #---wx.ART_TIP
-PROVIDER[wx.ART_TIP]=\
+PROVIDER[wx.ART_TIP] = \
 'x\xda\x01G\x06\xb8\xf9\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
 \x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
 \x08d\x88\x00\x00\x05\xfeIDATX\x85\xd5W[l\x14U\x18\xfe\xfe3gvg/\xdd\xed\x14)\
