@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-
+#
 # Phatch - Photo Batch Processor
 # Copyright (C) 2007-2008 www.stani.be
 #
@@ -17,19 +17,22 @@
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
 # Phatch recommends SPE (http://pythonide.stani.be) for editing python files.
-import os
-import sys
+#
+# Follow PEP8
+
 import wx
 from core import ct
 from core.api import import_module
 
 ID_droplet = wx.ID_FORWARD
 
+
 def install_frame(frame):
     try:
-        droplet  = import_module('droplet',ct.PLATFORM)#os.path.join('lib',ct.PLATFORM))
+        # os.path.join('lib', ct.PLATFORM))
+        droplet = import_module('droplet', ct.PLATFORM)
     except:
-        droplet  = None
+        droplet = None
     if droplet:
         droplet.install(frame)
     else:
