@@ -1,7 +1,5 @@
-#!/usr/bin/python
-
 # Phatch - Photo Batch Processor
-# Copyright (C) 2009 Nadia Alramli
+# Copyright (C) 2009 Nadia Alramli, Stani (www.stani.be)
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,11 +16,11 @@
 #
 # Phatch recommends SPE (http://pythonide.stani.be) for editing python files.
 #
+# Follows PEP8
 
 blender = {
     'Render Width': '128px',
-    'Render Height': '128px',
-}
+    'Render Height': '128px'}
 
 #geotag = {
 #    'GPS Data': ''
